@@ -6,23 +6,14 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C)      2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C)      2013 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText:      2006 by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText:      2013 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -87,22 +78,28 @@ DigikamApp::DigikamApp()
     ProgressManager::instance();
     ThumbnailLoadThread::setDisplayingWidget(this);
     DIO::instance();
+    LocalizeSettings::instance();
+    NetworkManager::instance();
+
+    connect(LocalizeSettings::instance(), &LocalizeSettings::signalOpenLocalizeSetup,
+            this, [=]()
+        {
+            Setup::execLocalize(this);
+        }
+    );
+
+    if (!ExifToolProcess::isCreated())
+    {
+        ExifToolThread* const exifToolThread = new ExifToolThread(this);
+        exifToolThread->start();
+    }
 
     // creation of the engine on first use - when drawing -
     // can take considerable time and cause a noticeable hang in the UI thread.
 
     QFontMetrics fm(font());
-
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
-
     fm.horizontalAdvance(QLatin1String("a"));
 
-#else
-
-    fm.width(QLatin1String("a"));
-
-#endif
-
     connect(ApplicationSettings::instance(), SIGNAL(setupChanged()),
             this, SLOT(slotSetupChanged()));
 
@@ -144,9 +141,9 @@ DigikamApp::DigikamApp()
     // to access items which were not created yet.
 
     setupView();
-    setupAccelerators();
     setupActions();
     setupStatusBar();
+    setupAccelerators();
 
     initGui();
 
@@ -300,8 +297,6 @@ DigikamApp::~DigikamApp()
 
     DatabaseServerStarter::instance()->stopServerManagerProcess();
 
-    AlbumManager::instance()->removeFakeConnection();
-
     delete d->modelCollection;
 
     m_instance = nullptr;
@@ -540,7 +535,7 @@ void DigikamApp::slotAlbumSelected(Album* album)
             bool isNormalAlbum   = !isRoot && !isAlbumRoot;
 
             d->deleteAction->setEnabled(isNormalAlbum);
-            d->renameAction->setEnabled(isNormalAlbum);
+            d->renameAction->setEnabled(isNormalAlbum || isAlbumRoot);
             d->propsEditAction->setEnabled(isNormalAlbum);
             d->openInFileManagerAction->setEnabled(isNormalAlbum || isAlbumRoot);
             d->newAction->setEnabled(isNormalAlbum || isAlbumRoot);
@@ -591,13 +586,15 @@ void DigikamApp::slotImageSelected(const ItemInfoList& selection, const ItemInfo
 
     ItemInfoList selectionWithoutGrouped = d->view->selectedInfoList(true, false);
 
-    foreach (const ItemInfo& info, selection)
+    Q_FOREACH (const ItemInfo& info, selection)
     {
+        // cppcheck-suppress useStlAlgorithm
         selectionFileSize += info.fileSize();
     }
 
-    foreach (const ItemInfo& info, listAll)
+    Q_FOREACH (const ItemInfo& info, listAll)
     {
+        // cppcheck-suppress useStlAlgorithm
         listAllFileSize += info.fileSize();
     }
 
@@ -780,7 +777,7 @@ void DigikamApp::slotSelectionChanged(int selectionCount)
     d->openWithAction->setEnabled(selectionCount > 0);
     d->imageAutoExifActionMenu->setEnabled(selectionCount > 0);
 
-    foreach (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this))
+    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this))
     {
         ac->setEnabled(selectionCount > 0);
     }
@@ -855,7 +852,7 @@ void DigikamApp::slotToggleShowBar()
 
 void DigikamApp::moveEvent(QMoveEvent*)
 {
-    emit signalWindowHasMoved();
+    Q_EMIT signalWindowHasMoved();
 }
 
 void DigikamApp::slotTransformAction()
@@ -1076,7 +1073,7 @@ void DigikamApp::customizedTrashView(bool set)
     d->recurseTagsAction->setEnabled(set);
     d->refreshAction->setEnabled(set);
 
-    foreach (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericView, this))
+    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericView, this))
     {
         ac->setEnabled(set);
     }
