@@ -6,18 +6,9 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Extra tools
  *
- * Copyright (C) 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -46,26 +37,26 @@ void DigikamApp::setupSelectToolsAction()
 
     QString postCategory   = i18nc("@title Post Processing Tools", "Post-Processing");
 
-    foreach (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericTool, this))
+    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericTool, this))
     {
         actionModel->addAction(ac, postCategory);
     }
 
-    foreach (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this))
+    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericMetadata, this))
     {
         actionModel->addAction(ac, postCategory);
     }
 
     QString exportCategory = i18nc("@title Export Tools",          "Export");
 
-    foreach (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericExport, this))
+    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericExport, this))
     {
         actionModel->addAction(ac, exportCategory);
     }
 
     QString importCategory = i18nc("@title Import Tools",          "Import");
 
-    foreach (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericImport, this))
+    Q_FOREACH (DPluginAction* const ac, DPluginLoader::instance()->pluginsActions(DPluginAction::GenericImport, this))
     {
         actionModel->addAction(ac, importCategory);
     }
@@ -114,6 +105,9 @@ void DigikamApp::slotScanNewItems()
     connect(tool, SIGNAL(signalComplete()),
             this, SLOT(slotMaintenanceDone()));
 
+    connect(tool, SIGNAL(signalCanceled()),
+            this, SLOT(slotMaintenanceDone()));
+
     if (ApplicationSettings::instance()->getDetectFacesInNewImages())
     {
         connect(tool, SIGNAL(signalComplete()),
@@ -155,7 +149,7 @@ void DigikamApp::slotDetectFaces()
     settings.accuracy               = ApplicationSettings::instance()->getFaceDetectionAccuracy();
     settings.useYoloV3              = ApplicationSettings::instance()->getFaceDetectionYoloV3();
     settings.task                   = FaceScanSettings::DetectAndRecognize;
-    settings.alreadyScannedHandling = FaceScanSettings::Rescan;
+    settings.alreadyScannedHandling = FaceScanSettings::Skip;
     settings.infos                  = newImages;
 
     FacesDetector* const tool       = new FacesDetector(settings);
