@@ -6,20 +6,11 @@
  * Date        : 2006-21-12
  * Description : a embedded view to show item preview widget.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2010-2011 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2011 by Aditya Bhatt <adityabhatt1991 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,8 +31,28 @@
 
 // KDE includes
 
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#   pragma GCC diagnostic push
+#   pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic push
+#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#endif
+
+#include <kactioncollection.h>
 #include <klocalizedstring.h>
 
+// Restore warnings
+#if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#   pragma GCC diagnostic pop
+#endif
+
+#if defined(Q_CC_CLANG)
+#   pragma clang diagnostic pop
+#endif
+
 // Local includes
 
 #include "digikam_debug.h"
@@ -76,26 +87,27 @@ class Q_DECL_HIDDEN ItemPreviewView::Private
 public:
 
     explicit Private()
-      : fullSize(false),
-        scale(1.0),
-        isValid(false),
-        rotationLock(false),
-        mode(ItemPreviewView::IconViewPreview),
-        item(nullptr),
-        prevAction(nullptr),
-        nextAction(nullptr),
-        rotLeftAction(nullptr),
-        rotRightAction(nullptr),
-        toolBar(nullptr),
-        faceGroup(nullptr),
-        peopleToggleAction(nullptr),
-        addPersonAction(nullptr),
-        forgetFacesAction(nullptr),
-        focusPointGroup(nullptr),
-        addFocusPointAction(nullptr),
+      : fullSize            (false),
+        scale               (1.0),
+        isValid             (false),
+        rotationLock        (false),
+        mode                (ItemPreviewView::IconViewPreview),
+        item                (nullptr),
+        prevAction          (nullptr),
+        nextAction          (nullptr),
+        rotLeftAction       (nullptr),
+        rotRightAction      (nullptr),
+        toolBar             (nullptr),
+        faceGroup           (nullptr),
+        peopleToggleAction  (nullptr),
+        addPersonAction     (nullptr),
+        forgetFacesAction   (nullptr),
+        markAsIgnoredAction (nullptr),
+        focusPointGroup     (nullptr),
+        addFocusPointAction (nullptr),
         showFocusPointAction(nullptr),
-        fullscreenAction(nullptr),
-        currAlbum(nullptr)
+        fullscreenAction    (nullptr),
+        currAlbum           (nullptr)
     {
     }
 
@@ -119,6 +131,7 @@ public:
     QAction*               peopleToggleAction;
     QAction*               addPersonAction;
     QAction*               forgetFacesAction;
+    QAction*               markAsIgnoredAction;
 
     FocusPointGroup*       focusPointGroup;
     QAction*               addFocusPointAction;
@@ -131,7 +144,7 @@ public:
 
 ItemPreviewView::ItemPreviewView(QWidget* const parent, Mode mode, Album* const currAlbum)
     : GraphicsDImgView(parent),
-      d(new Private())
+      d               (new Private())
 {
     d->mode      = mode;
     d->item      = new ItemPreviewCanvas();
@@ -167,24 +180,52 @@ ItemPreviewView::ItemPreviewView(QWidget* const parent, Mode mode, Album* const
 
     // ------------------------------------------------------------
 
-    d->prevAction          = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),          i18nc("go to previous image", "Back"),  this);
-    d->nextAction          = new QAction(QIcon::fromTheme(QLatin1String("go-next")),              i18nc("go to next image", "Forward"),   this);
-    d->rotLeftAction       = new QAction(QIcon::fromTheme(QLatin1String("object-rotate-left")),   i18nc("@info:tooltip", "Rotate Left"),  this);
-    d->rotRightAction      = new QAction(QIcon::fromTheme(QLatin1String("object-rotate-right")),  i18nc("@info:tooltip", "Rotate Right"), this);
+    KActionCollection* const ac = DigikamApp::instance()->actionCollection();
 
-    d->addPersonAction     = new QAction(QIcon::fromTheme(QLatin1String("list-add-user")),        i18n("Add a Face Tag"),                 this);
+    d->prevAction               = new QAction(QIcon::fromTheme(QLatin1String("go-previous")),
+                                              i18nc("go to previous image", "Back"),  this);
+    d->nextAction               = new QAction(QIcon::fromTheme(QLatin1String("go-next")),
+                                              i18nc("go to next image", "Forward"),   this);
+    d->rotLeftAction            = new QAction(QIcon::fromTheme(QLatin1String("object-rotate-left")),
+                                              i18nc("@info:tooltip", "Rotate Left"),  this);
+    d->rotRightAction           = new QAction(QIcon::fromTheme(QLatin1String("object-rotate-right")),
+                                              i18nc("@info:tooltip", "Rotate Right"), this);
 
-    d->forgetFacesAction   = new QAction(QIcon::fromTheme(QLatin1String("list-remove-user")),     i18n("Clear all faces on this image"),  this);
-    d->peopleToggleAction  = new QAction(QIcon::fromTheme(QLatin1String("im-user")),              i18n("Show Face Tags"),                 this);
+    d->addPersonAction          = ac->action(QLatin1String("add_face_tag_manually"));
 
-    d->addFocusPointAction = new QAction(QIcon::fromTheme(QLatin1String("list-add-user")),        i18n("Add a focus point"),              this);
-    d->showFocusPointAction = new QAction(QIcon::fromTheme(QLatin1String("im-user")),             i18n("Show focus points"),              this);
+    if (!d->addPersonAction)
+    {
+        d->addPersonAction      = new QAction(QIcon::fromTheme(QLatin1String("list-add-user")),
+                                              i18n("Add a Face Tag"),                 this);
+        ac->addAction(QLatin1String("add_face_tag_manually"), d->addPersonAction);
+    }
+
+    d->forgetFacesAction        = new QAction(QIcon::fromTheme(QLatin1String("list-remove-user")),
+                                              i18n("Clear all faces on this image"),  this);
+
+    d->markAsIgnoredAction      = new QAction(QIcon::fromTheme(QLatin1String("dialog-cancel")),
+                                              i18n("Mark all unconfirmed faces as ignored"),  this);
+
+    d->peopleToggleAction       = ac->action(QLatin1String("toggle_show_face_tags"));
+
+    if (!d->peopleToggleAction)
+    {
+        d->peopleToggleAction   = new QAction(QIcon::fromTheme(QLatin1String("im-user")),
+                                              i18n("Show Face Tags"),                 this);
+        ac->addAction(QLatin1String("toggle_show_face_tags"), d->peopleToggleAction);
+    }
+
+    d->addFocusPointAction      = new QAction(QIcon::fromTheme(QLatin1String("list-add-user")),
+                                              i18n("Add a focus point"),              this);
+    d->showFocusPointAction     = new QAction(QIcon::fromTheme(QLatin1String("im-user")),
+                                              i18n("Show focus points"),              this);
 
     d->peopleToggleAction->setCheckable(true);
     d->showFocusPointAction->setCheckable(true);
 
-    d->fullscreenAction    = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")), i18n("Show Fullscreen"),                this);
-    d->toolBar             = new QToolBar(this);
+    d->fullscreenAction         = new QAction(QIcon::fromTheme(QLatin1String("media-playback-start")),
+                                              i18n("Show Fullscreen"),                this);
+    d->toolBar                  = new QToolBar(this);
     d->toolBar->setStyleSheet(toolButtonStyleSheet());
 
     if (mode == IconViewPreview)
@@ -215,17 +256,44 @@ ItemPreviewView::ItemPreviewView(QWidget* const parent, Mode mode, Album* const
     connect(d->peopleToggleAction, SIGNAL(toggled(bool)),
             d->faceGroup, SLOT(setVisible(bool)));
 
-    connect(d->addPersonAction, SIGNAL(triggered()),
-            d->faceGroup, SLOT(addFace()));
+    connect(d->addPersonAction, &QAction::triggered,
+            this, [this]()
+        {
+            if (isVisible() && hasFocus())
+            {
+                d->faceGroup->addFace();
+            }
+        }
+    );
 
     connect(d->forgetFacesAction, SIGNAL(triggered()),
             d->faceGroup, SLOT(rejectAll()));
 
+    connect(d->markAsIgnoredAction, SIGNAL(triggered()),
+            d->faceGroup, SLOT(markAllAsIgnored()));
+
     connect(d->addFocusPointAction, SIGNAL(triggered()),
             d->focusPointGroup, SLOT(addPoint()));
 
-    connect(d->showFocusPointAction, SIGNAL(toggled(bool)),
-            d->focusPointGroup, SLOT(setVisible(bool)));
+    connect(d->showFocusPointAction, &QAction::toggled,
+            this, [this](bool checked)
+        {
+            bool add = false;
+
+            if (checked)
+            {
+                d->focusPointGroup->setInfo(d->item->imageInfo());
+                add = d->focusPointGroup->isAllowedToAddFocusPoint();
+            }
+            else
+            {
+                d->focusPointGroup->setInfo(ItemInfo());
+            }
+
+            d->focusPointGroup->setVisible(checked);
+            d->addFocusPointAction->setEnabled(add);
+        }
+    );
 
     connect(d->fullscreenAction, SIGNAL(triggered()),
             this, SLOT(slotSlideShowCurrent()));
@@ -264,20 +332,34 @@ void ItemPreviewView::reload()
 
 void ItemPreviewView::imageLoaded()
 {
-    emit signalPreviewLoaded(true);
+    Q_EMIT signalPreviewLoaded(true);
     d->rotLeftAction->setEnabled(true);
     d->rotRightAction->setEnabled(true);
+
     d->faceGroup->setInfo(d->item->imageInfo());
 
-    d->focusPointGroup->setInfo(d->item->imageInfo());
-    d->addFocusPointAction->setEnabled(d->focusPointGroup->isAllowedToAddFocusPoint());
+    bool add = false;
+
+    if (d->showFocusPointAction->isChecked())
+    {
+        d->focusPointGroup->setInfo(d->item->imageInfo());
+        add = d->focusPointGroup->isAllowedToAddFocusPoint();
+    }
+    else
+    {
+        d->focusPointGroup->setInfo(ItemInfo());
+    }
+
+    d->addFocusPointAction->setEnabled(add);
 }
 
 void ItemPreviewView::imageLoadingFailed()
 {
-    emit signalPreviewLoaded(false);
+    Q_EMIT signalPreviewLoaded(false);
     d->rotLeftAction->setEnabled(false);
     d->rotRightAction->setEnabled(false);
+    d->addFocusPointAction->setEnabled(false);
+
     d->faceGroup->setInfo(ItemInfo());
     d->focusPointGroup->setInfo(ItemInfo());
 
@@ -321,7 +403,16 @@ bool ItemPreviewView::acceptsMouseClick(QMouseEvent* e)
     return d->faceGroup->acceptsMouseClick(mapToScene(e->pos()));
 }
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+void ItemPreviewView::enterEvent(QEnterEvent* e)
+
+#else
+
 void ItemPreviewView::enterEvent(QEvent* e)
+
+#endif
+
 {
     d->faceGroup->enterEvent(e);
 }
@@ -372,15 +463,28 @@ void ItemPreviewView::slotShowContextMenu(QGraphicsSceneContextMenuEvent* event)
 
     // --------------------------------------------------------
 
+    cmHelper.addAction(d->peopleToggleAction,  true);
     cmHelper.addAction(QLatin1String("image_scan_for_faces"));
-    cmHelper.addAction(d->peopleToggleAction, true);
-    cmHelper.addAction(d->addPersonAction,    true);
-    cmHelper.addAction(d->forgetFacesAction,  true);
+    cmHelper.addAction(d->addPersonAction,     true);
+
+    // if there is a face in the image, give the option to remove all faces
+    if (d->faceGroup->items().length() > 0)
+    {
+        cmHelper.addAction(d->forgetFacesAction,   true);
+    }
+
+    // if there is at least one unconfirmed face
+    if (d->faceGroup->hasUnconfirmed())
+    {
+        // give the option to ignore unconfirmed faces
+        cmHelper.addAction(d->markAsIgnoredAction, true);
+        // give the option to recognize faces
+        cmHelper.addAction(QLatin1String("image_recognize_faces"));
+    }
     cmHelper.addSeparator();
 
     // -------------------------------------------------------
 
-    cmHelper.addAction(QLatin1String("image_add_af_point"));
     cmHelper.addAction(d->addFocusPointAction,  true);
     cmHelper.addAction(d->showFocusPointAction, true);
     cmHelper.addSeparator();
@@ -559,7 +663,7 @@ void ItemPreviewView::slotRotateRight()
 
 void ItemPreviewView::slotDeleteItem()
 {
-    emit signalDeleteItem();
+    Q_EMIT signalDeleteItem();
 }
 
 void Digikam::ItemPreviewView::slotUpdateFaces()
@@ -612,7 +716,12 @@ void ItemPreviewView::dropEvent(QDropEvent* e)
         popMenu.addSeparator();
         popMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("&Cancel"));
         popMenu.setMouseTracking(true);
+
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+        QAction* const choice             = popMenu.exec(this->mapToGlobal(e->position().toPoint()));
+#else
         QAction* const choice             = popMenu.exec(this->mapToGlobal(e->pos()));
+#endif
 
         if (choice == assignToThisAction)
         {
