@@ -6,24 +6,15 @@
  * Date        : 2002-16-10
  * Description : Item icon view interface - View methods.
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2011 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2017      by Simon Frei <freisim93 at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Johannes Wienke <languitar at semipol dot de>
+ * SPDX-FileCopyrightText: 2010-2011 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2013 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2017      by Simon Frei <freisim93 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -81,7 +72,7 @@ void ItemIconView::slotIconView()
 {
     if (viewMode() == StackedView::PreviewImageMode)
     {
-        emit signalThumbSizeChanged(d->thumbSize);
+        Q_EMIT signalThumbSizeChanged(d->thumbSize);
     }
 
     // and switch to icon view
@@ -147,41 +138,41 @@ void ItemIconView::slotViewModeChanged()
     {
         case StackedView::IconViewMode:
         {
-            emit signalSwitchedToIconView();
-            emit signalThumbSizeChanged(d->thumbSize);
+            Q_EMIT signalSwitchedToIconView();
+            Q_EMIT signalThumbSizeChanged(d->thumbSize);
             break;
         }
 
         case StackedView::PreviewImageMode:
         {
-            emit signalSwitchedToPreview();
+            Q_EMIT signalSwitchedToPreview();
             slotZoomFactorChanged(d->stackedview->zoomFactor());
             break;
         }
 
         case StackedView::WelcomePageMode:
         {
-            emit signalSwitchedToIconView();
+            Q_EMIT signalSwitchedToIconView();
             break;
         }
 
         case StackedView::MediaPlayerMode:
         {
-            emit signalSwitchedToPreview();
+            Q_EMIT signalSwitchedToPreview();
             break;
         }
 
         case StackedView::MapWidgetMode:
         {
-            emit signalSwitchedToMapView();
+            Q_EMIT signalSwitchedToMapView();
             // TODO: connect map view's zoom buttons to main status bar zoom buttons
             break;
         }
 
         case StackedView::TableViewMode:
         {
-            emit signalSwitchedToTableView();
-            emit signalThumbSizeChanged(d->thumbSize);
+            Q_EMIT signalSwitchedToTableView();
+            Q_EMIT signalThumbSizeChanged(d->thumbSize);
             break;
         }
 
@@ -190,7 +181,7 @@ void ItemIconView::slotViewModeChanged()
             d->msgNotifyTimer->stop();
             d->errorWidget->animatedHide();
 
-            emit signalSwitchedToTrashView();
+            Q_EMIT signalSwitchedToTrashView();
             break;
         }
     }
@@ -409,7 +400,7 @@ void ItemIconView::slotShowGroupContextMenu(QContextMenuEvent* event,
 {
     QList<qlonglong> selectedImageIDs;
 
-    foreach (const ItemInfo& info, selectedInfos)
+    Q_FOREACH (const ItemInfo& info, selectedInfos)
     {
         selectedImageIDs << info.id();
     }
