@@ -7,20 +7,11 @@
  * Description : a widget to display a welcome page
  *               on root album.
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -32,6 +23,7 @@
 #include <QFileInfo>
 #include <QTimer>
 #include <QWidget>
+#include <QLabel>
 #include <QApplication>
 #include <QStandardPaths>
 
@@ -69,7 +61,7 @@ bool WelcomePageViewPage::acceptNavigationRequest(const QUrl& url, QWebEnginePag
 {
     if (type == QWebEnginePage::NavigationTypeLinkClicked)
     {
-        emit linkClicked(url);
+        Q_EMIT linkClicked(url);
 
         return false;
     }
@@ -107,13 +99,9 @@ WelcomePageView::WelcomePageView(QWidget* const parent)
     WelcomePageViewPage* const wpage = new WelcomePageViewPage(this);
     setPage(wpage);
 
-#   if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 7, 0)
-
     settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
     settings()->setAttribute(QWebEngineSettings::Accelerated2dCanvasEnabled, false);
 
-#   endif
-
 #endif
 
     // ------------------------------------------------------------
@@ -149,39 +137,40 @@ void WelcomePageView::slotUrlOpen(const QUrl& url)
 QStringList WelcomePageView::featuresTabContent() const
 {
     QStringList newFeatures;
-    newFeatures << i18n("More than 1300 user-reports closed on bugzilla.");
-    newFeatures << i18n("New Neural Network engine based on OpenCV Deep Learning module to detect and recognize faces.");
-    newFeatures << i18n("Update Slideshow to plugin with new shuffle mode.");
-    newFeatures << i18n("Add new theme Html5Responsive for HtmlGallery plugin.");
-    newFeatures << i18n("New plugin ImageMosaicWall to create an image based on a bunch of other photos.");
-    newFeatures << i18n("add new batch queue manager tool to fix hot pixels from images.");
-    newFeatures << i18n("add new batch queue manager tool to apply texture over images.");
-    newFeatures << i18n("Face Scan dialog contents is now simplified and embedded into left sidebar.");
-    newFeatures << i18n("Add support for Gimp XCF files >= 2.10.");
-    newFeatures << i18n("Add Flatpak bundle support for Linux platforms.");
-    newFeatures << i18n("Table-view is now able to show digiKam Tag-Paths properties.");
-    newFeatures << i18n("Add option to write geolocation information in file metadata.");
-    newFeatures << i18n("Add color label support for advanced metadata settings.");
-    newFeatures << i18n("Add Exif, Iptc, and Xmp read support for HEIF images.");
-    newFeatures << i18n("Improved support for UNC network paths under Windows.");
-    newFeatures << i18n("Improved support for Unicode paths under Windows.");
-    newFeatures << i18n("Apple bundle is now relocatable and compatible with macOS BigSur.");
-    newFeatures << i18n("New online version checker and downloader to automate upgrade under Windows and macOS.");
-    newFeatures << i18n("Better support of astro FITS image format including metadata extraction support to populate the database.");
-    newFeatures << i18n("Use last Exiv2 0.27.5 in all bundles with Base Media File metadata read and write support (HEIF, AVIF).");
-    newFeatures << i18n("Find duplicates items is now process in parallel using multi-cores.");
-    newFeatures << i18n("New tool to export items to iNaturalist web service.");
-    newFeatures << i18n("New metadata viewer based on ExifTool.");
-    newFeatures << i18n("MacOS package, Windows installer, and AppImage bundle use KF5 5.89 and KAPPS 21.12.0 frameworks.");
-    newFeatures << i18n("AppImage Linux bundle now support <a href=\"https://fcitx-im.org/wiki/Fcitx_5\">Platform Input Context FCITX</a>.");
-    newFeatures << i18n("Improve RTL translations support.");
-    newFeatures << i18n("GUI internationalization and localization updates with more than 50 languages available.");
-    newFeatures << i18n("Add OpenWith contextual menu support under MacOS.");
-    newFeatures << i18n("Integration of Google Summer of Code project 2021 "
-                        "<a href=\"https://community.kde.org/GSoC/2021/StatusReports/PhuocKhanhLE\">Image Quality Sorter</a>.");
-    newFeatures << i18n("New tool to share items on the network with a Motion JPEG stream server.");
-    newFeatures << i18n("Showfoto has a new left sidebar hosting a folder-view to quickly explore images from local file system.");
-    newFeatures << i18n("Update internal RAW engine to last stable Libraw 0.21.1.");
+    newFeatures << i18n("More than 400 user-reports closed on bugzilla.");
+    newFeatures << i18n("Port code to Qt6 framework (code still compatible with Qt5 API).");
+    newFeatures << i18n("Add JPEG-XL, WEBP, and AVIF export settings everywhere.");
+    newFeatures << i18n("Add convert to lossless JPEG-XL, WEBP, and AVIF while importing from camera.");
+    newFeatures << i18n("Add JPEG-XL; WEBP, and AVIF converters in Batch Queue Manager.");
+    newFeatures << i18n("Versionning: add support of JPEG-XL, HEIF, WEBP, and AVIF as lossless image format to store versionned images in editor.");
+    newFeatures << i18n("Usability: add hamburger menu to tool-bar if main menu is hidden.");
+    newFeatures << i18n("Metadata: add new option to write metadata to files with ExifTool backend.");
+    newFeatures << i18n("Metadata: optional write metadata operations to DNG and RAW files are now always delegated to ExifTool Backend.");
+    newFeatures << i18n("Metadata: optimize layout of Metadata Edit plugin for a better usability.");
+    newFeatures << i18n("Metadata: add new options to save and load configuration profiles in Avanced Metadata Settings Pannel.");
+    newFeatures << i18n("Advanced Rename: add increment file counter to sequence numbering from with option [c] or [c,step].");
+    newFeatures << i18n("Advanced Rename: add random text sequence numbering with option [r].");
+    newFeatures << i18n("Advanced Rename: add configurable first character for the unique modifier with {unique:n,c}.");
+    newFeatures << i18n("Advanced Search: add search for items by number of face regions.");
+    newFeatures << i18n("Advanced Search: add search for items without face regions.");
+    newFeatures << i18n("Collections: add support for cross-platform network paths.");
+    newFeatures << i18n("Database: add support for SQLite WAL (Write-Ahead-Logging) mode.");
+    newFeatures << i18n("Add spell-checking support in caption text widget using KF5::Sonnet component.");
+    newFeatures << i18n("Add Spellcheck config panel in Settings/Miscellaneous for digiKam and Showfoto.");
+    newFeatures << i18n("Add online translations support to Alternative Language text editor widget.");
+    newFeatures << i18n("Add Localize config panel in Settings/Miscellaneous for digiKam and Showfoto.");
+    newFeatures << i18n("Add settings to list preferred alternative/translated languages in text edit widget.");
+    newFeatures << i18n("Allow to use Global or Customized Image Quality Sorting settings everywhere.");
+    newFeatures << i18n("Add Icon-View settings to customize Labels visibility over thumbnails.");
+    newFeatures << i18n("Add support for float16 (half float) images in the TIFF Loader.");
+    newFeatures << i18n("Add new maintenance tool to perform <a href=\"https://community.kde.org/GSoc/2022/StatusReports/PhuocKhanhLe\">Aesthetic Detection to classify images using deep learning model</a>.");
+    newFeatures << i18n("Add new tool <a href=\"https://community.kde.org/GSoC/2022/StatusReports/QuocHungTran\">to perform OCR over scanned text</a>.");
+    newFeatures << i18n("Queue Manager: add new tool to assign pick label automatically by parsing image quality.");
+    newFeatures << i18n("Queue Manager: add new tool to assign rating, pick, and color labels in batch.");
+    newFeatures << i18n("Queue Manager: add new tool to assign titles and captions in batch.");
+    newFeatures << i18n("Documentation: <a href=\" https://docs.digikam.org/en/index.html\">Rewrite handbook</a> from DocBook to Sphinx/ReStructuredText framework.");
+    newFeatures << i18n("Update G'MIC-Qt tool to last version 3.2.2 and finalize MacOS port and improve stability of plugin.");
+    newFeatures << i18n("Update internal RAW engine to last Libraw snapshot 20230403.");
     newFeatures << i18n("New RAW features: "
                         "Phase One/Leaf IIQ-S v2 support "
                         "Canon CR3 filmrolls/RawBurst "
