@@ -6,20 +6,11 @@
  * Date        : 2009-02-28
  * Description : batch tool to add visible watermark.
  *
- * Copyright (C) 2009-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010      by Mikkel Baekhoej Christensen <mbc at baekhoej dot dk>
- * Copyright (C) 2017      by Ahmed Fathi <ahmed dot fathi dot abdelmageed at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010      by Mikkel Baekhoej Christensen <mbc at baekhoej dot dk>
+ * SPDX-FileCopyrightText: 2017      by Ahmed Fathi <ahmed dot fathi dot abdelmageed at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -42,8 +33,8 @@
 #include <QStyle>
 #include <QFontComboBox>
 #include <QComboBox>
-#include <QLineEdit>
 #include <QDoubleSpinBox>
+#include <QRandomGenerator>
 
 // KDE includes
 
@@ -60,6 +51,7 @@
 #include "dfontproperties.h"
 #include "metaengine.h"
 #include "dcolorselector.h"
+#include "dtextedit.h"
 
 namespace DigikamBqmWatermarkPlugin
 {
@@ -75,7 +67,9 @@ public:
         TopRight,
         BottomLeft,
         BottomRight,
-        Center
+        Center,
+        TopCenter,
+        BottomCenter
     };
 
     enum WaterMarkPlacementType
@@ -131,7 +125,7 @@ public:
     QRadioButton*    useTextRadioButton;
 
     DFileSelector*   imageFileUrlRequester;
-    QLineEdit*       textEdit;
+    DTextEdit*       textEdit;
 
     QComboBox*       placementPositionComboBox;
     QComboBox*       placementTypeComboBox;
@@ -170,15 +164,16 @@ BatchTool* WaterMark::clone(QObject* const parent) const
 
 void WaterMark::registerSettingsWidget()
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     DVBox* const vbox = new DVBox;
-    vbox->setContentsMargins(QMargins());
+    vbox->setContentsMargins(spacing, spacing, spacing, spacing);
     vbox->setSpacing(spacing);
 
     DHBox* const hbox = new DHBox(vbox);
     hbox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    hbox->setSpacing(10);
+    hbox->setSpacing(spacing);
 
     d->useAbsoluteImageSizeGroupBox                       = new QGroupBox(vbox);
     QVBoxLayout* const useAbsoluteImageSizeGroupBoxLayout = new QVBoxLayout;
@@ -188,7 +183,7 @@ void WaterMark::registerSettingsWidget()
 
     DHBox* const useAbsoluteSizeHBox   = new DHBox();
     useAbsoluteSizeHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    useAbsoluteSizeHBox->setSpacing(10);
+    useAbsoluteSizeHBox->setSpacing(spacing);
     d->useAbsoluteSizeCheckBox         = new QCheckBox(useAbsoluteSizeHBox);
     d->useAbsoluteSizeCheckBox->setWhatsThis(i18n("Check this if you want the watermark to use the given size of "
                                                   "the font or the image without any adjustment to the actual image."));
@@ -199,7 +194,7 @@ void WaterMark::registerSettingsWidget()
     useAbsoluteImageSizeGroupBoxLayout->addWidget(useAbsoluteSizeHBox);
 
     QLabel* const watermarkTypeLabel   = new QLabel(hbox);
-    watermarkTypeLabel->setText(i18n("Watermark type:"));
+    watermarkTypeLabel->setText(i18n("Watermark type: "));
 
     d->useImageRadioButton      = new QRadioButton(hbox);
     d->useImageRadioButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -216,6 +211,8 @@ void WaterMark::registerSettingsWidget()
     useTextLabel->setAlignment(Qt::AlignLeft);
     d->useImageRadioButton->setChecked(true);
 
+    // ---
+
     d->imageSettingsGroupBox                       = new QGroupBox(vbox);
     d->imageSettingsGroupBox->setTitle(i18n("Image settings"));
     QVBoxLayout* const imageSettingsGroupBoxLayout = new QVBoxLayout;
@@ -223,16 +220,16 @@ void WaterMark::registerSettingsWidget()
     imageSettingsGroupBoxLayout->addStretch(1);
     d->imageSettingsGroupBox->setLayout(imageSettingsGroupBoxLayout);
 
-    QLabel* const label      = new QLabel();
-    d->imageFileUrlRequester = new DFileSelector();
+    DHBox* const imageSelectHBox = new DHBox();
+    QLabel* const label          = new QLabel(imageSelectHBox);
+    d->imageFileUrlRequester     = new DFileSelector(imageSelectHBox);
     d->imageFileUrlRequester->lineEdit()->setPlaceholderText(i18n("Click to select watermark image."));
-    label->setText(i18n("Watermark image:"));
-    imageSettingsGroupBoxLayout->addWidget(label);
-    imageSettingsGroupBoxLayout->addWidget(d->imageFileUrlRequester);
+    label->setText(i18n("Watermark image: "));
+    imageSettingsGroupBoxLayout->addWidget(imageSelectHBox);
 
     DHBox* const ignoreWatermarkAspectRatioHBox   = new DHBox();
     ignoreWatermarkAspectRatioHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    ignoreWatermarkAspectRatioHBox->setSpacing(5);
+    ignoreWatermarkAspectRatioHBox->setSpacing(spacing);
 
     d->ignoreWatermarkAspectCheckBox              = new QCheckBox(ignoreWatermarkAspectRatioHBox);
     d->ignoreWatermarkAspectCheckBox->setWhatsThis(i18n("Check this if you want the watermark to ignore its own "
@@ -246,7 +243,7 @@ void WaterMark::registerSettingsWidget()
     DHBox* const addTransparencyToWatermarkImageHBox = new DHBox();
     addTransparencyToWatermarkImageHBox->setContentsMargins(QMargins());
     addTransparencyToWatermarkImageHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    addTransparencyToWatermarkImageHBox->setSpacing(5);
+    addTransparencyToWatermarkImageHBox->setSpacing(spacing);
 
     d->addTransparencyToWatermarkImageCheckBox       = new QCheckBox(addTransparencyToWatermarkImageHBox);
     d->addTransparencyToWatermarkImageCheckBox->setWhatsThis(i18n("Check this if you want watermark to be transparent."));
@@ -256,18 +253,20 @@ void WaterMark::registerSettingsWidget()
     addTransparencyToWatermarkLabel->setText(i18n("Add transparency to watermark image"));
     imageSettingsGroupBoxLayout->addWidget(addTransparencyToWatermarkImageHBox);
 
-    DVBox* const watermarkImageOpacityBox = new DVBox();
+    DHBox* const watermarkImageOpacityBox = new DHBox();
     watermarkImageOpacityBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    watermarkImageOpacityBox->setSpacing(5);
+    watermarkImageOpacityBox->setSpacing(spacing);
 
     QLabel* const opacityLabel            = new QLabel(watermarkImageOpacityBox);
     d->waterMarkOpacityPercent            = new DIntNumInput(watermarkImageOpacityBox);
     d->waterMarkOpacityPercent->setRange(0, 100, 1);
     d->waterMarkOpacityPercent->setDefaultValue(100);
     d->waterMarkOpacityPercent->setWhatsThis(i18n("Opacity of watermark"));
-    opacityLabel->setText(i18n("Opacity (%):"));
+    opacityLabel->setText(i18n("Opacity (%): "));
     imageSettingsGroupBoxLayout->addWidget(watermarkImageOpacityBox);
  
+    // ---
+
     d->textSettingsGroupBox                       = new QGroupBox(vbox);
     d->textSettingsGroupBox->setTitle(i18n("Text settings"));
     QVBoxLayout* const textSettingsGroupBoxLayout = new QVBoxLayout;
@@ -276,10 +275,9 @@ void WaterMark::registerSettingsWidget()
     d->textSettingsGroupBox->setLayout(textSettingsGroupBoxLayout);
 
     QLabel* const textEditLabel = new QLabel(vbox);
-    d->textEdit                 = new QLineEdit(vbox);
-    d->textEdit->setClearButtonEnabled(true);
+    d->textEdit                 = new DTextEdit(vbox);
     d->textEdit->setPlaceholderText(i18n("Enter your watermark string here."));
-    textEditLabel->setText(i18n("Watermark text:"));
+    textEditLabel->setText(i18n("Watermark text: "));
     textSettingsGroupBoxLayout->addWidget(textEditLabel);
     textSettingsGroupBoxLayout->addWidget(d->textEdit);
 
@@ -289,27 +287,27 @@ void WaterMark::registerSettingsWidget()
     d->extendedFontChooserWidget->setWhatsThis(i18n("Choose the font type and style. Size is auto calculated."));
     textSettingsGroupBoxLayout->addWidget(d->extendedFontChooserWidget);
 
-    QLabel* const label3 = new QLabel();
-    d->fontColorButton   = new DColorSelector();
+    DHBox* const fontColorBox = new DHBox();
+    QLabel* const label3 = new QLabel(fontColorBox);
+    d->fontColorButton   = new DColorSelector(fontColorBox);
     d->fontColorButton->setColor(Qt::black);
     d->fontColorButton->setWhatsThis(i18n("Set the font color to use here."));
-    label3->setText(i18n("Font color:"));
-    textSettingsGroupBoxLayout->addWidget(label3);
-    textSettingsGroupBoxLayout->addWidget(d->fontColorButton);
+    label3->setText(i18n("Font color: "));
+    textSettingsGroupBoxLayout->addWidget(fontColorBox);
 
-    QLabel* const textOpacityLabel = new QLabel();
-    textOpacityLabel->setText(i18n("Text opacity:"));
-    d->textOpacity                 = new DIntNumInput();
+    DHBox* const fontOpacityBox    = new DHBox();
+    QLabel* const textOpacityLabel = new QLabel(fontOpacityBox);
+    textOpacityLabel->setText(i18n("Text opacity: "));
+    d->textOpacity                 = new DIntNumInput(fontOpacityBox);
     d->textOpacity->setRange(0, 100, 1);
     d->textOpacity->setDefaultValue(100);
     d->textOpacity->setWhatsThis(i18n("Set the opacity of the watermark text. "
                                       "100 is fully opaque, 0 is fully transparent."));
-    textSettingsGroupBoxLayout->addWidget(textOpacityLabel);
-    textSettingsGroupBoxLayout->addWidget(d->textOpacity);
+    textSettingsGroupBoxLayout->addWidget(fontOpacityBox);
 
     DHBox* const useBackgroundHBox   = new DHBox();
     useBackgroundHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    useBackgroundHBox->setSpacing(5);
+    useBackgroundHBox->setSpacing(spacing);
 
     d->useBackgroundCheckBox         = new QCheckBox(useBackgroundHBox);
     d->useBackgroundCheckBox->setWhatsThis(i18n("Check this if you want a background fill behind the text."));
@@ -317,37 +315,40 @@ void WaterMark::registerSettingsWidget()
     useBackgroundLabel->setText(i18n("Use background"));
     textSettingsGroupBoxLayout->addWidget(useBackgroundHBox);
 
-    QLabel* const backgroundColorLabel = new QLabel();
-    d->backgroundColorButton           = new DColorSelector();
+    DHBox* const useBackgroundColorHBox = new DHBox();
+    QLabel* const backgroundColorLabel  = new QLabel(useBackgroundColorHBox);
+    d->backgroundColorButton            = new DColorSelector(useBackgroundColorHBox);
     d->backgroundColorButton->setColor(QColor(0xCC, 0xCC, 0xCC));
     d->backgroundColorButton->setWhatsThis(i18n("Choose the color of the watermark background."));
-    backgroundColorLabel ->setText(i18n("Background color:"));
-    textSettingsGroupBoxLayout->addWidget(backgroundColorLabel);
-    textSettingsGroupBoxLayout->addWidget(d->backgroundColorButton);
+    backgroundColorLabel ->setText(i18n("Background color: "));
+    textSettingsGroupBoxLayout->addWidget(useBackgroundColorHBox);
 
-    QLabel* const backgroundOpacityLabel = new QLabel();
-    backgroundOpacityLabel->setText(i18n("Background opacity:"));
-    d->backgroundOpacity                 = new DIntNumInput();
+    DHBox* const useBackgroundOpacityHBox  = new DHBox();
+    QLabel* const backgroundOpacityLabel   = new QLabel(useBackgroundOpacityHBox);
+    backgroundOpacityLabel->setText(i18n("Background opacity: "));
+    d->backgroundOpacity                   = new DIntNumInput(useBackgroundOpacityHBox);
     d->backgroundOpacity->setRange(0, 100, 1);
     d->backgroundOpacity->setDefaultValue(100);
     d->backgroundOpacity->setWhatsThis(i18n("Set the opacity of the watermark background. "
                                             "100 is fully opaque, 0 is fully transparent."));
-    textSettingsGroupBoxLayout->addWidget(backgroundOpacityLabel);
-    textSettingsGroupBoxLayout->addWidget(d->backgroundOpacity);
+    textSettingsGroupBoxLayout->addWidget(useBackgroundOpacityHBox);
 
     d->imageSettingsGroupBox->setVisible(true);
     d->textSettingsGroupBox->setVisible(false);
 
-    QLabel* const placementTypeLabel = new QLabel(vbox);
-    d->placementTypeComboBox         = new QComboBox(vbox);
+    // ---
+
+    DHBox* const placementTypeHBox = new DHBox(vbox);
+    QLabel* const placementTypeLabel = new QLabel(placementTypeHBox);
+    d->placementTypeComboBox         = new QComboBox(placementTypeHBox);
     d->placementTypeComboBox->insertItem(Private::SpecifiedLocation,    i18n("Specific Location"));
     d->placementTypeComboBox->insertItem(Private::SystematicRepetition, i18n("Systematic Repetition"));
     d->placementTypeComboBox->insertItem(Private::RandomRepetition,     i18n("Random Repetition"));
-    placementTypeLabel->setText(i18n("Placement Type:"));
+    placementTypeLabel->setText(i18n("Placement Type: "));
 
     DHBox* const placementHBox = new DHBox(vbox);
     placementHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    placementHBox->setSpacing(5);
+    placementHBox->setSpacing(spacing);
 
     QLabel* const spaceLabel   = new QLabel(placementHBox);
     d->denseRepetitionCheckBox = new QCheckBox(placementHBox);
@@ -361,7 +362,7 @@ void WaterMark::registerSettingsWidget()
 
     DHBox* const randomizeHBox          = new DHBox(vbox);
     randomizeHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    randomizeHBox->setSpacing(5);
+    randomizeHBox->setSpacing(spacing);
 
     QLabel* const spaceLabel2           = new QLabel(randomizeHBox);
     d->randomizeRotationCheckBox        = new QCheckBox(randomizeHBox);
@@ -376,7 +377,7 @@ void WaterMark::registerSettingsWidget()
 
     DHBox* const sparsityHBox         = new DHBox(vbox);
     sparsityHBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    sparsityHBox->setSpacing(5);
+    sparsityHBox->setSpacing(spacing);
 
     QLabel* const sparsityFactorLabel = new QLabel(sparsityHBox);
     d->sparsityFactorSpinBox          = new QDoubleSpinBox(sparsityHBox);
@@ -387,45 +388,53 @@ void WaterMark::registerSettingsWidget()
                                            "repetition. The higher the value the sparser the watermarks get. "
                                            "Use floating point values, typically between 1.0 and 3.0. It can "
                                            "also be less than 1.0"));
-    sparsityFactorLabel->setText(i18n("Sparsity Factor:"));
+    sparsityFactorLabel->setText(i18n("Sparsity Factor: "));
 
-    QLabel* const label4         = new QLabel(vbox);
-    d->placementPositionComboBox = new QComboBox(vbox);
-    d->placementPositionComboBox->insertItem(Private::TopLeft,     i18nc("@item: placement position", "Top left"));
-    d->placementPositionComboBox->insertItem(Private::TopRight,    i18nc("@item: placement position", "Top right"));
-    d->placementPositionComboBox->insertItem(Private::BottomLeft,  i18nc("@item: placement position", "Bottom left"));
-    d->placementPositionComboBox->insertItem(Private::BottomRight, i18nc("@item: placement position", "Bottom right"));
-    d->placementPositionComboBox->insertItem(Private::Center,      i18nc("@item: placement position", "Center"));
-    label4->setText(i18n("Placement Position:"));
+    DHBox* const placementPositionHBox = new DHBox(vbox);
+    QLabel* const label4         = new QLabel(placementPositionHBox);
+    d->placementPositionComboBox = new QComboBox(placementPositionHBox);
+    d->placementPositionComboBox->insertItem(Private::TopLeft,      i18nc("@item: placement position", "Top left"));
+    d->placementPositionComboBox->insertItem(Private::TopRight,     i18nc("@item: placement position", "Top right"));
+    d->placementPositionComboBox->insertItem(Private::BottomLeft,   i18nc("@item: placement position", "Bottom left"));
+    d->placementPositionComboBox->insertItem(Private::BottomRight,  i18nc("@item: placement position", "Bottom right"));
+    d->placementPositionComboBox->insertItem(Private::Center,       i18nc("@item: placement position", "Center"));
+    d->placementPositionComboBox->insertItem(Private::TopCenter,    i18nc("@item: placement position", "Top center"));
+    d->placementPositionComboBox->insertItem(Private::BottomCenter, i18nc("@item: placement position", "Bottom center"));
 
-    QLabel* const labelRotation  = new QLabel(vbox);
-    d->rotationComboBox          = new QComboBox(vbox);
+    label4->setText(i18n("Placement Position: "));
+
+    DHBox* const placementRotationHBox = new DHBox(vbox);
+    QLabel* const labelRotation  = new QLabel(placementRotationHBox);
+    d->rotationComboBox          = new QComboBox(placementRotationHBox);
     d->rotationComboBox->insertItem(0, i18n("0 degrees"));
     d->rotationComboBox->insertItem(1, i18n("90 degrees CW"));
     d->rotationComboBox->insertItem(2, i18n("180 degrees"));
     d->rotationComboBox->insertItem(3, i18n("270 degrees CW"));
-    labelRotation->setText(i18n("Rotation:"));
+    labelRotation->setText(i18n("Rotation: "));
 
-    QLabel* const label5    = new QLabel(vbox);
-    d->waterMarkSizePercent = new DIntNumInput(vbox);
+    DHBox* const placementSizeHBox = new DHBox(vbox);
+    QLabel* const label5    = new QLabel(placementSizeHBox);
+    d->waterMarkSizePercent = new DIntNumInput(placementSizeHBox);
     d->waterMarkSizePercent->setRange(0, 100, 1);
     d->waterMarkSizePercent->setDefaultValue(30);
     d->waterMarkSizePercent->setWhatsThis(i18n("Size of watermark, as a percentage of the marked image."));
-    label5->setText(i18n("Size (%):"));
+    label5->setText(i18n("Size (%): "));
 
-    QLabel* const label6 = new QLabel(vbox);
-    d->xMarginInput      = new DIntNumInput(vbox);
+    DHBox* const placementXMarginHBox = new DHBox(vbox);
+    QLabel* const label6 = new QLabel(placementXMarginHBox);
+    d->xMarginInput      = new DIntNumInput(placementXMarginHBox);
     d->xMarginInput->setRange(0, 100, 1);
     d->xMarginInput->setDefaultValue(2);
     d->xMarginInput->setWhatsThis(i18n("Margin from edge in X direction, as a percentage of the marked image."));
-    label6->setText(i18n("X margin (%):"));
+    label6->setText(i18n("X margin (%): "));
 
-    QLabel* const label7 = new QLabel(vbox);
-    d->yMarginInput      = new DIntNumInput(vbox);
+    DHBox* const placementYMarginHBox = new DHBox(vbox);
+    QLabel* const label7 = new QLabel(placementYMarginHBox);
+    d->yMarginInput      = new DIntNumInput(placementYMarginHBox);
     d->yMarginInput->setRange(0, 100, 1);
     d->yMarginInput->setDefaultValue(2);
     d->yMarginInput->setWhatsThis(i18n("Margin from edge in Y direction, as a percentage of the marked image."));
-    label7->setText(i18n("Y margin (%):"));
+    label7->setText(i18n("Y margin (%): "));
 
     QLabel* const space = new QLabel(vbox);
     vbox->setStretchFactor(space, 10);
@@ -449,7 +458,7 @@ void WaterMark::registerSettingsWidget()
     connect(d->fontColorButton, SIGNAL(signalColorSelected(QColor)),
             this, SLOT(slotSettingsChanged()));
 
-    connect(d->textEdit, SIGNAL(textChanged(QString)),
+    connect(d->textEdit, SIGNAL(textChanged()),
             this, SLOT(slotSettingsChanged()));
 
     connect(d->textOpacity, SIGNAL(valueChanged(int)),
@@ -501,7 +510,7 @@ void WaterMark::registerSettingsWidget()
             this, SLOT(slotSettingsChanged()));
 
     connect(d->waterMarkOpacityPercent, SIGNAL(valueChanged(int)),
-	    this, SLOT(slotSettingsChanged()));
+            this, SLOT(slotSettingsChanged()));
 
     BatchTool::registerSettingsWidget();
 }
@@ -539,7 +548,14 @@ void WaterMark::slotAssignSettings2Widget()
     d->useImageRadioButton->setChecked(settings()[QLatin1String("Use image")].toBool());
     d->useTextRadioButton->setChecked(!settings()[QLatin1String("Use image")].toBool());
     d->imageFileUrlRequester->setFileDlgPath(settings()[QLatin1String("Watermark image")].toString());
-    d->textEdit->setText(settings()[QLatin1String("Text")].toString());
+
+    QString txt       = settings()[QLatin1String("Text")].toString();
+
+    if (d->textEdit->text() != txt)
+    {
+        d->textEdit->setText(txt);
+    }
+
     d->extendedFontChooserWidget->setFont(qvariant_cast<QFont>(settings()[QLatin1String("Font")]));
     d->fontColorButton->setColor(settings()[QLatin1String("Color")].toString());
     d->textOpacity->setValue(settings()[QLatin1String("Text opacity")].toInt());
@@ -754,6 +770,8 @@ bool WaterMark::toolOperations()
             }
 
             case Private::Center:
+            case Private::TopCenter:
+            case Private::BottomCenter:
             {
                 alignMode = Qt::AlignCenter;
                 break;
@@ -880,6 +898,30 @@ bool WaterMark::toolOperations()
                 break;
             }
 
+            case Private::TopCenter:
+            {
+                if ((rotationAngle == DImg::ANGLE::ROT90) || (rotationAngle == DImg::ANGLE::ROT270))
+                {
+                    xAdditionalValue += (watermarkRect.width() - watermarkRect.height()) / 2;
+                }
+
+                watermarkRect.moveCenter(QPoint((int)(image().width()  / 2 + xAdditionalValue), marginH));
+                break;
+            }
+
+            case Private::BottomCenter:
+            {
+                if ((rotationAngle == DImg::ANGLE::ROT90) || (rotationAngle == DImg::ANGLE::ROT270))
+                {
+                    xAdditionalValue += (watermarkRect.width() - watermarkRect.height()) / 2;
+                    yAdditionalValue += watermarkRect.height() - watermarkRect.width();
+                }
+
+                watermarkRect.moveCenter(QPoint((int)(image().width()  / 2 + xAdditionalValue),
+                                                image().height() + yAdditionalValue - 1 - marginH));
+                break;
+            }
+
             default:    // BottomRight
             {
                 if ((rotationAngle == DImg::ANGLE::ROT90) || (rotationAngle == DImg::ANGLE::ROT270))
@@ -928,7 +970,7 @@ bool WaterMark::toolOperations()
             widthRatio  = (widthRatio > heightRatio) ? widthRatio : heightRatio;
             heightRatio = widthRatio;
 
-            qsrand(static_cast<quint64>(QTime::currentTime().msecsSinceStartOfDay()));
+            auto randomGenerator = QRandomGenerator::global();
 
             for (uint i = 0 ; i < image().width() ; i += spacingFactor * widthRatio * image().width())
             {
@@ -936,11 +978,11 @@ bool WaterMark::toolOperations()
                 {
                     int number = (denseRepetition) ? 2 : 3;
 
-                    if (qrand() % number == 0)
+                    if (randomGenerator->bounded(number) == 0)
                     {
                         if (randomizeRotation)
                         {
-                            int x = qrand() % 4;
+                            int x = randomGenerator->bounded(4);
                             watermarkImage.rotate((DImg::ANGLE)x);
                         }
 
