@@ -6,23 +6,18 @@
  * Date        : 2019-09-26
  * Description : A HEIF IO file for DImg framework - load operations
  *
- * Copyright (C) 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #include "dimgheifloader.h"
 
+// C++ includes
+
+#include <cstdint>
+
 // Qt includes
 
 #include <QFile>
@@ -43,7 +38,7 @@
 namespace Digikam
 {
 
-static int64_t heifQIODeviceDImgGetPosition(void* userdata)
+static int64_t heifQIODeviceDImgGetPosition(void* userdata)                                     // krazy:exclude=typedefs
 {
     QFile* const file = static_cast<QFile*>(userdata);
 
@@ -61,17 +56,17 @@ static int heifQIODeviceDImgRead(void* data, size_t size, void* userdata)
 
     qint64 bytes = file->read((char*)data, size);
 
-    return (int)((file->error() != QFileDevice::NoError) || bytes != (qint64)size);
+    return (int)((file->error() != QFileDevice::NoError) || (bytes != (qint64)size));
 }
 
-static int heifQIODeviceDImgSeek(int64_t position, void* userdata)
+static int heifQIODeviceDImgSeek(int64_t position, void* userdata)                              // krazy:exclude=typedefs
 {
     QFile* const file = static_cast<QFile*>(userdata);
 
-    return (int)file->seek(position);
+    return (int)!file->seek(position);
 }
 
-static heif_reader_grow_status heifQIODeviceDImgWait(int64_t target_size, void* userdata)
+static heif_reader_grow_status heifQIODeviceDImgWait(int64_t target_size, void* userdata)       // krazy:exclude=typedefs
 {
     QFile* const file = static_cast<QFile*>(userdata);
 
@@ -99,7 +94,7 @@ bool DImgHEIFLoader::load(const QString& filePath, DImgLoaderObserver* const obs
         return false;
     }
 
-    const int headerLen = 12;
+    const qint64 headerLen = 12;
 
     QByteArray header(headerLen, '\0');
 
@@ -132,6 +127,12 @@ bool DImgHEIFLoader::load(const QString& filePath, DImgLoaderObserver* const obs
     // -------------------------------------------------------------------
     // Initialize HEIF API.
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+    heif_init(nullptr);
+
+#endif
+
     heif_item_id primary_image_id;
 
     struct heif_context* const heif_context = heif_context_alloc();
@@ -154,6 +155,12 @@ bool DImgHEIFLoader::load(const QString& filePath, DImgLoaderObserver* const obs
         heif_context_free(heif_context);
         loadingFailed();
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
@@ -165,12 +172,24 @@ bool DImgHEIFLoader::load(const QString& filePath, DImgLoaderObserver* const obs
         heif_context_free(heif_context);
         loadingFailed();
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+        heif_deinit();
+
+#endif
+
         return false;
     }
 
     bool ret = readHEICImageByID(heif_context, primary_image_id);
     heif_context_free(heif_context);
 
+#if LIBHEIF_NUMERIC_VERSION >= 0x010d0000
+
+    heif_deinit();
+
+#endif
+
     return ret;
 }
 
