@@ -6,17 +6,9 @@
  * Date        : 2007-09-09
  * Description : scanner dialog
  *
- * Copyright (C) 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,10 +31,6 @@
 
 #include <klocalizedstring.h>
 
-// LibKSane includes
-
-#include <ksanewidget.h>
-
 // Local includes
 
 #include "digikam_debug.h"
@@ -73,7 +61,7 @@ ScanDialog::ScanDialog(KSaneWidget* const saneWdg, QWidget* const parent)
     : DPluginDialog(parent, QLatin1String("Scan Tool Dialog")),
       d            (new Private)
 {
-    setWindowTitle(i18n("Scan Image"));
+    setWindowTitle(i18nc("@title:window", "Scan Image"));
     setModal(false);
 
     d->saneWidget          = saneWdg;
@@ -91,7 +79,12 @@ ScanDialog::ScanDialog(KSaneWidget* const saneWdg, QWidget* const parent)
 
     // ------------------------------------------------------------------------
 
-#if KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+    connect(d->saneWidget, &KSaneWidget::scannedImageReady,
+            this, &ScanDialog::slotSaveImage);
+
+#elif KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
 
     connect(d->saneWidget, &KSaneWidget::imageReady,
             this, &ScanDialog::slotSaveImage);
@@ -133,14 +126,18 @@ void ScanDialog::slotDialogFinished()
     d->saneWidget->closeDevice();
 }
 
-#if KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+void ScanDialog::slotSaveImage(const QImage& image_data)
+
+#elif KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
 
 // cppcheck-suppress constParameter
 void ScanDialog::slotSaveImage(QByteArray& ksane_data, int width, int height, int bytes_per_line, int ksaneformat)
 
 #else
 
-void ScanDialog::slotSaveImage(const QImage &image_data)
+void ScanDialog::slotSaveImage(const QImage& image_data)
 
 #endif
 
@@ -148,7 +145,7 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
     QStringList writableMimetypes;
     QList<QByteArray> supported = QImageWriter::supportedMimeTypes();
 
-    foreach (const QByteArray& mimeType, supported)
+    Q_FOREACH (const QByteArray& mimeType, supported)
     {
         writableMimetypes.append(QLatin1String(mimeType));
     }
@@ -167,7 +164,7 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
     QLatin1String defaultMimeType("image/png");
     QLatin1String defaultFileName("image.png");
 
-    QPointer<DFileDialog> imageFileSaveDialog = new DFileDialog(nullptr, i18n("New Image File Name"), d->targetDir);
+    QPointer<DFileDialog> imageFileSaveDialog = new DFileDialog(nullptr, i18nc("@title:window", "New Image File Name"), d->targetDir);
     imageFileSaveDialog->setAcceptMode(QFileDialog::AcceptSave);
     imageFileSaveDialog->setMimeTypeFilters(writableMimetypes);
     imageFileSaveDialog->selectMimeTypeFilter(defaultMimeType);
@@ -177,7 +174,7 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
 
     imageFileSaveDialog->exec();
 
-    if (!imageFileSaveDialog || !imageFileSaveDialog->hasAcceptedUrls())
+    if (!imageFileSaveDialog->hasAcceptedUrls())
     {
         delete imageFileSaveDialog;
 
@@ -215,9 +212,11 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
 
         if (!imgExtList.contains(format.toLatin1()) && !imgExtList.contains(format.toLower().toLatin1()))
         {
-            QMessageBox::critical(nullptr, i18n("Unsupported Format"),
+            QMessageBox::critical(nullptr, i18nc("@title:window", "Unsupported Format"),
                                   i18n("The target image file format \"%1\" is unsupported.", format));
+
             qCWarning(DIGIKAM_DPLUGIN_GENERIC_LOG) << "target image file format " << format << " is unsupported!";
+
             delete imageFileSaveDialog;
 
             return;
@@ -226,11 +225,13 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
 
     if (!newURL.isValid())
     {
-        QMessageBox::critical(nullptr, i18n("Cannot Save File"),
+        QMessageBox::critical(nullptr, i18nc("@title:window", "Cannot Save File"),
                               i18n("Failed to save file\n\"%1\" to\n\"%2\".",
                               newURL.fileName(),
                               QDir::toNativeSeparators(newURL.toLocalFile().section(QLatin1Char('/'), -2, -2))));
+
         qCWarning(DIGIKAM_DPLUGIN_GENERIC_LOG) << "target URL is not valid !";
+
         delete imageFileSaveDialog;
 
         return;
@@ -240,7 +241,7 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
 
     if (fi.exists())
     {
-        int result = QMessageBox::warning(nullptr, i18n("Overwrite File?"),
+        int result = QMessageBox::warning(nullptr, i18nc("@title:window", "Overwrite File?"),
                                           i18n("A file named \"%1\" already "
                                                "exists. Are you sure you want "
                                                "to overwrite it?",
@@ -269,7 +270,12 @@ void ScanDialog::slotSaveImage(const QImage &image_data)
     connect(thread, &SaveImgThread::signalComplete,
             this, &ScanDialog::slotThreadDone);
 
-#if KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+    thread->setImageData(image_data);
+    thread->setScannerModel(d->saneWidget->deviceVendor(), d->saneWidget->deviceModel());
+
+#elif KSANE_VERSION < QT_VERSION_CHECK(21,8,0)
 
     thread->setImageData(ksane_data, width, height, bytes_per_line, ksaneformat);
     thread->setScannerModel(d->saneWidget->make(), d->saneWidget->model());
@@ -295,7 +301,7 @@ void ScanDialog::slotThreadDone(const QUrl& url, bool success)
 {
     if (!success)
     {
-        QMessageBox::critical(nullptr, i18n("File Not Saved"), i18n("Cannot save \"%1\" file", url.fileName()));
+        QMessageBox::critical(nullptr, i18nc("@title:window", "File Not Saved"), i18n("Cannot save \"%1\" file", url.fileName()));
     }
 
     d->progress->setProgressText(QString());
