@@ -6,17 +6,9 @@
  * Date        : 2007-10-24
  * Description : XMP origin settings page.
  *
- * Copyright (C) 2007-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -109,10 +101,10 @@ public:
 };
 
 XMPOrigin::XMPOrigin(QWidget* const parent)
-    : QWidget(parent),
-      d      (new Private)
+    : MetadataEditPage(parent),
+      d               (new Private)
 {
-    QGridLayout* const grid = new QGridLayout(this);
+    QGridLayout* const grid = new QGridLayout(widget());
 
     QString dateTimeFormat  = QLocale().dateTimeFormat(QLocale::ShortFormat);
 
@@ -192,28 +184,30 @@ XMPOrigin::XMPOrigin(QWidget* const parent)
     d->cityCheck = new QCheckBox(i18n("City:"), this);
     d->cityEdit  = new QLineEdit(this);
     d->cityEdit->setClearButtonEnabled(true);
-    d->cityEdit->setWhatsThis(i18n("Set here the content's city of origin."));
+    d->cityEdit->setPlaceholderText(i18n("Set here the content's city of origin."));
 
     // --------------------------------------------------------
 
     d->sublocationCheck = new QCheckBox(i18n("Sublocation:"), this);
     d->sublocationEdit  = new QLineEdit(this);
     d->sublocationEdit->setClearButtonEnabled(true);
-    d->sublocationEdit->setWhatsThis(i18n("Set here the content's location within the city."));
+    d->sublocationEdit->setPlaceholderText(i18n("Set here the content's location within the city."));
 
     // --------------------------------------------------------
 
     d->provinceCheck = new QCheckBox(i18n("State/Province:"), this);
     d->provinceEdit  = new QLineEdit(this);
     d->provinceEdit->setClearButtonEnabled(true);
-    d->provinceEdit->setWhatsThis(i18n("Set here the content's Province or State of origin."));
+    d->provinceEdit->setPlaceholderText(i18n("Set here the content's Province or State of origin."));
 
     // --------------------------------------------------------
 
     d->countryCheck = new MetadataCheckBox(i18n("Country:"), this);
     d->countryCB    = new CountrySelector(this);
     d->countryCB->setWhatsThis(i18n("Select here country name of content origin."));
+
     // Remove 2 last items for the list (separator + Unknown item)
+
     d->countryCB->removeItem(d->countryCB->count()-1);
     d->countryCB->removeItem(d->countryCB->count()-1);
 
@@ -244,8 +238,12 @@ XMPOrigin::XMPOrigin(QWidget* const parent)
     grid->addWidget(d->countryCB,                          12, 1, 1, 5);
     grid->setColumnStretch(4, 10);
     grid->setRowStretch(13, 10);
-    grid->setContentsMargins(QMargins());
-    grid->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+
+    int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+
+    grid->setContentsMargins(spacing, spacing, spacing, spacing);
+    grid->setSpacing(spacing);
 
     // --------------------------------------------------------
 
