@@ -6,18 +6,10 @@
  * Date        : 2008-09-14
  * Description : a presentation tool.
  *
- * Copyright (C) 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
- * Copyright (C) 2012-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -37,6 +29,7 @@
 #include "presentation_mainpage.h"
 #include "presentationcontainer.h"
 #include "digikam_debug.h"
+#include "digikam_globals.h"
 #include "dfiledialog.h"
 
 using namespace Digikam;
@@ -50,7 +43,7 @@ SoundtrackPreview::SoundtrackPreview(QWidget* const parent,
     : QDialog(parent)
 {
     setModal(true);
-    setWindowTitle(i18n("Soundtrack preview"));
+    setWindowTitle(i18nc("@title:window", "Soundtrack Preview"));
 
     m_playbackWidget                  = new PresentationAudioWidget(this, urls, sharedData);
     QDialogButtonBox* const buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
@@ -366,7 +359,7 @@ void PresentationAudioPage::slotAddDropItems(const QList<QUrl>& filesUrl)
 void PresentationAudioPage::slotSoundFilesButtonAdd()
 {
     QPointer<DFileDialog> dlg = new DFileDialog(this,
-                                                i18n("Select sound files"),
+                                                i18nc("@title:window", "Select Sound Files"),
                                                 d->sharedData->soundtrackPath.adjusted(QUrl::RemoveFilename).toLocalFile());
 
     QStringList atm;
@@ -377,8 +370,9 @@ void PresentationAudioPage::slotSoundFilesButtonAdd()
     dlg->setMimeTypeFilters(atm);
     dlg->setAcceptMode(QFileDialog::AcceptOpen);
     dlg->setFileMode(QFileDialog::ExistingFiles);
+    dlg->exec();
 
-    if (dlg->exec() == QDialog::Accepted)
+    if (dlg->hasAcceptedUrls())
     {
         addItems(dlg->selectedUrls());
         updateFileList();
@@ -492,12 +486,13 @@ void PresentationAudioPage::slotSoundFilesButtonDown()
 
 void PresentationAudioPage::slotSoundFilesButtonLoad()
 {
-    QPointer<DFileDialog> dlg = new DFileDialog(this, i18n("Load playlist"),
+    QPointer<DFileDialog> dlg = new DFileDialog(this, i18nc("@title:window", "Load Playlist"),
                                                 QString(), i18n("Playlist (*.m3u)"));
     dlg->setAcceptMode(QFileDialog::AcceptOpen);
     dlg->setFileMode(QFileDialog::ExistingFile);
+    dlg->exec();
 
-    if (dlg->exec() != QDialog::Accepted)
+    if (!dlg->hasAcceptedUrls())
     {
         delete dlg;
 
@@ -550,12 +545,13 @@ void PresentationAudioPage::slotSoundFilesButtonLoad()
 
 void PresentationAudioPage::slotSoundFilesButtonSave()
 {
-    QPointer<DFileDialog> dlg = new DFileDialog(this, i18n("Save playlist"),
+    QPointer<DFileDialog> dlg = new DFileDialog(this, i18nc("@title:window", "Save Playlist"),
                                                 QString(), i18n("Playlist (*.m3u)"));
     dlg->setAcceptMode(QFileDialog::AcceptSave);
     dlg->setFileMode(QFileDialog::AnyFile);
+    dlg->exec();
 
-    if (dlg->exec() != QDialog::Accepted)
+    if (!dlg->hasAcceptedUrls())
     {
         delete dlg;
 
@@ -579,7 +575,7 @@ void PresentationAudioPage::slotSoundFilesButtonSave()
 
                 if (fUrl.isValid() && fUrl.isLocalFile())
                 {
-                    out << fUrl.toLocalFile() << endl;
+                    out << fUrl.toLocalFile() << QT_ENDL;
                 }
             }
 
