@@ -6,17 +6,9 @@
  * Date        : 2021-03-20
  * Description : a tool to export images to iNaturalist web service
  *
- * Copyright (C) 2021      by Joerg Lohse <joergmlpts at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2022 by Joerg Lohse <joergmlpts at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -32,7 +24,6 @@
 #include <QMessageBox>
 #include <QApplication>
 #include <QProgressDialog>
-#include <QNetworkAccessManager>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
@@ -51,6 +42,7 @@
 #include "digikam_version.h"
 #include "previewloadthread.h"
 #include "inatbrowserdlg.h"
+#include "networkmanager.h"
 
 // OAuth2 library includes
 
@@ -247,15 +239,17 @@ public:
                                const QByteArray& data) const = 0;
 
     // Has operation timed out?
+
     bool isTimeout() const
     {
-        return durationMilliSecs() > 1000 * RESPONSE_TIMEOUT_SECS;
+        return (durationMilliSecs() > 1000 * RESPONSE_TIMEOUT_SECS);
     }
 
     // How long did it take?
+
     qint64 durationMilliSecs() const
     {
-        return QDateTime::currentMSecsSinceEpoch() - m_startTime;
+        return (QDateTime::currentMSecsSinceEpoch() - m_startTime);
     }
 
 private:
@@ -296,12 +290,6 @@ public:
         apiToken        = QString();
     }
 
-    ~Private()
-    {
-        delete netMngr;
-        delete store;
-    }
-
     QWidget*                          parent;
     QNetworkAccessManager*            netMngr;
     QTimer*                           timer;
@@ -341,12 +329,14 @@ INatTalker::INatTalker(QWidget* const parent, const QString& serviceName,
     d->iface           = iface;
     m_authProgressDlg  = nullptr;
 
-    d->netMngr         = new QNetworkAccessManager(this);
+    d->netMngr         = NetworkManager::instance()->getNetworkManager(this);
     d->timer           = new QTimer(this);
 
     connect(d->netMngr, SIGNAL(finished(QNetworkReply*)),
             this, SLOT(slotFinished(QNetworkReply*)));
-    connect(d->timer, SIGNAL(timeout()), this, SLOT(slotTimeout()));
+
+    connect(d->timer, SIGNAL(timeout()),
+            this, SLOT(slotTimeout()));
 
     d->settings = WSToolUtils::getOauthSettings(this);
     d->store    = new O0SettingsStore(d->settings,
@@ -404,7 +394,7 @@ bool INatTalker::restoreApiToken(const QString& username,
         }
     }
 
-    bool valid = emitSignal && apiTokenExpiresIn() > 0;
+    bool valid = (emitSignal && (apiTokenExpiresIn() > 0));
 
     if (valid)
     {
@@ -450,7 +440,7 @@ int INatTalker::apiTokenExpiresIn() const
 }
 
 /**
- * We received an api token from a web brower login.
+ * We received an api token from a web browser login.
  */
 void INatTalker::slotApiToken(const QString& apiToken,
                               const QList<QNetworkCookie>& cookies)
@@ -459,13 +449,14 @@ void INatTalker::slotApiToken(const QString& apiToken,
 
     if (apiToken.isEmpty())
     {
-        emit signalLinkingFailed(QLatin1String("no api token"));
+        Q_EMIT signalLinkingFailed(QLatin1String("no api token"));
         return;
     }
     else
     {
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "API token received; "
                                             "querying user info.";
+
         d->apiTokenExpires = (uint)(QDateTime::currentMSecsSinceEpoch() / 1000 +
                                     INAT_API_TOKEN_EXPIRATION);
         userInfo(cookies);
@@ -489,10 +480,10 @@ public:
     void reportError(INatTalker& talker, QNetworkReply::NetworkError,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "users/me error" <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "users/me error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
 
-        emit talker.signalLinkingFailed(QLatin1String("user-info request "
+        Q_EMIT talker.signalLinkingFailed(QLatin1String("user-info request "
                                                       "failed"));
     }
 
@@ -505,7 +496,7 @@ public:
         {
             QJsonObject result = json[RESULTS].toArray()[0].toObject();
             QString username(result[LOGIN].toString());
-            emit talker.signalLinkingSucceeded(username,
+            Q_EMIT talker.signalLinkingSucceeded(username,
                                                result[NAME].toString(),
                                                QUrl(result[ICON].toString()));
             talker.d->store->setGroupKey(talker.d->serviceName + username);
@@ -543,7 +534,7 @@ public:
         }
         else
         {
-            emit talker.signalLinkingFailed(QLatin1String("user-info request "
+            Q_EMIT talker.signalLinkingFailed(QLatin1String("user-info request "
                                             "failed"));
         }
 
@@ -553,7 +544,7 @@ public:
             talker.m_authProgressDlg->hide();
         }
 
-        emit talker.signalBusy(false);
+        Q_EMIT talker.signalBusy(false);
     }
 
 private:
@@ -568,7 +559,7 @@ void INatTalker::userInfo(const QList<QNetworkCookie>& cookies)
         return;
     }
 
-    emit signalBusy(true);
+    Q_EMIT signalBusy(true);
 
     if (m_authProgressDlg)
     {
@@ -608,13 +599,15 @@ public:
     void reportError(INatTalker& talker, QNetworkReply::NetworkError code,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url" << m_url << "error" <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
-        if (networkErrorRetry(code) && m_retries < MAX_RETRIES)
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url" << m_url << "error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
+
+        if      (networkErrorRetry(code) && (m_retries < MAX_RETRIES))
         {
-            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Attempting to load" << m_url <<
-                "again, retry" << m_retries+1 << "of" << MAX_RETRIES;
-            talker.loadUrl(m_url, m_retries+1);
+            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Attempting to load" << m_url << "again, retry"
+                                             << m_retries + 1 << "of" << MAX_RETRIES;
+
+            talker.loadUrl(m_url, m_retries + 1);
         }
         else if (talker.d->cachedLoadUrls.contains(m_url))
         {
@@ -625,11 +618,12 @@ public:
     void parseResponse(INatTalker& talker,
                        const QByteArray& data) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url" << m_url <<
-            "loaded in" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url" << m_url << "loaded in"
+                                         << durationMilliSecs() << "msecs.";
+
         talker.d->cachedLoadUrls.insert(m_url, data);
 
-        emit talker.signalLoadUrlSucceeded(m_url, data);
+        Q_EMIT talker.signalLoadUrlSucceeded(m_url, data);
     }
 
 private:
@@ -656,22 +650,25 @@ void INatTalker::loadUrl(const QUrl& imgUrl, int retries)
     if (d->cachedLoadUrls.contains(imgUrl))
     {
         const QByteArray& result = d->cachedLoadUrls.value(imgUrl);
+
         if (!result.isEmpty())
         {
-            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url" << imgUrl <<
-                "found in cache.";
-            emit signalLoadUrlSucceeded(imgUrl, result);
+            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url" << imgUrl
+                                             << "found in cache.";
+
+            Q_EMIT signalLoadUrlSucceeded(imgUrl, result);
         }
         else
         {
-            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url load of" << imgUrl <<
-                "already in progress; ignoring request.";
+            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Url load of" << imgUrl
+                                             << "already in progress; ignoring request.";
         }
 
         return;
     }
 
     // empty cache entry means load in progress
+
     d->cachedLoadUrls.insert(imgUrl, QByteArray());
 
     QNetworkRequest netRequest(imgUrl);
@@ -696,9 +693,9 @@ public:
     void reportError(INatTalker&, QNetworkReply::NetworkError,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Taxon auto-completion" <<
-            m_partialName << "error" << errorString << "after" <<
-            durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Taxon auto-completion" << m_partialName
+                                         << "error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
     }
 
     void parseResponse(INatTalker& talker,
@@ -719,7 +716,7 @@ public:
             QPair<QString, QList<Taxon> > result(m_partialName, taxa);
             talker.d->cachedAutoCompletions.insert(m_partialName, result);
 
-            emit talker.signalTaxonAutoCompletions(result);
+            Q_EMIT talker.signalTaxonAutoCompletions(result);
         }
     }
 
@@ -742,7 +739,7 @@ void INatTalker::taxonAutoCompletions(const QString& partialName)
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Taxon auto-completions for"
                                          <<  partialName << "found in cache.";
 
-        emit signalTaxonAutoCompletions(d->cachedAutoCompletions.
+        Q_EMIT signalTaxonAutoCompletions(d->cachedAutoCompletions.
                                         value(partialName));
         return;
     }
@@ -778,6 +775,8 @@ public:
           m_longitude(longitude),
           m_query    (query)
     {
+        Q_UNUSED(m_latitude);
+        Q_UNUSED(m_longitude);
     }
 
     void parseResponse(INatTalker& talker,
@@ -787,8 +786,9 @@ public:
 
         if (json.contains(RESULTS))
         {
-            static const QString BBOX_AREA = QLatin1String("bbox_area");
-            QJsonObject results            = json[RESULTS].toObject();
+            static const QString BBOX_AREA    = QLatin1String("bbox_area");
+            static const QString DISPLAY_NAME = QLatin1String("display_name");
+            QJsonObject results               = json[RESULTS].toObject();
             QList<Place> places;
 
             for (auto key : results.keys())
@@ -796,7 +796,7 @@ public:
                 for (auto placeValue : results.value(key).toArray())
                 {
                     QJsonObject place = placeValue.toObject();
-                    places.push_front(Place(place[NAME].toString(),
+                    places.push_front(Place(place[DISPLAY_NAME].toString(),
                                             place[BBOX_AREA].toDouble()));
                 }
             }
@@ -810,15 +810,16 @@ public:
             }
 
             talker.d->cachedNearbyPlaces.insert(m_query, placesStrList);
-            emit talker.signalNearbyPlaces(placesStrList);
+
+            Q_EMIT talker.signalNearbyPlaces(placesStrList);
         }
     }
 
     void reportError(INatTalker&, QNetworkReply::NetworkError,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Nearby places error" <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Nearby places error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
     }
 
 private:
@@ -862,6 +863,7 @@ void INatTalker::nearbyPlaces(double latitude, double longitude)
 
     QString lat = QString::number(latitude,  'f', GEOLOCATION_PRECISION);
     QString lng = QString::number(longitude, 'f', GEOLOCATION_PRECISION);
+
     qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Requesting nearby places for lat"
                                      << lat << "lon" << lng;
     QUrlQuery query;
@@ -877,7 +879,7 @@ void INatTalker::nearbyPlaces(double latitude, double longitude)
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Nearby places for lat" << lat
                                          << "lon" << lng << "found in cache.";
 
-        emit signalNearbyPlaces(d->cachedNearbyPlaces.value(query.query()));
+        Q_EMIT signalNearbyPlaces(d->cachedNearbyPlaces.value(query.query()));
 
         return;
     }
@@ -939,7 +941,7 @@ public:
                     talker.d->cachedNearbyObservations.insert(m_query,
                             INatTalker::NearbyObservation());
 
-                    emit talker.signalNearbyObservation(INatTalker::
+                    Q_EMIT talker.signalNearbyObservation(INatTalker::
                                                         NearbyObservation());
                 }
             }
@@ -1027,7 +1029,7 @@ public:
                             closestOpen.isValid() ? closestOpen
                                                   : closestObscured);
 
-                    emit talker.signalNearbyObservation(closestOpen.isValid()
+                    Q_EMIT talker.signalNearbyObservation(closestOpen.isValid()
                                                         ? closestOpen
                                                         : closestObscured);
                 }
@@ -1038,8 +1040,8 @@ public:
     void reportError(INatTalker&, QNetworkReply::NetworkError,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Closest observation error" <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Closest observation error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
     }
 
 private:
@@ -1087,7 +1089,7 @@ void INatTalker::closestObservation(uint taxon, double latitude,
                                          << longitude << "with radius"
                                          << radiusKm << "km found in cache.";
 
-        emit signalNearbyObservation(d->cachedNearbyObservations.value(
+        Q_EMIT signalNearbyObservation(d->cachedNearbyObservations.value(
                                          query.query()));
         return;
     }
@@ -1166,8 +1168,8 @@ public:
     {
         static const QString COMMON_ANCESTOR = QLatin1String("common_ancestor");
 
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Computer vision for" <<
-            m_imagePath << "took" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Computer vision for" << m_imagePath
+                                         << "took" << durationMilliSecs() << "msecs.";
 
         QJsonObject json = parseJsonResponse(data);
         QList<ComputerVisionScore> scores;
@@ -1187,14 +1189,14 @@ public:
 
         ImageScores result(m_imagePath, scores);
         talker.d->cachedImageScores.insert(m_imagePath, result);
-        emit talker.signalComputerVisionResults(result);
+        Q_EMIT talker.signalComputerVisionResults(result);
     }
 
     void reportError(INatTalker&, QNetworkReply::NetworkError,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Computer vision error" <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Computer vision error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
     }
 
 private:
@@ -1230,7 +1232,8 @@ void INatTalker::computerVision(const QUrl& localImage)
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Vision identification for"
                                          << localImage.toLocalFile()
                                          << "found in cache.";
-        emit signalComputerVisionResults(d->cachedImageScores.value(path));
+
+        Q_EMIT signalComputerVisionResults(d->cachedImageScores.value(path));
 
         return;
     }
@@ -1324,20 +1327,22 @@ public:
     void reportError(INatTalker& talker, QNetworkReply::NetworkError code,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyCreateObservation: " <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
-        if (networkErrorRetry(code) && m_retries < MAX_RETRIES)
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyCreateObservation: " << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
+
+        if (networkErrorRetry(code) && (m_retries < MAX_RETRIES))
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Attempting to call "
-                "VerifyCreateObservation again, retry" << m_retries+1 <<
-                "of" << MAX_RETRIES;
+                                                "VerifyCreateObservation again, retry"
+                                             << m_retries+1 << "of" << MAX_RETRIES;
+
             talker.verifyCreateObservation(m_parameters, m_uploadRequest, 1,
                                            m_retries+1);
         }
         else
         {
             QMessageBox::critical(QApplication::activeWindow(),
-                                  i18n("ERROR while creating observation"),
+                                  i18nc("@title:window", "ERROR While Creating Observation"),
                                   errorString);
         }
     }
@@ -1348,25 +1353,27 @@ public:
         QJsonObject json          = parseJsonResponse(data);
         int         observationId = -1;
 
-        if (json.contains(TOTAL_RESULTS) && json.contains(PER_PAGE) &&
-            json.contains(RESULTS) && json.contains(PAGE))
+        if (json.contains(TOTAL_RESULTS) &&
+            json.contains(PER_PAGE)      &&
+            json.contains(RESULTS)       &&
+            json.contains(PAGE))
         {
             int        totalResults = json[TOTAL_RESULTS].toInt();
             int        perPage      = json[PER_PAGE].toInt();
             QJsonArray results      = json[RESULTS].toArray();
 
-            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation check:" <<
-                results.count() << "results of" << totalResults <<
-                "received in" << durationMilliSecs() << "msecs.";
+            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation check:" << results.count()
+                                             << "results of" << totalResults
+                                             << "received in" << durationMilliSecs() << "msecs.";
 
-            for (int i = 0; i < results.count(); ++i)
+            for (int i = 0 ; i < results.count() ; ++i)
             {
                 QJsonObject result = results[i].toObject();
 
-                if (result.contains(OBSERVED_ON_STRING) &&
-                    result.contains(TAXON) &&
+                if (result.contains(OBSERVED_ON_STRING)                    &&
+                    result.contains(TAXON)                                 &&
                     result[OBSERVED_ON_STRING].toString() == m_observed_on &&
-                    result[TAXON].toObject()[ID].toInt() == m_taxon_id)
+                    result[TAXON].toObject()[ID].toInt()  == m_taxon_id)
                 {
                     observationId = result[ID].toInt();
                     break;
@@ -1374,7 +1381,8 @@ public:
             }
 
             // Not found. If the server has more results request them.
-            if (observationId < 0 && results.count() >= perPage)
+
+            if ((observationId < 0) && (results.count() >= perPage))
             {
                 talker.verifyCreateObservation(m_parameters, m_uploadRequest,
                                                json[PAGE].toInt()+1, m_retries);
@@ -1385,20 +1393,23 @@ public:
         if (observationId > 0)
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyCreateObservation: "
-                "observation" << observationId << "of taxon_id" <<
-                m_taxon_id << "of" << m_observed_on <<
-                "found; uploading photos.";
+                                                "observation" << observationId
+                                             << "of taxon_id" << m_taxon_id
+                                             << "of" << m_observed_on
+                                             << "found; uploading photos.";
 
             INatTalker::PhotoUploadRequest request(m_uploadRequest);
             request.m_observationId = observationId;
 
-            emit talker.signalObservationCreated(request);
+            Q_EMIT talker.signalObservationCreated(request);
         }
         else
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyCreateObservation: "
-                "observation of taxon_id" << m_taxon_id << "at" <<
-                m_observed_on << "not found on server; uploading again.";
+                                                "observation of taxon_id"
+                                             << m_taxon_id << "at" << m_observed_on
+                                             << "not found on server; uploading again.";
+
             talker.createObservation(m_parameters, m_uploadRequest);
         }
     }
@@ -1431,20 +1442,24 @@ void INatTalker::verifyCreateObservation(const QByteArray& parameters,
 
     int     taxon_id = 0;
     QString observed_on;
+
     if (json.contains(OBSERVATION))
     {
         QJsonObject parms = json[OBSERVATION].toObject();
+
         if (parms.contains(OBSERVED_ON_STRING))
         {
             observed_on = parms[OBSERVED_ON_STRING].toString();
             query.addQueryItem(OBSERVED_ON, observed_on.left(10));
         }
+
         if (parms.contains(TAXON_ID))
         {
             taxon_id = parms[TAXON_ID].toInt();
             query.addQueryItem(TAXON_ID, QString::number(taxon_id));
         }
     }
+
     url.setQuery(query.query());
 
     QNetworkRequest netRequest(url);
@@ -1479,8 +1494,8 @@ public:
                      const QString& errorString) const override
     {
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation not created due to "
-            "network error" << errorString << "after" <<
-            durationMilliSecs() << "msecs.";
+                                            "network error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
 
         if (networkErrorRetry(code))
         {
@@ -1489,7 +1504,7 @@ public:
         else
         {
             QMessageBox::critical(QApplication::activeWindow(),
-                                  i18n("ERROR while creating observation"),
+                                  i18nc("@title:window", "ERROR While Creating Observation"),
                                   errorString);
         }
     }
@@ -1497,8 +1512,8 @@ public:
     void parseResponse(INatTalker& talker,
                        const QByteArray& data) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation created in" <<
-            durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation created in"
+                                         << durationMilliSecs() << "msecs.";
 
         QJsonObject json = parseJsonResponse(data);
 
@@ -1507,7 +1522,7 @@ public:
             INatTalker::PhotoUploadRequest request(m_uploadRequest);
             request.m_observationId = json[ID].toInt();
 
-            emit talker.signalObservationCreated(request);
+            Q_EMIT talker.signalObservationCreated(request);
         }
     }
 
@@ -1553,20 +1568,21 @@ public:
     void reportError(INatTalker& talker, QNetworkReply::NetworkError code,
                      const QString& errorString) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyPhotoUploadNextPhoto: " <<
-            errorString << "after" << durationMilliSecs() << "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyPhotoUploadNextPhoto: " << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
 
         if (networkErrorRetry(code) && m_retries < MAX_RETRIES)
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Attempting to call "
-                "VerifyPhotoUploadNextPhoto again, retry" << m_retries+1 <<
-                "of" << MAX_RETRIES;
+                                                "VerifyPhotoUploadNextPhoto again, retry"
+                                             << m_retries + 1 << "of" << MAX_RETRIES;
+
             talker.verifyUploadNextPhoto(m_request, m_retries+1);
         }
         else
         {
             QMessageBox::critical(QApplication::activeWindow(),
-                                  i18n("ERROR while uploading photo"),
+                                  i18nc("@title:window", "ERROR While Uploading Photo"),
                                   errorString);
         }
     }
@@ -1580,8 +1596,9 @@ public:
         int lastObservationPhotoId = -1;
         int lastPhotoId            = -1;
 
-        if (json.contains(TOTAL_RESULTS) && json.contains(RESULTS) &&
-            json[TOTAL_RESULTS].toInt() == 1)
+        if (json.contains(TOTAL_RESULTS)     &&
+            json.contains(RESULTS)           &&
+            (json[TOTAL_RESULTS].toInt() == 1))
         {
             QJsonObject result = json[RESULTS].toArray()[0].toObject();
 
@@ -1598,30 +1615,30 @@ public:
                 }
             }
 
-            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyUploadNextPhoto:" <<
-                noPhotos << "photos on server," << m_request.m_images.count() <<
-                "photos to upload," << m_request.m_totalImages <<
-                "total photos, checked in" << durationMilliSecs() << "msecs.";
+            qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyUploadNextPhoto:" << noPhotos
+                                             << "photos on server," << m_request.m_images.count()
+                                             << "photos to upload," << m_request.m_totalImages
+                                             << "total photos, checked in" << durationMilliSecs() << "msecs.";
 
-            if (noPhotos + m_request.m_images.count() ==
-                m_request.m_totalImages)
+            if      ((noPhotos + m_request.m_images.count()) ==
+                     m_request.m_totalImages)
             {
                 talker.uploadNextPhoto(m_request);
             }
-            else if (noPhotos + m_request.m_images.count() ==
-                     m_request.m_totalImages + 1)
+            else if ((noPhotos + m_request.m_images.count()) ==
+                     (m_request.m_totalImages + 1))
             {
                 INatTalker::PhotoUploadResult uploadResult(m_request,
-                                                       lastObservationPhotoId,
-                                                       lastPhotoId);
-                emit talker.signalPhotoUploaded(uploadResult);
+                                                           lastObservationPhotoId,
+                                                           lastPhotoId);
+                Q_EMIT talker.signalPhotoUploaded(uploadResult);
             }
         }
         else
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "VerifyPhotoUploadNextPhoto: "
-                "observation" << m_request.m_observationId << "NOT FOUND in" <<
-                durationMilliSecs() << "msecs.";
+                                                "observation" << m_request.m_observationId
+                                             << "NOT FOUND in" << durationMilliSecs() << "msecs.";
         }
     }
 
@@ -1673,8 +1690,8 @@ public:
                      const QString& errorString) const override
     {
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Photo not uploaded due to "
-            "network error" << errorString << "after" <<
-            durationMilliSecs() << "msecs.";
+                                            "network error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
 
         if (networkErrorRetry(code))
         {
@@ -1683,7 +1700,7 @@ public:
         else
         {
             QMessageBox::critical(QApplication::activeWindow(),
-                                  i18n("ERROR while uploading photo"),
+                                  i18nc("@title:window", "ERROR While Uploading Photo"),
                                   errorString);
         }
     }
@@ -1691,10 +1708,10 @@ public:
     void parseResponse(INatTalker& talker,
                        const QByteArray& data) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Photo" <<
-            m_request.m_images.front().toLocalFile() << "to observation" <<
-            m_request.m_observationId << "uploaded in" << durationMilliSecs() <<
-            "msecs.";
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Photo" << m_request.m_images.front().toLocalFile()
+                                         << "to observation" << m_request.m_observationId
+                                         << "uploaded in" << durationMilliSecs() << "msecs.";
+
         static const QString PHOTO_ID = QLatin1String("photo_id");
         QJsonObject json              = parseJsonResponse(data);
 
@@ -1702,7 +1719,7 @@ public:
         {
             INatTalker::PhotoUploadResult result(m_request, json[ID].toInt(),
                                                  json[PHOTO_ID].toInt());
-            emit talker.signalPhotoUploaded(result);
+            Q_EMIT talker.signalPhotoUploaded(result);
         }
     }
 
@@ -1750,11 +1767,11 @@ void INatTalker::uploadNextPhoto(const PhotoUploadRequest& request)
         }
     }
 
-    QHttpMultiPart* multiPart  = getMultiPart(parameters,
-                                              QLatin1String("file"),
-                                              QFileInfo(path).fileName(),
-                                              tmpImage.isEmpty() ? path
-                                                                 : tmpImage);
+    QHttpMultiPart* const multiPart  = getMultiPart(parameters,
+                                                    QLatin1String("file"),
+                                                    QFileInfo(path).fileName(),
+                                                    tmpImage.isEmpty() ? path
+                                                                       : tmpImage);
     QUrl url(d->apiUrl + OBSERVATION_PHOTOS);
     QNetworkRequest netRequest(url);
     netRequest.setRawHeader("Authorization", request.m_apiKey.toLatin1());
@@ -1770,9 +1787,9 @@ class Q_DECL_HIDDEN DeleteObservationRequest : public Request
 public:
 
     DeleteObservationRequest(const QString& apiKey, int id, int retries)
-        : m_apiKey(apiKey),
+        : m_apiKey       (apiKey),
           m_observationId(id),
-          m_retries(retries)
+          m_retries      (retries)
     {
     }
 
@@ -1780,29 +1797,32 @@ public:
                      const QString& errorString) const override
     {
         qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Delete observation failed with "
-            "error" << errorString << "after" << durationMilliSecs() <<
-            "msecs.";
+                                            "error" << errorString
+                                         << "after" << durationMilliSecs() << "msecs.";
 
         if (networkErrorRetry(code) && m_retries < MAX_RETRIES)
         {
             qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Attempting to delete "
-                "observation" << m_observationId << "again, retry" <<
-                m_retries+1 << "of" << MAX_RETRIES;
-            talker.deleteObservation(m_observationId, m_apiKey, m_retries+1);
+                                                "observation" << m_observationId
+                                             << "again, retry" << m_retries + 1
+                                             << "of" << MAX_RETRIES;
+
+            talker.deleteObservation(m_observationId, m_apiKey, m_retries + 1);
         }
         else
         {
             QMessageBox::critical(QApplication::activeWindow(),
-                                  i18n("ERROR while deleting observation"),
+                                  i18nc("@title:window", "ERROR While Deleting Observation"),
                                   errorString);
         }
     }
 
     void parseResponse(INatTalker& talker, const QByteArray&) const override
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation" <<
-            m_observationId << "deleted in" << durationMilliSecs() << "msecs.";
-        emit talker.signalObservationDeleted(m_observationId);
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Observation" << m_observationId
+                                         << "deleted in" << durationMilliSecs() << "msecs.";
+
+        Q_EMIT talker.signalObservationDeleted(m_observationId);
     }
 
 private:
@@ -1839,7 +1859,7 @@ void INatTalker::cancel()
     }
 
     d->clear();
-    emit signalBusy(false);
+    Q_EMIT signalBusy(false);
 }
 
 void INatTalker::slotFinished(QNetworkReply* reply)
@@ -1848,8 +1868,6 @@ void INatTalker::slotFinished(QNetworkReply* reply)
 
     if (!d->pendingRequests.contains(reply))
     {
-        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "Ignoring unexpected NetworkReply.";
-        reply->deleteLater();
         return;
     }
 
@@ -1871,26 +1889,26 @@ void INatTalker::slotFinished(QNetworkReply* reply)
 void INatTalker::slotTimeout()
 {
     QList<QPair<QNetworkReply*, Request*> > timeoutList;
+    QHash<QNetworkReply*, Request*>::const_iterator it;
 
-    for (QHash<QNetworkReply*, Request*>::key_value_iterator it =
-             d->pendingRequests.keyValueBegin();
-         it != d->pendingRequests.keyValueEnd(); ++it)
+    for (it = d->pendingRequests.constBegin() ;
+         it != d->pendingRequests.constEnd() ; ++it)
     {
-        Request* request = (*it).second;
+        Request* const request = it.value();
+
         if (request->isTimeout())
         {
-            timeoutList.append(QPair<QNetworkReply*, Request*>((*it).first,
-                                                               request));
+            timeoutList.append(qMakePair(it.key(), request));
         }
     }
 
     for (auto pair : timeoutList)
     {
-        QNetworkReply* reply = pair.first;
+        QNetworkReply* const reply            = pair.first;
         d->pendingRequests.remove(reply);
 
         QNetworkReply::NetworkError errorCode = reply->error();
-        QString errorString = reply->errorString();
+        QString errorString                   = reply->errorString();
 
         reply->abort();
         delete reply;
@@ -1902,7 +1920,7 @@ void INatTalker::slotTimeout()
                                RESPONSE_TIMEOUT_SECS);
         }
 
-        Request* request = pair.second;
+        Request* const request = pair.second;
         request->reportError(*this, errorCode, errorString);
         delete request;
     }
