@@ -6,25 +6,24 @@
  * Date        : 2004-06-15
  * Description : Albums manager interface - Database helpers.
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #include "albummanager_p.h"
 
+// Qt includes
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QTextCodec>
+#else
+    #include <QStringConverter>
+#endif
+
 // KDE includes
 
 #include <kconfiggroup.h>
@@ -49,12 +48,16 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
         return true;
     }
 
-    // shutdown possibly running collection scans. Must call resumeCollectionScan further down.
+    d->changed = true;
 
-    ScanController::instance()->cancelAllAndSuspendCollectionScan();
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
-    d->changed = true;
+    DatabaseServerStarter::instance()->stopServerManagerProcess();
+
+    // Shutdown possibly running collection scans.
+    // Must call resumeCollectionScan further down.
+
+    ScanController::instance()->cancelAllAndSuspendCollectionScan();
 
     disconnect(CollectionManager::instance(), nullptr, this, nullptr);
     CollectionManager::instance()->setWatchDisabled();
@@ -64,15 +67,13 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
         disconnect(CoreDbAccess::databaseWatch(), nullptr, this, nullptr);
     }
 
-    DatabaseServerStarter::instance()->stopServerManagerProcess();
-
     d->albumWatch->clear();
 
     cleanUp();
 
     d->currentAlbums.clear();
-    emit signalAlbumCurrentChanged(d->currentAlbums);
-    emit signalAlbumsCleared();
+    Q_EMIT signalAlbumCurrentChanged(d->currentAlbums);
+    Q_EMIT signalAlbumsCleared();
 
     d->albumPathHash.clear();
     d->allAlbumsIdHash.clear();
@@ -96,13 +97,6 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     qCDebug(DIGIKAM_GENERAL_LOG) << params;
 
-    // workaround for the problem mariaDB >= 10.2 and QTBUG-63108
-
-    if (params.isMySQL())
-    {
-        addFakeConnection();
-    }
-
     QString databaseError;
 
     ApplicationSettings* const settings = ApplicationSettings::instance();
@@ -135,8 +129,8 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     if (!databaseError.isEmpty())
     {
-        QString configPath = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) +
-                             QLatin1String("/digikamrc");
+        QString configPath = QStandardPaths::locate(QStandardPaths::GenericConfigLocation,
+                                                    QLatin1String("digikamrc"));
 
         databaseError     += i18n("\n\nIf you want to start with a new configuration and "
                                   "with a first run wizard, delete the file %1",
@@ -244,75 +238,32 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     // -- Locale Checking ---------------------------------------------------------
 
-    QString currLocale = QString::fromUtf8((QTextCodec::codecForLocale()->name()));
+    QString currLocale = CoreDbAccess().db()->getDatabaseEncoding();
     QString dbLocale   = CoreDbAccess().db()->getSetting(QLatin1String("Locale"));
 
-    // guilty until proven innocent
-
-    bool localeChanged = true;
-
-    if (dbLocale.isNull())
+    if      (dbLocale.isEmpty())
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "No locale found in database";
-
-        // Copy an existing locale from the settings file (used < 0.8)
-        // to the database.
-
-        KSharedConfig::Ptr config = KSharedConfig::openConfig();
-        KConfigGroup group        = config->group(QLatin1String("General Settings"));
-
-        if (group.hasKey(QLatin1String("Locale")))
-        {
-            qCDebug(DIGIKAM_GENERAL_LOG) << "Locale found in configfile";
-            dbLocale = group.readEntry(QLatin1String("Locale"), QString());
-
-            // this hack is necessary, as we used to store the entire
-            // locale info LC_ALL (for eg: en_US.UTF-8) earlier,
-            // we now save only the encoding (UTF-8)
-
-            QString oldConfigLocale = QString::fromUtf8(::setlocale(0, nullptr));
-
-            if (oldConfigLocale == dbLocale)
-            {
-                dbLocale      = currLocale;
-                localeChanged = false;
-                CoreDbAccess().db()->setSetting(QLatin1String("Locale"), dbLocale);
-            }
-        }
-        else
-        {
-            qCDebug(DIGIKAM_GENERAL_LOG) << "No locale found in config file";
-            dbLocale      = currLocale;
-
-            localeChanged = false;
-            CoreDbAccess().db()->setSetting(QLatin1String("Locale"), dbLocale);
-        }
+        CoreDbAccess().db()->setSetting(QLatin1String("Locale"), currLocale);
     }
-    else
-    {
-        if (dbLocale == currLocale)
-        {
-            localeChanged = false;
-        }
-    }
-
-    if (localeChanged)
+    else if (dbLocale != currLocale)
     {
         // TODO it would be better to replace all yes/no confirmation dialogs with ones that has custom
         // buttons that denote the actions directly, i.e.:  ["Ignore and Continue"]  ["Adjust locale"]
 
         int result = QMessageBox::warning(qApp->activeWindow(), qApp->applicationName(),
-                                 i18n("Your locale has changed since this "
+                                 i18n("Your database character set has changed since this "
                                       "album was last opened.\n"
-                                      "Old locale: %1, new locale: %2\n"
-                                      "If you have recently changed your locale, you need not be concerned.\n"
-                                      "Please note that if you switched to a locale "
+                                      "Old character set: %1, new character set: %2\n"
+                                      "If you have recently changed your database character set, "
+                                      "you need not be concerned.\n"
+                                      "Please note that if you switched to a database character set "
                                       "that does not support some of the filenames in your collection, "
                                       "these files may no longer be found in the collection. "
                                       "If you are sure that you want to "
                                       "continue, click 'Yes'. "
                                       "Otherwise, click 'No' and correct your "
-                                      "locale setting before restarting digiKam.",
+                                      "database character set setting before restarting digiKam.",
                                       dbLocale, currLocale),
                                   QMessageBox::Yes | QMessageBox::No);
 
@@ -328,7 +279,7 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
 
     QList<CollectionLocation> disappearedLocations = CollectionManager::instance()->checkHardWiredLocations();
 
-    foreach (const CollectionLocation& loc, disappearedLocations)
+    Q_FOREACH (const CollectionLocation& loc, disappearedLocations)
     {
         QString locDescription;
         QStringList candidateIds, candidateDescriptions;
@@ -403,7 +354,7 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
         vbx->addWidget(widget);
         vbx->addWidget(buttons);
         dialog->setLayout(vbx);
-        dialog->setWindowTitle(i18n("Collection not found"));
+        dialog->setWindowTitle(i18nc("@title:window", "Collection not Found"));
 
         connect(buttons->button(QDialogButtonBox::Ok), SIGNAL(clicked()),
                 dialog, SLOT(accept()));
@@ -428,7 +379,7 @@ bool AlbumManager::setDatabase(const DbEngineParameters& params, bool priority,
             }
             else if (isRemovableButton->isChecked())
             {
-                CollectionManager::instance()->changeType(loc, CollectionLocation::TypeVolumeRemovable);
+                CollectionManager::instance()->changeType(loc, CollectionLocation::VolumeRemovable);
             }
         }
 
@@ -505,7 +456,7 @@ void AlbumManager::checkDatabaseDirsAfterFirstRun(const QString& dbPath, const Q
         if (digikam3DB.exists() || digikamVeryOldDB.exists())
         {
             QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
-                     i18n("Database Folder"),
+                     i18nc("@title:window", "Database Folder"),
                      i18n("<p>You have chosen the folder \"%1\" as the place to store the database. "
                           "A database file from an older version of digiKam is found in this folder.</p> "
                           "<p>Would you like to upgrade the old database file - confirming "
@@ -516,9 +467,9 @@ void AlbumManager::checkDatabaseDirsAfterFirstRun(const QString& dbPath, const Q
                       QMessageBox::Yes | QMessageBox::No,
                       qApp->activeWindow());
 
-            msgBox->button(QMessageBox::Yes)->setText(i18n("Upgrade Database"));
+            msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Upgrade Database"));
             msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
-            msgBox->button(QMessageBox::No)->setText(i18n("Create New Database"));
+            msgBox->button(QMessageBox::No)->setText(i18nc("@action:button", "Create New Database"));
             msgBox->button(QMessageBox::No)->setIcon(QIcon::fromTheme(QLatin1String("document-new")));
             msgBox->setDefaultButton(QMessageBox::Yes);
 
@@ -547,6 +498,8 @@ void AlbumManager::checkDatabaseDirsAfterFirstRun(const QString& dbPath, const Q
 
 void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
 {
+    ScanController::instance()->shutDown();
+
     // if there is no file at the new place, copy old one
 
     DbEngineParameters params = CoreDbAccess::parameters();
@@ -555,12 +508,13 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
 
     if (newParams.isSQLite())
     {
-        DatabaseServerStarter::instance()->stopServerManagerProcess();
+        bool walModeChanged = ((params.walMode != newParams.walMode)                                     &&
+                               (params.getCoreDatabaseNameOrDir() == newParams.getCoreDatabaseNameOrDir()));
 
         QDir newDir(newParams.getCoreDatabaseNameOrDir());
         QFileInfo newFile(newDir, QLatin1String("digikam4.db"));
 
-        if (!newFile.exists())
+        if      (!newFile.exists() && !walModeChanged)
         {
             QFileInfo digikam3DB(newDir, QLatin1String("digikam3.db"));
             QFileInfo digikamVeryOldDB(newDir, QLatin1String("digikam.db"));
@@ -572,7 +526,7 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                 if (params.isSQLite())
                 {
                     QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
-                             i18n("New database folder"),
+                             i18nc("@title:window", "New Database Folder"),
                              i18n("<p>You have chosen the folder \"%1\" as the new place to store the database. "
                                   "A database file from an older version of digiKam is found in this folder.</p> "
                                   "<p>Would you like to upgrade the old database file, start with a new database, "
@@ -581,11 +535,11 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                              QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
                              qApp->activeWindow());
 
-                    msgBox->button(QMessageBox::Yes)->setText(i18n("Upgrade Database"));
+                    msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Upgrade Database"));
                     msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
-                    msgBox->button(QMessageBox::No)->setText(i18n("Create New Database"));
+                    msgBox->button(QMessageBox::No)->setText(i18nc("@action:button", "Create New Database"));
                     msgBox->button(QMessageBox::No)->setIcon(QIcon::fromTheme(QLatin1String("document-new")));
-                    msgBox->button(QMessageBox::Cancel)->setText(i18n("Copy Current Database"));
+                    msgBox->button(QMessageBox::Cancel)->setText(i18nc("@action:button", "Copy Current Database"));
                     msgBox->button(QMessageBox::Cancel)->setIcon(QIcon::fromTheme(QLatin1String("edit-copy")));
                     msgBox->setDefaultButton(QMessageBox::Yes);
 
@@ -595,7 +549,7 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                 else
                 {
                     QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
-                             i18n("New database folder"),
+                             i18nc("@title:window", "New Database Folder"),
                              i18n("<p>You have chosen the folder \"%1\" as the new place to store the database. "
                                   "A database file from an older version of digiKam is found in this folder.</p> "
                                   "<p>Would you like to upgrade the old database file or start with a new database?</p>",
@@ -603,9 +557,9 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                              QMessageBox::Yes | QMessageBox::No,
                              qApp->activeWindow());
 
-                    msgBox->button(QMessageBox::Yes)->setText(i18n("Upgrade Database"));
+                    msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Upgrade Database"));
                     msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
-                    msgBox->button(QMessageBox::No)->setText(i18n("Create New Database"));
+                    msgBox->button(QMessageBox::No)->setText(i18nc("@action:button", "Create New Database"));
                     msgBox->button(QMessageBox::No)->setIcon(QIcon::fromTheme(QLatin1String("document-new")));
                     msgBox->setDefaultButton(QMessageBox::Yes);
 
@@ -645,7 +599,7 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                 if (params.isSQLite())
                 {
                     QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
-                             i18n("New database folder"),
+                             i18nc("@title:window", "New Database Folder"),
                              i18n("<p>You have chosen the folder \"%1\" as the new place to store the database.</p>"
                                   "<p>Would you like to copy the current database to this location "
                                   "and continue using it, or start with a new database?</p> ",
@@ -653,9 +607,9 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                              QMessageBox::Yes | QMessageBox::No,
                              qApp->activeWindow());
 
-                    msgBox->button(QMessageBox::Yes)->setText(i18n("Create New Database"));
+                    msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Create New Database"));
                     msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("document-new")));
-                    msgBox->button(QMessageBox::No)->setText(i18n("Copy Current Database"));
+                    msgBox->button(QMessageBox::No)->setText(i18nc("@action:button", "Copy Current Database"));
                     msgBox->button(QMessageBox::No)->setIcon(QIcon::fromTheme(QLatin1String("edit-copy")));
                     msgBox->setDefaultButton(QMessageBox::Yes);
 
@@ -670,14 +624,14 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                 }
             }
         }
-        else
+        else if (!walModeChanged)
         {
             int result = QMessageBox::No;
 
             if (params.isSQLite())
             {
                 QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
-                         i18n("New database folder"),
+                         i18nc("@title:window", "New Database Folder"),
                          i18n("<p>You have chosen the folder \"%1\" as the new place to store the database. "
                               "There is already a database file in this location.</p> "
                               "<p>Would you like to use this existing file as the new database, or remove it "
@@ -686,9 +640,9 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
                          QMessageBox::Yes | QMessageBox::No,
                          qApp->activeWindow());
 
-                msgBox->button(QMessageBox::Yes)->setText(i18n("Copy Current Database"));
+                msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Copy Current Database"));
                 msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("edit-copy")));
-                msgBox->button(QMessageBox::No)->setText(i18n("Use Existing File"));
+                msgBox->button(QMessageBox::No)->setText(i18nc("@action:button", "Use Existing File"));
                 msgBox->button(QMessageBox::No)->setIcon(QIcon::fromTheme(QLatin1String("document-open")));
                 msgBox->setDefaultButton(QMessageBox::Yes);
 
@@ -712,6 +666,8 @@ void AlbumManager::changeDatabase(const DbEngineParameters& newParams)
         }
     }
 
+    ScanController::instance()->restart();
+
     if (setDatabase(newParams, false))
     {
         QApplication::setOverrideCursor(Qt::WaitCursor);
@@ -728,26 +684,6 @@ bool AlbumManager::databaseEqual(const DbEngineParameters& parameters) const
     return (params == parameters);
 }
 
-void AlbumManager::addFakeConnection()
-{
-    if (!d->dbFakeConnection)
-    {
-        // workaround for the problem mariaDB >= 10.2 and QTBUG-63108
-        // from a Qt minimum version of >= 5.9.2 we can remove this workaround
-
-        QSqlDatabase::addDatabase(QLatin1String("QMYSQL"), QLatin1String("FakeConnection"));
-        d->dbFakeConnection = true;
-    }
-}
-
-void AlbumManager::removeFakeConnection()
-{
-    if (d->dbFakeConnection)
-    {
-        QSqlDatabase::removeDatabase(QLatin1String("FakeConnection"));
-    }
-}
-
 bool AlbumManager::moveToBackup(const QFileInfo& info)
 {
     if (info.exists())
@@ -809,20 +745,32 @@ bool AlbumManager::showDatabaseSetupPage(const QString& error, bool priority, co
     QPointer<QDialog> setup                  = new QDialog(qApp->activeWindow());
     QVBoxLayout* const layout                = new QVBoxLayout(setup);
     DatabaseSettingsWidget* const dbsettings = new DatabaseSettingsWidget(setup);
-    QDialogButtonBox* const buttons          = new QDialogButtonBox(QDialogButtonBox::Ok |
+    QDialogButtonBox* const buttons          = new QDialogButtonBox(QDialogButtonBox::Ok    |
+                                                                    QDialogButtonBox::Reset |
                                                                     QDialogButtonBox::Cancel, setup);
+    buttons->button(QDialogButtonBox::Reset)->setText(i18nc("@action:button", "New database"));
     buttons->button(QDialogButtonBox::Ok)->setDefault(true);
 
     layout->addWidget(dbsettings);
     layout->addStretch(10);
     layout->addWidget(buttons);
 
+    bool newDatabase = false;
+
     connect(buttons->button(QDialogButtonBox::Ok), SIGNAL(clicked()),
             setup, SLOT(accept()));
 
     connect(buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
             setup, SLOT(reject()));
 
+    connect(buttons->button(QDialogButtonBox::Reset), &QPushButton::clicked,
+            this, [&]()
+            {
+                newDatabase = true;
+                setup->accept();
+            }
+    );
+
     ApplicationSettings* const settings = ApplicationSettings::instance();
     dbsettings->setParametersFromSettings(settings);
 
@@ -839,6 +787,26 @@ bool AlbumManager::showDatabaseSetupPage(const QString& error, bool priority, co
 
     delete setup;
 
+    if (newDatabase)
+    {
+        if (dbParams.internalServer)
+        {
+            DatabaseServerError result = DatabaseServerStarter::instance()->startServerManagerProcess(dbParams);
+
+            if (result.getErrorType() != DatabaseServerError::NoErrors)
+            {
+                return false;
+            }
+        }
+
+        CoreDbAccess::setParameters(dbParams);
+
+        if (!CoreDbAccess::checkReadyForUse())
+        {
+            return false;
+        }
+    }
+
     return (setDatabase(dbParams, priority, suggestedAlbumRoot));
 }
 
