@@ -6,31 +6,18 @@
  * Date        : 2003-01-17
  * Description : Haar Database interface
  *
- * Copyright (C) 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
- * Copyright (C) 2003      by Ricardo Niederberger Cabral <nieder at mail dot ru>
- * Copyright (C) 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2016-2018 by Mario Frank <mario dot frank at uni minus potsdam dot de>
+ * SPDX-FileCopyrightText: 2003      by Ricardo Niederberger Cabral <nieder at mail dot ru>
+ * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2011 by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #include "haariface_p.h"
 
-// C++ includes
-
-#include <functional>
-
 namespace Digikam
 {
 
@@ -53,7 +40,7 @@ HaarIface::~HaarIface()
 
 void HaarIface::setAlbumRootsToSearch(const QList<int>& albumRootIds)
 {
-    setAlbumRootsToSearch(albumRootIds.toSet());
+    setAlbumRootsToSearch(QSet<int>(albumRootIds.begin(), albumRootIds.end()));
 }
 
 void HaarIface::setAlbumRootsToSearch(const QSet<int>& albumRootIds)
@@ -300,7 +287,7 @@ QMultiMap<double, qlonglong> HaarIface::bestMatches(Haar::SignatureData* const q
         {
             // find the last entry, the one with the highest (=worst) score
 
-            QMap<double, qlonglong>::iterator last = bestMatches.end();
+            QMultiMap<double, qlonglong>::iterator last = bestMatches.end();
             --last;
             worstScore = last.key();
 
@@ -592,7 +579,7 @@ void HaarIface::getBestAndWorstPossibleScore(Haar::SignatureData* const sig,
 
     for (int channel = 0 ; channel < 3 ; ++channel)
     {
-        Haar::Idx* coefs = sig->sig[channel];
+        Haar::Idx* const coefs = sig->sig[channel];
 
         for (int coef = 0 ; coef < Haar::NumberOfCoefficients ; ++coef)
         {
@@ -676,16 +663,18 @@ QSet<qlonglong> HaarIface::imagesFromAlbumsAndTags(const QList<int>& albums2Scan
 
     // Get all items DB id from all albums and all collections
 
-    foreach (int albumId, albums2Scan)
+    Q_FOREACH (int albumId, albums2Scan)
     {
-        imagesFromAlbums.unite(CoreDbAccess().db()->getItemIDsInAlbum(albumId).toSet());
+        const auto list = CoreDbAccess().db()->getItemIDsInAlbum(albumId);
+        imagesFromAlbums.unite(QSet<qlonglong>(list.begin(), list.end()));
     }
 
     // Get all items DB id from all tags
 
-    foreach (int albumId, tags2Scan)
+    Q_FOREACH (int albumId, tags2Scan)
     {
-        imagesFromTags.unite(CoreDbAccess().db()->getItemIDsInTag(albumId).toSet());
+        const auto list = CoreDbAccess().db()->getItemIDsInTag(albumId);
+        imagesFromTags.unite(QSet<qlonglong>(list.begin(), list.end()));
     }
 
     switch (relation)
@@ -817,11 +806,11 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
                 qlonglong refFileSize   = 0;
                 qlonglong reference     = *images2ScanIterator;
 
-                foreach (const qlonglong& refId, duplicates)
+                Q_FOREACH (const qlonglong& refId, duplicates)
                 {
                     ItemInfo info(refId);
-                    quint64 infoPixelSize = info.dimensions().width() *
-                                            info.dimensions().height();
+                    quint64 infoPixelSize = (quint64)info.dimensions().width() *
+                                            (quint64)info.dimensions().height();
 
                     if (
                         !refDateTime.isValid()             ||
@@ -842,8 +831,8 @@ HaarIface::DuplicatesResultsMap HaarIface::findDuplicates(const QSet<qlonglong>&
 
                 resultsMap.insert(reference, qMakePair(bestMatches.first, duplicates));
 
-                resultsCandidates << reference;
-                resultsCandidates.unite(duplicates.toSet());
+                resultsCandidates << *images2ScanIterator;
+                resultsCandidates.unite(QSet<qlonglong>(duplicates.begin(), duplicates.end()));
             }
         }
 
