@@ -6,21 +6,12 @@
  * Date        : 2005-05-17
  * Description : low level files management interface.
  *
- * Copyright (C) 2005      by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2012-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2018      by Maik Qualmann <metzpinguin at gmail dot com>
+ * SPDX-FileCopyrightText: 2005      by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2012-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2015      by Mohamed_Anwer <m_dot_anwer at gmx dot com>
+ * SPDX-FileCopyrightText: 2018      by Maik Qualmann <metzpinguin at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -271,14 +262,17 @@ void DIO::processJob(IOJobData* const data)
     else if ((operation == IOJobData::Trash) ||
              (operation == IOJobData::Delete))
     {
+        SidecarFinder finder(data->sourceUrls());
+        data->setSourceUrls(finder.localFiles);
+
         qCDebug(DIGIKAM_DATABASE_LOG) << "Number of files to be deleted:" << data->sourceUrls().count();
     }
 
-    SidecarFinder finder(data->sourceUrls());
-    data->setSourceUrls(finder.localFiles);
-
     if (operation == IOJobData::Rename)
     {
+        SidecarFinder finder(data->sourceUrls());
+        data->setSourceUrls(finder.localFiles);
+
         for (int i = 0 ; i < finder.localFiles.size() ; ++i)
         {
             if (finder.localFileModes.at(i))
@@ -319,17 +313,20 @@ void DIO::createJob(IOJobData* const data)
         (operation == IOJobData::MoveImage) || (operation == IOJobData::MoveAlbum) ||
         (operation == IOJobData::MoveFiles))
     {
+        CollectionLocation location         = CollectionManager::instance()->locationForUrl(data->destUrl());
+        Qt::CaseSensitivity caseSensitivity = location.asQtCaseSensitivity();
         QDir dir(data->destUrl().toLocalFile());
-        const QStringList& dirList = dir.entryList(QDir::Dirs    |
-                                                   QDir::Files   |
-                                                   QDir::NoDotAndDotDot);
 
-        foreach (const QUrl& url, data->sourceUrls())
+        const QStringList& dirList          = dir.entryList(QDir::Dirs    |
+                                                            QDir::Files   |
+                                                            QDir::NoDotAndDotDot);
+
+        Q_FOREACH (const QUrl& url, data->sourceUrls())
         {
-            if (dirList.contains(url.adjusted(QUrl::StripTrailingSlash).fileName()))
+            if (dirList.contains(url.adjusted(QUrl::StripTrailingSlash).fileName(), caseSensitivity))
             {
                 QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Warning,
-                        i18n("File conflict"),
+                        i18nc("@title:window", "File Conflict"),
                         i18n("Files or folders with the same name already exist in the target folder.\n\n"
                              "What action is applied in the event of a file conflict?\n\n"
                              "Available options are:\n"
@@ -339,11 +336,11 @@ void DIO::createJob(IOJobData* const data)
                         QMessageBox::Yes | QMessageBox::No | QMessageBox::Ok | QMessageBox::Cancel,
                         qApp->activeWindow());
 
-                msgBox->button(QMessageBox::Yes)->setText(i18n("Rename automatically"));
+                msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Rename Automatically"));
                 msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("document-edit")));
-                msgBox->button(QMessageBox::No)->setText(i18n("Overwrite automatically"));
+                msgBox->button(QMessageBox::No)->setText(i18nc("@action:button", "Overwrite Automatically"));
                 msgBox->button(QMessageBox::No)->setIcon(QIcon::fromTheme(QLatin1String("edit-copy")));
-                msgBox->button(QMessageBox::Ok)->setText(i18n("Skip automatically"));
+                msgBox->button(QMessageBox::Ok)->setText(i18nc("@action:button", "Skip Automatically"));
                 msgBox->button(QMessageBox::Ok)->setIcon(QIcon::fromTheme(QLatin1String("go-next")));
 
                 if ((operation == IOJobData::CopyAlbum) || (operation == IOJobData::MoveAlbum))
@@ -431,8 +428,9 @@ void DIO::slotResult()
     }
 
     IOJobData* const data = jobThread->jobData();
+    const int operation   = data->operation();
 
-    if (jobThread->hasErrors() && data->operation() != IOJobData::Rename)
+    if      (jobThread->hasErrors() && operation != IOJobData::Rename)
     {
         // Pop-up a message about the error.
 
@@ -440,6 +438,27 @@ void DIO::slotResult()
         DNotificationWrapper(QString(), errors, DigikamApp::instance(),
                              DigikamApp::instance()->windowTitle());
     }
+    else
+    {
+        if ((operation == IOJobData::CopyImage) ||
+            (operation == IOJobData::MoveImage))
+        {
+            if (data->destAlbum())
+            {
+                updateAlbumDate(data->destAlbum()->id());
+            }
+        }
+
+        if ((operation == IOJobData::Trash)  ||
+            (operation == IOJobData::Delete) ||
+            (operation == IOJobData::MoveImage))
+        {
+            Q_FOREACH (int albumID, data->srcAlbumIds())
+            {
+                updateAlbumDate(albumID);
+            }
+        }
+    }
 
     if (m_processingCount)
     {
@@ -724,6 +743,30 @@ void DIO::slotOneProccessed(const QUrl& url)
     }
 }
 
+void DIO::updateAlbumDate(int albumID)
+{
+    QDate newAlbumDate;
+    MetaEngineSettingsContainer settings = MetaEngineSettings::instance()->settings();
+
+    if      (settings.albumDateFrom == MetaEngineSettingsContainer::OldestItemDate)
+    {
+        newAlbumDate = CoreDbAccess().db()->getAlbumLowestDate(albumID);
+    }
+    else if (settings.albumDateFrom == MetaEngineSettingsContainer::NewestItemDate)
+    {
+        newAlbumDate = CoreDbAccess().db()->getAlbumHighestDate(albumID);
+    }
+    else if (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate)
+    {
+        newAlbumDate = CoreDbAccess().db()->getAlbumAverageDate(albumID);
+    }
+
+    if (newAlbumDate.isValid())
+    {
+        CoreDbAccess().db()->setAlbumDate(albumID, newAlbumDate);
+    }
+}
+
 QString DIO::getItemString(IOJobData* const data) const
 {
     switch (data->operation())
