@@ -6,20 +6,11 @@
  * Date        : 2005-10-28
  * Description : scan item controller.
  *
- * Copyright (C) 2005-2006 by Tom Albers <tomalbers at kde dot nl>
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -232,7 +223,7 @@ void ScanController::run()
                 d->advice = ContinueWithoutDatabase;
             }
 
-            emit databaseInitialized(success);
+            Q_EMIT databaseInitialized(success);
         }
         else if (doScan)
         {
@@ -249,7 +240,7 @@ void ScanController::run()
 
             scanner.completeScan();
 
-            emit completeScanDone();
+            Q_EMIT completeScanDone();
 
             if (doScanDeferred)
             {
@@ -269,7 +260,7 @@ void ScanController::run()
             CollectionScanner scanner;
             connectCollectionScanner(&scanner);
 
-            emit collectionScanStarted(i18nc("@info:status", "Scanning collection"));
+            Q_EMIT collectionScanStarted(i18nc("@info:status", "Scanning collection"));
 
             //TODO: reconsider performance
 
@@ -283,8 +274,8 @@ void ScanController::run()
             scanner.finishCompleteScan(d->completeScanDeferredAlbums);
 
             d->completeScanDeferredAlbums.clear();
-            emit completeScanDone();
-            emit collectionScanFinished();
+            Q_EMIT completeScanDone();
+            Q_EMIT collectionScanFinished();
         }
         else if (doPartialScan)
         {
@@ -296,7 +287,7 @@ void ScanController::run()
             SimpleCollectionScannerObserver observer(&d->continuePartialScan);
             scanner.setObserver(&observer);
             scanner.partialScan(task);
-            emit partialScanDone(task);
+            Q_EMIT partialScanDone(task);
         }
         else if (doUpdateUniqueHash)
         {
@@ -305,7 +296,7 @@ void ScanController::run()
             updater.setCoreDbAccess(&access);
             updater.setObserver(this);
             updater.updateUniqueHash();
-            emit completeScanDone();
+            Q_EMIT completeScanDone();
         }
     }
 }
@@ -368,7 +359,8 @@ void ScanController::updateUniqueHash()
     d->needTotalFiles = false;
 }
 
-ItemInfo ScanController::scannedInfo(const QString& filePath)
+ItemInfo ScanController::scannedInfo(const QString& filePath,
+                                     CollectionScanner::FileScanMode mode)
 {
     CollectionScanner scanner;
     scanner.setHintContainer(d->hints);
@@ -383,7 +375,7 @@ ItemInfo ScanController::scannedInfo(const QString& filePath)
     }
     else
     {
-        scanner.scanFile(info, CollectionScanner::NormalScan);
+        scanner.scanFile(info, mode);
 
         return info;
     }
