@@ -6,19 +6,10 @@
  * Date        : 2009-11-14
  * Description : database settings widget
  *
- * Copyright (C) 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
+ * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -46,7 +37,8 @@ void DatabaseSettingsWidget::setupMainArea()
 
     // --------------------------------------------------------
 
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     QGroupBox* const dbConfigBox    = new QGroupBox(i18n("Database Configuration"), this);
     QVBoxLayout* const vlay         = new QVBoxLayout(dbConfigBox);
@@ -104,7 +96,7 @@ void DatabaseSettingsWidget::setupMainArea()
                                      "one for all collections properties, "
                                      "one to store compressed thumbnails, "
                                      "one to store faces recognition metadata, "
-                                     "and one to store similarity finguerprints.<br/>"
+                                     "and one to store similarity fingerprints.<br/>"
                                      "Write access is required to be able to edit image properties.</p>"
                                      "<p>Databases are digiKam core engines. Take care to use a place hosted by fast "
                                      "hardware (eg. SSD or NVMe) with enough free space especially for thumbnails database.</p>"
@@ -118,8 +110,22 @@ void DatabaseSettingsWidget::setupMainArea()
 
     // --------------------------------------------------------
 
+    d->walModeCheck = new QCheckBox(i18n("Enable WAL mode for the databases"), dbConfigBox);
+    d->walModeCheck->setToolTip(i18n("The WAL (Write-Ahead Log) mode is significantly "
+                                     "faster in most scenarios on supported systems."));
+
+    d->walLabel     = new QLabel(i18n("Write-Ahead Log is a mode to use a roll-forward journal that records transactions "
+                                      "that have been committed but not yet applied to the databases. It uses an auxiliary "
+                                      "journalized file to host structures for recovery transactions during a crash. The changes "
+                                      "are first recorded in the log, before the changes are written to the database. This made "
+                                      "database requests atomic and robust in extensive and critical use cases."),
+                                 dbConfigBox);
+    d->walLabel->setWordWrap(true);
+
+    // --------------------------------------------------------
+
     d->mysqlCmdBox = new DVBox(dbConfigBox);
-    d->mysqlCmdBox->layout()->setContentsMargins(0, 0, 0, 0);
+    d->mysqlCmdBox->layout()->setContentsMargins(QMargins());
 
     new DLineWidget(Qt::Horizontal, d->mysqlCmdBox);
     QLabel* const mysqlBinariesLabel  = new QLabel(i18n("<p>Here you can configure locations where MySQL binary tools are located. "
@@ -215,8 +221,8 @@ void DatabaseSettingsWidget::setupMainArea()
 
     // Only accept printable Ascii char for database names.
 
-    QRegExp asciiRx(QLatin1String("[\x20-\x7F]+$"));
-    QValidator* const asciiValidator = new QRegExpValidator(asciiRx, this);
+    QRegularExpression asciiRx(QLatin1String("[\x20-\x7F]+$"));
+    QValidator* const asciiValidator = new QRegularExpressionValidator(asciiRx, this);
 
     QLabel* const dbNameCoreLabel                    = new QLabel(i18n("Core Db Name:"));
     d->dbNameCore                                    = new QLineEdit();
@@ -354,6 +360,9 @@ void DatabaseSettingsWidget::setupMainArea()
     vlay->addWidget(d->dbPathEdit);
     vlay->addWidget(d->mysqlCmdBox);
     vlay->addWidget(d->tab);
+    vlay->addWidget(d->walModeCheck);
+    vlay->addWidget(d->walLabel);
+    vlay->addStretch(10);
     vlay->setContentsMargins(spacing, spacing, spacing, spacing);
     vlay->setSpacing(spacing);
 
@@ -453,6 +462,8 @@ void DatabaseSettingsWidget::setDatabaseInputFields(int index)
         {
             d->dbPathLabel->setVisible(true);
             d->dbPathEdit->setVisible(true);
+            d->walModeCheck->setVisible(true);
+            d->walLabel->setVisible(true);
             d->mysqlCmdBox->setVisible(false);
             d->tab->setVisible(false);
 
@@ -466,6 +477,8 @@ void DatabaseSettingsWidget::setDatabaseInputFields(int index)
         {
             d->dbPathLabel->setVisible(true);
             d->dbPathEdit->setVisible(true);
+            d->walModeCheck->setVisible(false);
+            d->walLabel->setVisible(false);
             d->mysqlCmdBox->setVisible(true);
             d->tab->setVisible(false);
 
@@ -479,6 +492,8 @@ void DatabaseSettingsWidget::setDatabaseInputFields(int index)
         {
             d->dbPathLabel->setVisible(false);
             d->dbPathEdit->setVisible(false);
+            d->walModeCheck->setVisible(false);
+            d->walLabel->setVisible(false);
             d->mysqlCmdBox->setVisible(false);
             d->tab->setVisible(true);
 
@@ -576,12 +591,12 @@ void DatabaseSettingsWidget::slotCheckMysqlServerConnection()
 
     if (checkMysqlServerConnection(error))
     {
-        QMessageBox::information(qApp->activeWindow(), i18n("Database connection test"),
+        QMessageBox::information(qApp->activeWindow(), i18nc("@title:window", "Database Connection Test"),
                                  i18n("Database connection test successful."));
     }
     else
     {
-        QMessageBox::critical(qApp->activeWindow(), i18n("Database connection test"),
+        QMessageBox::critical(qApp->activeWindow(), i18nc("@title:window", "Database Connection Test"),
                               i18n("Database connection test was not successful. <p>Error was: %1</p>",
                                    error));
     }
@@ -644,8 +659,6 @@ bool DatabaseSettingsWidget::checkMysqlServerConnection(QString& error)
 
     qApp->setOverrideCursor(Qt::WaitCursor);
 
-    AlbumManager::instance()->addFakeConnection();
-
     QString databaseID(QLatin1String("ConnectionTest"));
 
     {
@@ -682,6 +695,7 @@ void DatabaseSettingsWidget::setParametersFromSettings(const ApplicationSettings
     {
         d->dbPathEdit->setFileDlgPath(d->orgPrms.getCoreDatabaseNameOrDir());
         d->dbType->setCurrentIndex(d->dbTypeMap[SQlite]);
+        d->walModeCheck->setChecked(d->orgPrms.walMode);
         slotResetMysqlServerDBNames();
 
         if (settings->getDatabaseDirSetAtCmd() && !migration)
@@ -706,6 +720,7 @@ void DatabaseSettingsWidget::setParametersFromSettings(const ApplicationSettings
         d->mysqlInitBin.setup(QFileInfo(d->orgPrms.internalServerMysqlInitCmd).absoluteFilePath());
         d->mysqlServBin.setup(QFileInfo(d->orgPrms.internalServerMysqlServCmd).absoluteFilePath());
         d->dbBinariesWidget->allBinariesFound();
+        d->walModeCheck->setChecked(false);
         slotResetMysqlServerDBNames();
     }
 
@@ -723,6 +738,7 @@ void DatabaseSettingsWidget::setParametersFromSettings(const ApplicationSettings
         d->connectOpts->setText(d->orgPrms.connectOptions);
         d->userName->setText(d->orgPrms.userName);
         d->password->setText(d->orgPrms.password);
+        d->walModeCheck->setChecked(false);
     }
 
 #endif
@@ -738,7 +754,8 @@ DbEngineParameters DatabaseSettingsWidget::getDbEngineParameters() const
     {
         case SQlite:
         {
-            prm = DbEngineParameters::parametersForSQLiteDefaultFile(databasePath());
+            prm         = DbEngineParameters::parametersForSQLiteDefaultFile(databasePath());
+            prm.walMode = d->walModeCheck->isChecked();
             break;
         }
 
@@ -823,7 +840,7 @@ bool DatabaseSettingsWidget::checkDatabaseSettings()
 
             if (!checkMysqlServerDbNamesConfig(error))
             {
-                QMessageBox::critical(qApp->activeWindow(), i18n("Database Configuration"),
+                QMessageBox::critical(qApp->activeWindow(), i18nc("@title:window", "Database Configuration"),
                                       i18n("The database names configuration is not valid. Error is <br/><p>%1</p><br/>"
                                            "Please check your configuration.",
                                            error));
@@ -832,7 +849,7 @@ bool DatabaseSettingsWidget::checkDatabaseSettings()
 
             if (!checkMysqlServerConnection(error))
             {
-                QMessageBox::critical(qApp->activeWindow(), i18n("Database Connection Test"),
+                QMessageBox::critical(qApp->activeWindow(), i18nc("@title:window", "Database Connection Test"),
                                       i18n("Testing database connection has failed with error<br/><p>%1</p><br/>"
                                            "Please check your configuration.",
                                            error));
@@ -861,7 +878,7 @@ bool DatabaseSettingsWidget::checkDatabasePath()
 
     if (!targetPath.exists())
     {
-        int rc = QMessageBox::question(qApp->activeWindow(), i18n("Create Database Folder?"),
+        int rc = QMessageBox::question(qApp->activeWindow(), i18nc("@title:window", "Create Database Folder?"),
                                     i18n("<p>The folder to put your database in does not seem to exist:</p>"
                                          "<p><b>%1</b></p>"
                                          "Would you like digiKam to create it for you?", dbFolder));
@@ -873,7 +890,7 @@ bool DatabaseSettingsWidget::checkDatabasePath()
 
         if (!targetPath.mkpath(dbFolder))
         {
-            QMessageBox::information(qApp->activeWindow(), i18n("Create Database Folder Failed"),
+            QMessageBox::information(qApp->activeWindow(), i18nc("@title:window", "Create Database Folder Failed"),
                                     i18n("<p>digiKam could not create the folder to host your database file.\n"
                                          "Please select a different location.</p>"
                                          "<p><b>%1</b></p>", dbFolder));
@@ -899,7 +916,7 @@ bool DatabaseSettingsWidget::checkDatabasePath()
 #endif
 
     {
-        QMessageBox::information(qApp->activeWindow(), i18n("No Database Write Access"),
+        QMessageBox::information(qApp->activeWindow(), i18nc("@title:window", "No Database Write Access"),
                                  i18n("<p>You do not seem to have write access "
                                       "for the folder to host the database file.<br/>"
                                       "Please select a different location.</p>"
