@@ -6,19 +6,10 @@
  * Date        : 17-8-2016
  * Description : A Red-Eye automatic detection and correction filter.
  *
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2016      by Omar Amin <Omar dot moh dot amin at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2016      by Omar Amin <Omar dot moh dot amin at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -36,15 +27,12 @@
 #include <QListIterator>
 #include <QStandardPaths>
 
-// KDE includes
-
-#include <klocalizedstring.h>
-
 // Local includes
 
 #include "digikam_debug.h"
 #include "facedetector.h"
 #include "shapepredictor.h"
+#include "digikam_globals_p.h"      // For KF6::Ki18n deprecated
 
 namespace Digikam
 {
@@ -94,7 +82,7 @@ RedEyeCorrectionFilter::RedEyeCorrectionFilter(const RedEyeCorrectionContainer&
       d                 (new Private)
 {
     d->settings = settings;
-    filterImage();
+    this->filterImage();
 }
 
 RedEyeCorrectionFilter::~RedEyeCorrectionFilter()
@@ -114,7 +102,7 @@ void RedEyeCorrectionFilter::filterImage()
     {
         // Loading the shape predictor model
 
-        QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+        QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
         QUrl    appUrl  = QUrl::fromLocalFile(appPath).adjusted(QUrl::RemoveFilename);
         appUrl.setPath(appUrl.path() + QLatin1String("digikam/facesengine/"));
 
@@ -276,7 +264,7 @@ FilterAction RedEyeCorrectionFilter::filterAction()
 {
     DefaultFilterAction<RedEyeCorrectionFilter> action;
     d->settings.writeToFilterAction(action);
-    return std::move(action);
+    return action;
 }
 
 void RedEyeCorrectionFilter::readParameters(const FilterAction& action)
