@@ -11,19 +11,10 @@
  *               sthanhng github on face detection with Yolov3:
  *               https://github.com/sthanhng/yoloface
  *
- * Copyright (C) 2019      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
- * Copyright (C) 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -59,7 +50,7 @@ DNNFaceDetectorYOLO::~DNNFaceDetectorYOLO()
 
 bool DNNFaceDetectorYOLO::loadModels()
 {
-    QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+    QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
     QUrl    appUrl  = QUrl::fromLocalFile(appPath).adjusted(QUrl::RemoveFilename);
     appUrl.setPath(appUrl.path() + QLatin1String("digikam/facesengine/"));
 
