@@ -7,19 +7,10 @@
  * Description : Exiv2 library interface.
  *               Exif manipulation methods
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -31,7 +22,12 @@
 
 // Qt includes
 
-#include <QTextCodec>
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#   include <QStringEncoder>
+#else
+#   include <QTextCodec>
+#endif
+
 #include <QBuffer>
 
 // KDE includes
@@ -80,7 +76,7 @@ bool MetaEngine::canWriteExif(const QString& filePath)
     catch (Exiv2::AnyError& e)
     {
         qCCritical(DIGIKAM_METAENGINE_LOG) << "Cannot check Exif access mode with Exiv2:(Error #"
-                                           << e.code() << ": " << QString::fromStdString(e.what()) << ")";
+                                           << (int)e.code() << ": " << QString::fromStdString(e.what()) << ")";
     }
     catch (...)
     {
@@ -194,6 +190,25 @@ bool MetaEngine::setExif(const QByteArray& data) const
 }
 
 QString MetaEngine::getExifComment(bool readDescription) const
+{
+    QString comment = getExifTagComment("Exif.Photo.UserComment");
+
+    if (!comment.isEmpty())
+    {
+        return comment;
+    }
+
+    if (readDescription)
+    {
+        comment = getExifTagComment("Exif.Image.ImageDescription");
+
+        return comment;
+    }
+
+    return QString();
+}
+
+QString MetaEngine::getExifTagComment(const char* exifTagName) const
 {
     QMutexLocker lock(&s_metaEngineMutex);
 
@@ -207,15 +222,35 @@ QString MetaEngine::getExifComment(bool readDescription) const
 
         if (!d->exifMetadata().empty())
         {
+            std::string exifkey(exifTagName);
             Exiv2::ExifData exifData(d->exifMetadata());
-            Exiv2::ExifKey key("Exif.Photo.UserComment");
+            Exiv2::ExifKey key(exifkey);
             Exiv2::ExifData::const_iterator it = exifData.findKey(key);
 
             if (it != exifData.end())
             {
-                QString exifComment    = d->convertCommentValue(*it);
+                QString exifComment;
+
+                if (QLatin1String(exifTagName) == QLatin1String("Exif.Image.XPComment"))
+                {
+                    exifComment = QString::fromStdString(it->print(&exifData));
+                }
+                else
+                {
+                    exifComment = d->convertCommentValue(*it);
+                }
+
                 QString trimmedComment = exifComment.trimmed();
 
+                // Some cameras fill in nonsense default values
+
+                if (QLatin1String(exifTagName) == QLatin1String("Exif.Image.ImageDescription"))
+                {
+                    blackList << QLatin1String("SONY DSC"); // + whitespace
+                    blackList << QLatin1String("OLYMPUS DIGITAL CAMERA");
+                    blackList << QLatin1String("MINOLTA DIGITAL CAMERA");
+                }
+
                 // some cameras fill the UserComment with whitespace
 
                 if (!exifComment.isEmpty() && !trimmedComment.isEmpty() && !blackList.contains(trimmedComment))
@@ -223,31 +258,6 @@ QString MetaEngine::getExifComment(bool readDescription) const
                     return exifComment;
                 }
             }
-
-            if (readDescription)
-            {
-                Exiv2::ExifKey key2("Exif.Image.ImageDescription");
-                Exiv2::ExifData::const_iterator it2 = exifData.findKey(key2);
-
-                if (it2 != exifData.end())
-                {
-                    QString exifComment    = d->convertCommentValue(*it2);
-                    QString trimmedComment = exifComment.trimmed();
-
-                    // Some cameras fill in nonsense default values
-
-                    blackList << QLatin1String("SONY DSC"); // + whitespace
-                    blackList << QLatin1String("OLYMPUS DIGITAL CAMERA");
-                    blackList << QLatin1String("MINOLTA DIGITAL CAMERA");
-
-                    // some cameras fill the UserComment with whitespace
-
-                    if (!exifComment.isEmpty() && !trimmedComment.isEmpty() && !blackList.contains(trimmedComment))
-                    {
-                        return exifComment;
-                    }
-                }
-            }
         }
     }
     catch (Exiv2::AnyError& e)
@@ -299,9 +309,16 @@ bool MetaEngine::setExifComment(const QString& comment, bool writeDescription) c
 
             // Write as Unicode only when necessary.
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+            auto latin1Codec         = QStringEncoder(QStringEncoder::Latin1);
+            QByteArray encodedString = latin1Codec(comment);
+
+            if (!encodedString.isEmpty() && !latin1Codec.hasError())
+#else
             QTextCodec* const latin1Codec = QTextCodec::codecForName("iso8859-1");
 
             if (latin1Codec && latin1Codec->canEncode(comment))
+#endif
             {
                 // We know it's in the ISO-8859-1 8bit range.
                 // Check if it's in the ASCII 7bit range
@@ -520,7 +537,11 @@ bool MetaEngine::setExifTagData(const char* exifTagName, const QByteArray& data)
 bool MetaEngine::setExifTagVariant(const char* exifTagName, const QVariant& val,
                                    bool rationalWantSmallDenominator) const
 {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+    switch (val.typeId())
+#else
     switch (val.type())
+#endif
     {
         case QVariant::Int:
         case QVariant::UInt:
@@ -620,7 +641,11 @@ QString MetaEngine::createExifUserStringFromValue(const char* exifTagName, const
         Exiv2::ExifKey key(exifTagName);
         Exiv2::Exifdatum datum(key);
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+        switch (val.typeId())
+#else
         switch (val.type())
+#endif
         {
             case QVariant::Int:
             case QVariant::Bool:
@@ -739,8 +764,11 @@ bool MetaEngine::getExifTagLong(const char* exifTagName, long& val, int componen
 
         if ((it != exifData.end()) && (it->count() > 0))
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            val = it->toInt64(component);
+#else
             val = it->toLong(component);
-
+#endif
             return true;
         }
     }
@@ -769,10 +797,8 @@ QByteArray MetaEngine::getExifTagData(const char* exifTagName) const
 
         if (it != exifData.end())
         {
-            char* const s = new char[(*it).size()];
-            (*it).copy((Exiv2::byte*)s, Exiv2::bigEndian);
-            QByteArray data(s, (*it).size());
-            delete[] s;
+            QByteArray data((*it).size(), '\0');
+            (*it).copy((Exiv2::byte*)data.data(), Exiv2::bigEndian);
 
             return data;
         }
@@ -812,11 +838,19 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
                 {
                     if ((int)it->count() > component)
                     {
+#if EXIV2_TEST_VERSION(0,27,99)
+                        return QVariant((int)it->toInt64(component));
+#else
                         return QVariant((int)it->toLong(component));
+#endif
                     }
                     else
                     {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                        return QVariant(QMetaType(QMetaType::Int));
+#else
                         return QVariant(QVariant::Int);
+#endif
                     }
                 }
 
@@ -827,20 +861,32 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
                     {
                         if ((int)it->count() <= component)
                         {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                            return QVariant(QMetaType(QMetaType::QVariantList));
+#else
                             return QVariant(QVariant::List);
+#endif
                         }
 
                         QList<QVariant> list;
                         list << (*it).toRational(component).first;
                         list << (*it).toRational(component).second;
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                        return QVariant(QMetaType(QMetaType::QVariantList));
+#else
                         return QVariant(list);
+#endif
                     }
                     else
                     {
                         if ((int)it->count() <= component)
                         {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                            return QVariant(QMetaType(QMetaType::Double));
+#else
                             return QVariant(QVariant::Double);
+#endif
                         }
 
                         // prefer double precision
@@ -850,7 +896,11 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
 
                         if (den == 0.0)
                         {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+                            return QVariant(QMetaType(QMetaType::Double));
+#else
                             return QVariant(QVariant::Double);
+#endif
                         }
 
                         return QVariant(num / den);
@@ -915,7 +965,14 @@ QString MetaEngine::getExifTagString(const char* exifTagName, bool escapeCR) con
             QString tagValue;
             QString key = QLatin1String(it->key().c_str());
 
-            if ((key == QLatin1String("Exif.CanonCs.LensType")) && (it->toLong() == 65535))
+            if (
+                (key == QLatin1String("Exif.CanonCs.LensType")) &&
+#if EXIV2_TEST_VERSION(0,27,99)
+                (it->toInt64() == 65535)
+#else
+                (it->toLong()  == 65535)
+#endif
+               )
             {
                 // FIXME: workaround for a possible crash in Exiv2 pretty-print function for the Exif.CanonCs.LensType.
 
@@ -987,12 +1044,21 @@ QImage MetaEngine::getExifThumbnail(bool fixOrientation) const
         Exiv2::ExifThumbC thumb(d->exifMetadata());
         Exiv2::DataBuf const c1 = thumb.copy();
 
+#if EXIV2_TEST_VERSION(0,27,99)
+        if (c1.size() == 0)
+        {
+            return thumbnail;
+        }
+
+        thumbnail.loadFromData(c1.c_data(), c1.size());
+#else
         if (c1.size_ == 0)
         {
             return thumbnail;
         }
 
         thumbnail.loadFromData(c1.pData_, c1.size_);
+#endif
 
         if (!thumbnail.isNull())
         {
@@ -1010,7 +1076,11 @@ QImage MetaEngine::getExifThumbnail(bool fixOrientation) const
 
                 if (it != exifData.end() && it->count())
                 {
+#if EXIV2_TEST_VERSION(0,27,99)
+                    long orientation = it->toInt64();
+#else
                     long orientation = it->toLong();
+#endif
 
                     //qCDebug(DIGIKAM_METAENGINE_LOG) << "Exif Thumbnail Orientation: " << (int)orientation;
 
@@ -1035,7 +1105,7 @@ QImage MetaEngine::getExifThumbnail(bool fixOrientation) const
 
 bool MetaEngine::rotateExifQImage(QImage& image, ImageOrientation orientation) const
 {
-    QMatrix matrix = MetaEngineRotation::toMatrix(orientation);
+    QTransform matrix = MetaEngineRotation::toTransform(orientation);
 
     if ((orientation != ORIENTATION_NORMAL) && (orientation != ORIENTATION_UNSPECIFIED))
     {
@@ -1092,7 +1162,15 @@ bool MetaEngine::setTiffThumbnail(const QImage& thumbImage) const
 
         Exiv2::ExifData::const_iterator pos = d->exifMetadata().findKey(Exiv2::ExifKey("Exif.Image.NewSubfileType"));
 
-        if ((pos == d->exifMetadata().end()) || (pos->count() != 1) || (pos->toLong() != 0))
+        if (
+            (pos            == d->exifMetadata().end()) ||
+            (pos->count()   != 1)                       ||
+#if EXIV2_TEST_VERSION(0,27,99)
+            (pos->toInt64() != 0)
+#else
+            (pos->toLong()  != 0)
+#endif
+           )
         {
 
 #if EXIV2_TEST_VERSION(0,27,0)
@@ -1136,9 +1214,17 @@ bool MetaEngine::setTiffThumbnail(const QImage& thumbImage) const
             Exiv2::DataBuf buf((Exiv2::byte*)data.data(), data.size());
             Exiv2::ULongValue val;
             val.read("0");
+#if EXIV2_TEST_VERSION(0,27,99)
+            val.setDataArea(buf.data(), buf.size());
+#else
             val.setDataArea(buf.pData_, buf.size_);
+#endif
             d->exifMetadata()["Exif.SubImage1.JPEGInterchangeFormat"]       = val;
+#if EXIV2_TEST_VERSION(0,27,99)
+            d->exifMetadata()["Exif.SubImage1.JPEGInterchangeFormatLength"] = uint32_t(buf.size());
+#else
             d->exifMetadata()["Exif.SubImage1.JPEGInterchangeFormatLength"] = uint32_t(buf.size_);
+#endif
             d->exifMetadata()["Exif.SubImage1.Compression"]                 = uint16_t(6);          // JPEG (old-style)
             d->exifMetadata()["Exif.SubImage1.NewSubfileType"]              = uint32_t(1);          // Thumbnail image
 
@@ -1261,7 +1347,14 @@ MetaEngine::MetaDataMap MetaEngine::getExifTagsDataList(const QStringList& exifK
             {
                 tagValue = QString::number(md->value().size());
             }
-            else if (key == QLatin1String("Exif.CanonCs.LensType") && md->toLong() == 65535)
+            else if (
+                     (key           == QLatin1String("Exif.CanonCs.LensType")) && 
+#if EXIV2_TEST_VERSION(0,27,99)
+                     (md->toInt64() == 65535)
+#else
+                     (md->toLong()  == 65535)
+#endif
+                    )
             {
                 // FIXME: workaround for a possible crash in Exiv2 pretty-print function for the Exif.CanonCs.LensType.
 
