@@ -7,19 +7,10 @@
  * Description : Exiv2 library interface.
  *               File I/O methods
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -49,21 +40,20 @@ QString MetaEngine::getFilePath() const
     return d->filePath;
 }
 
-QString MetaEngine::sidecarFilePathForFile(const QString& path, bool useLR)
+QString MetaEngine::sidecarFilePathForFile(const QString& path)
 {
     if (path.isEmpty())
     {
         return QString();
     }
 
-    QFileInfo info(path);
-    QString pathForLR = path;
-    pathForLR.chop(info.suffix().size());
-    pathForLR.append(QLatin1String("xmp"));
-
-    if (useLR || QFileInfo::exists(pathForLR))
+    if (MetaEngineSettings::instance()->settings().useCompatibleFileName)
     {
-        return pathForLR;
+        QFileInfo info(path);
+        QString pathBaseXmp = path;
+        pathBaseXmp.chop(info.suffix().size());
+
+        return pathBaseXmp + QLatin1String("xmp");
     }
 
     return path + QLatin1String(".xmp");
@@ -113,6 +103,11 @@ QString MetaEngine::backendName(Backend t)
             return QLatin1String("FFMpeg");
         }
 
+        case ExifToolBackend:
+        {
+            return QLatin1String("ExifTool");
+        }
+
         case NoBackend:
         {
             return QLatin1String("No Backend");
@@ -142,6 +137,8 @@ bool MetaEngine::load(const QString& filePath, Backend* backend)
 
     QMutexLocker lock(&s_metaEngineMutex);
 
+    s_metaEngineWarnOrError = false;
+
     try
     {
         Exiv2::Image::AutoPtr image;
@@ -186,6 +183,10 @@ bool MetaEngine::load(const QString& filePath, Backend* backend)
 
 #endif // _XMP_SUPPORT_
 
+        if (s_metaEngineWarnOrError)
+        {
+            return false;
+        }
 
         if (backend)
         {
@@ -381,11 +382,11 @@ bool MetaEngine::save(const QString& imageFilePath, bool setVersion) const
 
         if (!dinfo.isWritable())
         {
-            writtenToSidecar = d->saveToXMPSidecar(imageFilePath);
+            writtenToSidecar = d->saveToXMPSidecar(QFileInfo(imageFilePath));
         }
         else
         {
-            writtenToSidecar = d->saveToXMPSidecar(regularFilePath);
+            writtenToSidecar = d->saveToXMPSidecar(QFileInfo(regularFilePath));
         }
 
         if (writtenToSidecar)
@@ -408,7 +409,7 @@ bool MetaEngine::applyChanges(bool setVersion) const
     return save(d->filePath, setVersion);
 }
 
-bool MetaEngine::exportChanges(const QString& exvTmpFile, QStringList& removedTags) const
+bool MetaEngine::exportChanges(const QString& exvTmpFile) const
 {
     if (d->filePath.isEmpty())
     {
@@ -420,174 +421,19 @@ bool MetaEngine::exportChanges(const QString& exvTmpFile, QStringList& removedTa
 
     try
     {
-        Exiv2::Image::AutoPtr image;
+        // Create target EXV container.
 
-        qCDebug(DIGIKAM_METAENGINE_LOG) << "List of changes to perform on:" << getFilePath();
-
-#if defined Q_OS_WIN && defined EXV_UNICODE_PATH
-
-        image = Exiv2::ImageFactory::open((const wchar_t*)getFilePath().utf16());
-
-#elif defined Q_OS_WIN
-
-        image = Exiv2::ImageFactory::open(QFile::encodeName(getFilePath()).constData());
-
-#else
-
-        image = Exiv2::ImageFactory::open(getFilePath().toUtf8().constData());
-
-#endif
-
-        image->readMetadata();
-
-        // --- Parse differences in Exif
-
-        Exiv2::ExifData orgExif = image->exifData();
-        Exiv2::ExifData newExif = d->exifMetadata();
-        Exiv2::ExifData chgExif;
-
-        for (Exiv2::ExifData::const_iterator it = newExif.begin() ; it != newExif.end() ; ++it)
-        {
-            Exiv2::ExifData::const_iterator it2 = orgExif.findKey(Exiv2::ExifKey(it->key()));
-
-            if      (it2 == orgExif.end())
-            {
-                // Original Exif do not have the tag.
-
-                chgExif[it->key().c_str()] = newExif[it->key().c_str()];
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "New Exif tag" << it->key().c_str()
-                                                << "with value"   << it->toString().c_str();
-            }
-            else if (getExifTagData(it2->key().c_str()) != getExifTagData(it->key().c_str()))
-            {
-                // Original Exif has already the tag.
-
-                chgExif[it->key().c_str()] = newExif[it->key().c_str()];
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "Changed Exif tag" << it->key().c_str()
-                                                << "old value"        << it2->toString().c_str()
-                                                << "new value"        << it->toString().c_str();
-            }
-        }
-
-        // Check for removed Exif tags.
-
-        for (Exiv2::ExifData::const_iterator it = orgExif.begin() ; it != orgExif.end() ; ++it)
-        {
-            Exiv2::ExifData::const_iterator it2 = newExif.findKey(Exiv2::ExifKey(it->key()));
-
-            if (it2 == newExif.end())
-            {
-                // New Exif do not have the tag.
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "Removed Exif tag" << it->key().c_str();
-                removedTags <<  QString::fromStdString(it->key());
-            }
-        }
-
-        // --- Parse differences in Iptc
-
-        Exiv2::IptcData orgIptc = image->iptcData();
-        Exiv2::IptcData newIptc = d->iptcMetadata();
-        Exiv2::IptcData chgIptc;
-
-        for (Exiv2::IptcData::const_iterator it = newIptc.begin() ; it != newIptc.end() ; ++it)
-        {
-            Exiv2::IptcData::const_iterator it2 = orgIptc.findKey(Exiv2::IptcKey(it->key()));
-
-            if      (it2 == orgIptc.end())
-            {
-                // Original Iptc do not have the tag.
-
-                chgIptc[it->key().c_str()] = newIptc[it->key().c_str()];
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "New Iptc tag" << it->key().c_str()
-                                                << "with value"   << it->toString().c_str();
-            }
-            else if (getIptcTagData(it2->key().c_str()) != getIptcTagData(it->key().c_str()))
-            {
-                // Original Iptc has already the tag.
-
-                chgIptc[it->key().c_str()] = newIptc[it->key().c_str()];
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "Changed Iptc tag" << it->key().c_str()
-                                                << "old value"        << it2->toString().c_str()
-                                                << "new value"        << it->toString().c_str();
-            }
-        }
-
-        // Check for removed Iptc tags.
-
-        for (Exiv2::IptcData::const_iterator it = orgIptc.begin() ; it != orgIptc.end() ; ++it)
-        {
-            Exiv2::IptcData::const_iterator it2 = newIptc.findKey(Exiv2::IptcKey(it->key()));
-
-            if (it2 == newIptc.end())
-            {
-                // New Iptc do not have the tag.
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "Removed Iptc tag" << it->key().c_str();
-                removedTags <<  QString::fromStdString(it->key());
-            }
-        }
+        Exiv2::Image::AutoPtr targetExv = Exiv2::ImageFactory::create(Exiv2::ImageType::exv, exvTmpFile.toStdString());
+        targetExv->setComment(d->itemComments());
+        targetExv->setExifData(d->exifMetadata());
+        targetExv->setIptcData(d->iptcMetadata());
 
 #ifdef _XMP_SUPPORT_
 
-        // --- Parse differences in Xmp
-
-        Exiv2::XmpData orgXmp = image->xmpData();
-        Exiv2::XmpData newXmp = d->xmpMetadata();
-        Exiv2::XmpData chgXmp;
-
-        for (Exiv2::XmpData::const_iterator it = newXmp.begin() ; it != newXmp.end() ; ++it)
-        {
-            Exiv2::XmpData::const_iterator it2 = orgXmp.findKey(Exiv2::XmpKey(it->key()));
-
-            if      (it2 == orgXmp.end())
-            {
-                // Original Xmp do not have the tag.
-
-                chgXmp[it->key().c_str()] = newXmp[it->key().c_str()];
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "New Xmp tag" << it->key().c_str()
-                                                << "with value"  << it->toString().c_str();
-            }
-            else if (getXmpTagVariant(it2->key().c_str()) != getXmpTagVariant(it->key().c_str()))
-            {
-                // Original Xmp has already the tag.
-
-                chgXmp[it->key().c_str()] = newXmp[it->key().c_str()];
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "Changed Xmp tag" << it->key().c_str()
-                                                << "old value"       << it2->toString().c_str()
-                                                << "new value"       << it->toString().c_str();
-            }
-        }
-
-        // Check for removed Xmp tags.
-
-        for (Exiv2::XmpData::const_iterator it = orgXmp.begin() ; it != orgXmp.end() ; ++it)
-        {
-            Exiv2::XmpData::const_iterator it2 = newXmp.findKey(Exiv2::XmpKey(it->key()));
-
-            if (it2 == newXmp.end())
-            {
-                // New Xmp do not have the tag.
-
-                qCDebug(DIGIKAM_METAENGINE_LOG) << "Removed Xmp tag" << it->key().c_str();
-                removedTags <<  QString::fromStdString(it->key());
-            }
-        }
+        targetExv->setXmpData(d->xmpMetadata());
 
 #endif // _XMP_SUPPORT_
 
-        // Create target EXV container with list of changed tags.
-
-        Exiv2::Image::AutoPtr targetExv = Exiv2::ImageFactory::create(Exiv2::ImageType::exv, exvTmpFile.toStdString());
-        targetExv->setExifData(chgExif);
-        targetExv->setIptcData(chgIptc);
-        targetExv->setXmpData(chgXmp);
         targetExv->writeMetadata();
 
         return true;
