@@ -7,20 +7,11 @@
  * Description : Exiv2 library interface.
  *               GPS manipulation methods
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2012 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2010-2012 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -38,6 +29,7 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "geodetictools.h"
 
 #if defined(Q_CC_CLANG)
 #   pragma clang diagnostic push
@@ -254,69 +246,73 @@ bool MetaEngine::getGPSAltitude(double* const altitude) const
 
         // Try XMP first. Reason: XMP in sidecar may be more up-to-date than EXIF in original image.
 
-        const QString altRefXmp = getXmpTagString("Xmp.exif.GPSAltitudeRef");
+        QString altRefXmp = getXmpTagString("Xmp.exif.GPSAltitudeRef");
 
-        if (!altRefXmp.isEmpty())
+        if (altRefXmp.isEmpty())
         {
-            const QString altXmp = getXmpTagString("Xmp.exif.GPSAltitude");
-
-            if (!altXmp.isEmpty())
-            {
-                num = altXmp.section(QLatin1Char('/'), 0, 0).toDouble();
-                den = altXmp.section(QLatin1Char('/'), 1, 1).toDouble();
-
-                if (den == 0)
-                {
-                    return false;
-                }
-
-                *altitude = num/den;
-
-                if (altRefXmp == QLatin1String("1"))
-                {
-                    *altitude *= -1.0;
-                }
-
-                return true;
-            }
+            altRefXmp = QLatin1String("0");
         }
 
-        // Get the reference from Exif (above/below sea level)
+        const QString altXmp = getXmpTagString("Xmp.exif.GPSAltitude");
 
-        const QByteArray altRef = getExifTagData("Exif.GPSInfo.GPSAltitudeRef");
-
-        if (!altRef.isEmpty())
+        if (!altXmp.isEmpty())
         {
-            // Altitude decoding from Exif.
+            num = altXmp.section(QLatin1Char('/'), 0, 0).toDouble();
+            den = altXmp.section(QLatin1Char('/'), 1, 1).toDouble();
 
-            Exiv2::ExifKey exifKey3("Exif.GPSInfo.GPSAltitude");
-            Exiv2::ExifData exifData(d->exifMetadata());
-            Exiv2::ExifData::const_iterator it = exifData.findKey(exifKey3);
-
-            if (it != exifData.end() && (*it).count())
-            {
-                num = (double)((*it).toRational(0).first);
-                den = (double)((*it).toRational(0).second);
-
-                if (den == 0)
-                {
-                    return false;
-                }
-
-                *altitude = num / den;
-            }
-            else
+            if (den == 0)
             {
                 return false;
             }
 
-            if (altRef[0] == '1')
+            *altitude = num/den;
+
+            if (altRefXmp == QLatin1String("1"))
             {
                 *altitude *= -1.0;
             }
 
             return true;
         }
+
+        // Get the reference from Exif (above/below sea level)
+
+        QByteArray altRef = getExifTagData("Exif.GPSInfo.GPSAltitudeRef");
+
+        if (altRef.isEmpty())
+        {
+            altRef = "0";
+        }
+
+        // Altitude decoding from Exif.
+
+        Exiv2::ExifKey exifKey3("Exif.GPSInfo.GPSAltitude");
+        Exiv2::ExifData exifData(d->exifMetadata());
+        Exiv2::ExifData::const_iterator it = exifData.findKey(exifKey3);
+
+        if (it != exifData.end() && (*it).count())
+        {
+            num = (double)((*it).toRational(0).first);
+            den = (double)((*it).toRational(0).second);
+
+            if (den == 0)
+            {
+                return false;
+            }
+
+            *altitude = num / den;
+
+            if (altRef[0] == '1')
+            {
+                *altitude *= -1.0;
+            }
+        }
+        else
+        {
+            return false;
+        }
+
+        return true;
     }
     catch (Exiv2::AnyError& e)
     {
@@ -406,9 +402,27 @@ bool MetaEngine::setGPSInfo(const double* const altitude, const double latitude,
 
     try
     {
-        // In first, we need to clean up all existing GPS info.
+        // In first, we need to clean up all existing GPS info
+        // if the coordinate deviation is greater than 100 m.
 
-        removeGPSInfo();
+        double lat = 0.0;
+        double lon = 0.0;
+
+        if (getGPSLatitudeNumber(&lat) && getGPSLongitudeNumber(&lon))
+        {
+            GeodeticCalculator calc;
+            calc.setStartingGeographicPoint(lon, lat);
+            calc.setDestinationGeographicPoint(longitude, latitude);
+
+            if (calc.orthodromicDistance() > 100.0)
+            {
+                removeGPSInfo();
+            }
+        }
+        else
+        {
+            removeGPSInfo();
+        }
 
         // now re-initialize the GPS info:
 
@@ -600,8 +614,8 @@ bool MetaEngine::removeGPSInfo()
          * them in setGPSInfo(), we should also remove them here.
          * See bug #450982.
          */
-        removeXmpTag("Xmp.exif.GPSLongitudeRef");
         removeXmpTag("Xmp.exif.GPSLatitudeRef");
+        removeXmpTag("Xmp.exif.GPSLongitudeRef");
 
         removeXmpTag("Xmp.exif.GPSVersionID");
         removeXmpTag("Xmp.exif.GPSLatitude");
