@@ -7,19 +7,10 @@
  * Description : Exiv2 library interface.
  *               Common metadata image information manipulation methods
  *
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -127,7 +118,11 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it != exifData.end()) && it->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            width = it->toInt64();
+#else
             width = it->toLong();
+#endif
         }
 
         Exiv2::ExifKey key2("Exif.Photo.PixelYDimension");
@@ -135,7 +130,11 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it2 != exifData.end()) && it2->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            height = it2->toInt64();
+#else
             height = it2->toLong();
+#endif
         }
 
         if ((width != -1) && (height != -1))
@@ -153,7 +152,11 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it3 != exifData.end()) && it3->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            width = it3->toInt64();
+#else
             width = it3->toLong();
+#endif
         }
 
         Exiv2::ExifKey key4("Exif.Image.ImageLength");
@@ -161,7 +164,11 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it4 != exifData.end()) && it4->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            height = it4->toInt64();
+#else
             height = it4->toLong();
+#endif
         }
 
         if ((width != -1) && (height != -1))
@@ -320,7 +327,11 @@ MetaEngine::ImageOrientation MetaEngine::getItemOrientation() const
 
         if ((it != exifData.end()) && it->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            orientation = it->toInt64();
+#else
             orientation = it->toLong();
+#endif
 
             //qCDebug(DIGIKAM_METAENGINE_LOG) << "Orientation => Exif.MinoltaCs7D.Rotation =>" << (int)orientation;
 
@@ -347,7 +358,11 @@ MetaEngine::ImageOrientation MetaEngine::getItemOrientation() const
 
         if ((it != exifData.end()) && it->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            orientation = it->toInt64();
+#else
             orientation = it->toLong();
+#endif
 
             //qCDebug(DIGIKAM_METAENGINE_LOG) << "Orientation => Exif.MinoltaCs5D.Rotation =>" << (int)orientation;
 
@@ -376,7 +391,11 @@ MetaEngine::ImageOrientation MetaEngine::getItemOrientation() const
 
         if ((it != exifData.end()) && it->count())
         {
+#if EXIV2_TEST_VERSION(0,27,99)
+            orientation = it->toInt64();
+#else
             orientation = it->toLong();
+#endif
 
             //qCDebug(DIGIKAM_METAENGINE_LOG) << "Orientation => Exif.Image.Orientation =>" << (int)orientation;
 
