@@ -6,21 +6,12 @@
  * Date        : 2004-11-17
  * Description : item properties side bar using data from digiKam database.
  *
- * Copyright (C) 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2011 by Martin Klapetek <martin dot klapetek at gmail dot com>
- * Copyright (C)      2011 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2010-2011 by Martin Klapetek <martin dot klapetek at gmail dot com>
+ * SPDX-FileCopyrightText:      2011 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -57,6 +48,7 @@
 #include "itempropertiesversionstab.h"
 #include "itemposition.h"
 #include "tagscache.h"
+#include "dtrash.h"
 
 #ifdef HAVE_MARBLE
 #   include "itempropertiesgpstab.h"
@@ -156,6 +148,16 @@ void ItemPropertiesSideBarDB::itemChanged(const QUrl& url,
 
     m_currentURL = url;
 
+    // Special case if item come from a trash view. ItemInfo will be empty as item is removed from the database.
+    // We need to use the DMetadata based method to populated the properties view.
+
+    if (url.path().contains(DTrash::TRASH_FOLDER))
+    {
+        ItemPropertiesSideBar::itemChanged(url);
+
+        return;
+    }
+
     ItemInfoList list;
 
     if (!info.isNull())
@@ -186,19 +188,21 @@ void ItemPropertiesSideBarDB::itemChanged(const ItemInfoList& infos,
                                           DImg* const img,
                                           const DImageHistory& history)
 {
+    bool changedInfos    = (d->currentInfos == infos);
+    m_dirtyPropertiesTab = (changedInfos && (d->allInfos == allInfos));
+    m_dirtyMetadataTab   = changedInfos;
+    m_dirtyColorTab      = (changedInfos && (m_image == img) && (m_currentRect == rect));
+    m_dirtyGpsTab        = changedInfos;
+    m_dirtyHistoryTab    = (changedInfos && (d->currentHistory == history));
+    d->dirtyDesceditTab  = changedInfos;
+
     m_currentRect        = rect;
     m_image              = img;
     d->currentHistory    = history;
     d->currentInfos      = infos;
     d->allInfos          = allInfos;
-    m_dirtyPropertiesTab = false;
-    m_dirtyMetadataTab   = false;
-    m_dirtyColorTab      = false;
-    m_dirtyGpsTab        = false;
-    m_dirtyHistoryTab    = false;
-    d->dirtyDesceditTab  = false;
 
-    // slotChangedTab only handles the active tab.
+    // changedTab only handles the active tab.
     // Any tab that holds information reset above shall be reset here,
     // unless it is the active tab.
 
@@ -207,7 +211,7 @@ void ItemPropertiesSideBarDB::itemChanged(const ItemInfoList& infos,
         d->desceditTab->setItem();
     }
 
-    slotChangedTab(getActiveTab());
+    changedTab(getActiveTab());
 }
 
 void ItemPropertiesSideBarDB::slotNoCurrentItem()
@@ -215,7 +219,7 @@ void ItemPropertiesSideBarDB::slotNoCurrentItem()
     ItemPropertiesSideBar::slotNoCurrentItem();
 
     // All tabs that store the ItemInfo list and access it after selection change
-    // must release the image info here. slotChangedTab only handles the active tab!
+    // must release the image info here. changedTab only handles the active tab!
 
     d->desceditTab->setItem();
     d->currentInfos.clear();
@@ -228,6 +232,18 @@ void ItemPropertiesSideBarDB::populateTags()
 }
 
 void ItemPropertiesSideBarDB::slotChangedTab(QWidget* tab)
+{
+    m_dirtyPropertiesTab = false;
+    m_dirtyMetadataTab   = false;
+    m_dirtyColorTab      = false;
+    m_dirtyGpsTab        = false;
+    m_dirtyHistoryTab    = false;
+    d->dirtyDesceditTab  = false;
+
+    changedTab(tab);
+}
+
+void ItemPropertiesSideBarDB::changedTab(QWidget* const tab)
 {
     setCursor(Qt::WaitCursor);
 
@@ -403,9 +419,9 @@ void ItemPropertiesSideBarDB::slotFileMetadataChanged(const QUrl& url)
 
         if (getActiveTab() == m_metadataTab)
         {
-            // update now - reuse code form slotChangedTab
+            // update now - reuse code form changedTab
 
-            slotChangedTab(getActiveTab());
+            changedTab(getActiveTab());
         }
     }
 }
@@ -421,7 +437,7 @@ void ItemPropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& chan
             return;
         }
 
-        if ((tab == m_propertiesStackedView)
+        if      ((tab == m_propertiesStackedView)
 
 #ifdef HAVE_MARBLE
 
@@ -462,9 +478,23 @@ void ItemPropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& chan
 
                    )
                 {
-                    // update now - reuse code form slotChangedTab
+                    // update now - reuse code form changedTab
 
-                    slotChangedTab(tab);
+                    changedTab(tab);
+                }
+            }
+        }
+        else if ((tab == d->desceditTab) && d->desceditTab->isModified())
+        {
+            ItemInfo& info = d->currentInfos.first();
+
+            if (changeset.ids().contains(info.id()))
+            {
+                DatabaseFields::Set set = changeset.changes();
+
+                if (set & DatabaseFields::Rating)
+                {
+                    d->desceditTab->replaceRating(info.rating());
                 }
             }
         }
@@ -482,14 +512,42 @@ void ItemPropertiesSideBarDB::slotImageTagChanged(const ImageTagChangeset& chang
             return;
         }
 
-        if (tab == m_propertiesStackedView)
+        if      (tab == m_propertiesStackedView)
         {
             ItemInfo& info = d->currentInfos.first();
 
             if (changeset.ids().contains(info.id()))
             {
                 m_dirtyPropertiesTab = false;
-                slotChangedTab(tab);
+                changedTab(tab);
+            }
+        }
+        else if ((tab == d->desceditTab) && d->desceditTab->isModified())
+        {
+            ItemInfo& info = d->currentInfos.first();
+
+            if (changeset.ids().contains(info.id()))
+            {
+                QVector<int> colorLabelTags = TagsCache::instance()->colorLabelTags();
+                QVector<int> pickLabelTags  = TagsCache::instance()->pickLabelTags();
+
+                Q_FOREACH (int ctag, changeset.tags())
+                {
+                    if (colorLabelTags.contains(ctag))
+                    {
+                        d->desceditTab->replaceColorLabel(info.colorLabel());
+                        break;
+                    }
+                }
+
+                Q_FOREACH (int ptag, changeset.tags())
+                {
+                    if (pickLabelTags.contains(ptag))
+                    {
+                        d->desceditTab->replacePickLabel(info.pickLabel());
+                        break;
+                    }
+                }
             }
         }
     }
@@ -540,10 +598,10 @@ void ItemPropertiesSideBarDB::refreshTagsView()
 
 void ItemPropertiesSideBarDB::setImagePropertiesInformation(const QUrl& url)
 {
-    foreach (const ItemInfo& info, d->currentInfos)
+    Q_FOREACH (const ItemInfo& info, d->currentInfos)
     {
         if (info.fileUrl() == url)
-        {
+        {   // cppcheck-suppress useStlAlgorithm
             QString str;
             QString unavailable(QString::fromUtf8("<i>%1</i>").arg(i18nc("@info: item properties", "unavailable")));
             QFileInfo fileInfo(url.toLocalFile());
@@ -688,8 +746,9 @@ void ItemPropertiesSideBarDB::setImageSelectionPropertiesInformation()
 
     qint64 selectionFileSize = 0;
 
-    foreach (const ItemInfo& info, d->currentInfos)
+    Q_FOREACH (const ItemInfo& info, d->currentInfos)
     {
+        // cppcheck-suppress useStlAlgorithm
         selectionFileSize += info.fileSize();
     }
 
@@ -701,8 +760,9 @@ void ItemPropertiesSideBarDB::setImageSelectionPropertiesInformation()
 
     qint64 totalFileSize = 0;
 
-    foreach (const ItemInfo& info, d->allInfos)
+    Q_FOREACH (const ItemInfo& info, d->allInfos)
     {
+        // cppcheck-suppress useStlAlgorithm
         totalFileSize += info.fileSize();
     }
 
