@@ -6,24 +6,19 @@
  * Date        : 2000-12-05
  * Description : helper class used to modify tag albums in views
  *
- * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2010 by Johannes Wienke <languitar at semipol dot de>
+ * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
 #include "tagmodificationhelper.h"
 
+// C++ includes
+
+#include <iterator>
+
 // Qt includes
 
 #include <QApplication>
@@ -155,10 +150,10 @@ TAlbum* TagModificationHelper::slotTagNew(TAlbum* parent, const QString& title,
     {
         TAlbum* tag = nullptr;
 
-        foreach (Album* const album, tList)
+        Q_FOREACH (Album* const album, tList)
         {
             tag = static_cast<TAlbum*>(album);
-            emit tagCreated(tag);
+            Q_EMIT tagCreated(tag);
         }
 
         return tag;
@@ -229,7 +224,7 @@ void TagModificationHelper::slotTagEdit(TAlbum* t)
         TagsActionMngr::defaultManager()->updateTagShortcut(tag->id(), ks);
     }
 
-    emit tagEdited(tag);
+    Q_EMIT tagEdited(tag);
 }
 
 void TagModificationHelper::slotTagEdit()
@@ -296,13 +291,13 @@ void TagModificationHelper::slotTagDelete(TAlbum* t)
         message = i18n("Delete '%1' tag?", tag->title());
     }
 
-    int result = QMessageBox::warning(qApp->activeWindow(), i18n("Delete Tag"),
+    int result = QMessageBox::warning(qApp->activeWindow(), i18nc("@title:window", "Delete Tag"),
                                       message,
                                       QMessageBox::Yes | QMessageBox::Cancel);
 
     if (result == QMessageBox::Yes && tag)
     {
-        emit aboutToDeleteTag(tag);
+        Q_EMIT aboutToDeleteTag(tag);
         QString errMsg;
 
         if (!AlbumManager::instance()->deleteTAlbum(tag, errMsg))
@@ -324,7 +319,7 @@ void TagModificationHelper::slotMultipleTagDel(const QList<TAlbum*>& tags)
     QString tagWithImages;
     QMultiMap<int, TAlbum*> sortedTags;
 
-    foreach (TAlbum* const t, tags)
+    Q_FOREACH (TAlbum* const t, tags)
     {
         if (!t || t->isRoot())
         {
@@ -409,7 +404,7 @@ void TagModificationHelper::slotMultipleTagDel(const QList<TAlbum*>& tags)
         message = i18n("Delete '%1' tag(s)?", tagWithoutImages);
     }
 
-    int result = QMessageBox::warning(qApp->activeWindow(), i18n("Delete Tag"),
+    int result = QMessageBox::warning(qApp->activeWindow(), i18nc("@title:window", "Delete Tag"),
                                       message,
                                       QMessageBox::Yes | QMessageBox::Cancel);
 
@@ -422,9 +417,9 @@ void TagModificationHelper::slotMultipleTagDel(const QList<TAlbum*>& tags)
          * because end() points after the last element
          */
 
-        for (it = sortedTags.end()-1 ; it != sortedTags.begin()-1 ; --it)
+        for (it = std::prev(sortedTags.end(), 1) ; it != std::prev(sortedTags.begin(), 1) ; --it)
         {
-            emit aboutToDeleteTag(it.value());
+            Q_EMIT aboutToDeleteTag(it.value());
             QString errMsg;
 
             if (!AlbumManager::instance()->deleteTAlbum(it.value(), errMsg))
@@ -467,13 +462,11 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
     QList<qlonglong> allAssignedItems;
     int tagsWithImagesCount   = 0;
 
-    foreach (TAlbum* const selectedTag, tags)
+    Q_FOREACH (TAlbum* const selectedTag, tags)
     {
-        if (!selectedTag                                            ||
-            selectedTag->isRoot()                                   ||
-            (selectedTag->id() == FaceTags::unknownPersonTagId())   ||
-            (selectedTag->id() == FaceTags::ignoredPersonTagId())   ||
-            (selectedTag->id() == FaceTags::unconfirmedPersonTagId()))
+        if (!selectedTag                                   ||
+            selectedTag->isRoot()                          ||
+            FaceTags::isSystemPersonTagId(selectedTag->id()))
         {
             continue;
         }
@@ -503,7 +496,7 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
 
         // Get the assigned faces for all person tags to delete
 
-        foreach (TAlbum* const tAlbum, personTagsToDelete)
+        Q_FOREACH (TAlbum* const tAlbum, personTagsToDelete)
         {
             // If the global set does not yet contain the tag
 
@@ -515,7 +508,7 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
                 QList<qlonglong> autodetected  = CoreDbAccess().db()->getImagesWithImageTagProperty(
                     tAlbum->id(), ImageTagPropertyName::autodetectedFace());
 
-                foreach (const qlonglong& id1, autodetected)
+                Q_FOREACH (const qlonglong& id1, autodetected)
                 {
                     if (!assignedItems.contains(id1))
                     {
@@ -527,7 +520,7 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
                 {
                     // Add the items to the global set for potential untagging
 
-                    foreach (const qlonglong& id2, assignedItems)
+                    Q_FOREACH (const qlonglong& id2, assignedItems)
                     {
                         if (!allAssignedItems.contains(id2))
                         {
@@ -548,7 +541,7 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
 
         // Add the found tags to the global set.
 
-        foreach (TAlbum* const album, personTagsToDelete)
+        Q_FOREACH (TAlbum* const album, personTagsToDelete)
         {
             if (!allPersonTagsToDelete.contains(album))
             {
@@ -615,13 +608,11 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
                                                           qApp->applicationName(), msg,
                                                           QMessageBox::Yes | QMessageBox::No));
 
-        MetadataHub metadataHub;
-
         // remove the face region from images and unassign the tag if wished
 
-        foreach (const qlonglong& imageId, allAssignedItems)
+        Q_FOREACH (const qlonglong& imageId, allAssignedItems)
         {
-            foreach (TAlbum* const tagToRemove, allPersonTagsToDelete)
+            Q_FOREACH (TAlbum* const tagToRemove, allPersonTagsToDelete)
             {
                 ItemTagPair imageTagAssociation(imageId, tagToRemove->id());
 
@@ -640,19 +631,18 @@ void TagModificationHelper::slotMultipleFaceTagDel(const QList<TAlbum*>& tags)
 
                         if (!info.isNull())
                         {
-                            metadataHub.load(info);
+                            MetadataHub hub;
+                            hub.load(info);
 
-                            if (!metadataHub.writeToMetadata(info))
-                            {
-                                qCWarning(DIGIKAM_GENERAL_LOG) << "Tags in image not changed:" << info.filePath();
-                            }
+                            ScanController::FileMetadataWrite writeScope(info);
+                            writeScope.changed(hub.writeToMetadata(info, MetadataHub::WRITE_TAGS, true));
                         }
                     }
                 }
             }
         }
 
-        foreach (TAlbum* const tAlbum, allPersonTagsToDelete)
+        Q_FOREACH (TAlbum* const tAlbum, allPersonTagsToDelete)
         {
             TagProperties props(tAlbum->id());
 
@@ -717,7 +707,7 @@ void TagModificationHelper::slotTagToFaceTag()
 
 void TagModificationHelper::slotMultipleTagsToFaceTags(const QList<TAlbum*>& tags)
 {
-    foreach (TAlbum* const selectedTag, tags)
+    Q_FOREACH (TAlbum* const selectedTag, tags)
     {
         slotTagToFaceTag(selectedTag);
     }
@@ -747,7 +737,7 @@ QSet<TAlbum*> TagModificationHelper::getFaceTags(const QList<TAlbum*>& tags)
 {
     QSet<TAlbum*> faceTags;
 
-    foreach (TAlbum* const tAlbum, tags)
+    Q_FOREACH (TAlbum* const tAlbum, tags)
     {
         if (FaceTags::isPerson(tAlbum->id()))
         {
