@@ -6,19 +6,10 @@
  * Date        : 2008-12-10
  * Description : misc file operation methods
  *
- * Copyright (C) 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -42,12 +33,15 @@
 #include <QProcess>
 #include <QDir>
 #include <QFile>
+#include <QFileInfo>
+#include <QSettings>
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QDesktopServices>
-#include <QFileInfo>
 #include <QDirIterator>
+#include <QStandardPaths>
 #include <qplatformdefs.h>
+#include <QRegularExpression>
 
 #ifdef HAVE_DBUS
 #   include <QDBusInterface>
@@ -58,6 +52,7 @@
 
 #include "digikam_debug.h"
 #include "digikam_globals.h"
+#include "dservicemenu.h"
 #include "progressmanager.h"
 #include "metaenginesettings.h"
 
@@ -151,7 +146,21 @@ void DFileOperations::openFilesWithDefaultApplication(const QList<QUrl>& urls)
         return;
     }
 
-    foreach (const QUrl& url, urls)
+#ifdef Q_OS_LINUX
+
+    KService::List offers = DServiceMenu::servicesForOpenWith(urls);
+
+    if (!offers.isEmpty())
+    {
+        KService::Ptr service = offers.first();
+        DServiceMenu::runFiles(service, urls);
+
+        return;
+    }
+
+#endif
+
+    Q_FOREACH (const QUrl& url, urls)
     {
         QDesktopServices::openUrl(url);
     }
@@ -168,13 +177,14 @@ QUrl DFileOperations::getUniqueFileUrl(const QUrl& orgUrl,
     int counter = 0;
     QUrl destUrl(orgUrl);
     QFileInfo fi(destUrl.toLocalFile());
-    QRegExp version(QLatin1String("(.+)_v(\\d+)"));
-    QString completeBaseName = fi.completeBaseName();
+    QRegularExpression version(QRegularExpression::anchoredPattern(QLatin1String("(.+)_v(\\d+)")));
+    QString completeBaseName      = fi.completeBaseName();
+    QRegularExpressionMatch match = version.match(completeBaseName);
 
-    if (version.exactMatch(completeBaseName))
+    if (match.hasMatch())
     {
-        completeBaseName = version.cap(1);
-        counter          = version.cap(2).toInt();
+        completeBaseName = match.captured(1);
+        counter          = match.captured(2).toInt();
     }
 
     if (fi.exists())
@@ -199,7 +209,7 @@ QUrl DFileOperations::getUniqueFileUrl(const QUrl& orgUrl,
                 fileFound = true;
                 destUrl   = destUrl.adjusted(QUrl::RemoveFilename);
                 destUrl.setPath(destUrl.path() + completeBaseName +
-                                QString::fromUtf8("_v%1.").arg(++counter) + fi.completeSuffix());
+                                QString::fromUtf8("_v%1.").arg(++counter) + fi.suffix());
             }
         }
         while (fileFound);
@@ -213,13 +223,14 @@ QUrl DFileOperations::getUniqueFolderUrl(const QUrl& orgUrl)
     int counter              = 0;
     QUrl destUrl(orgUrl);
     QFileInfo fi(destUrl.toLocalFile());
-    QRegExp version(QLatin1String("(.+)-(\\d+)"));
-    QString completeFileName = fi.fileName();
+    QRegularExpression version(QRegularExpression::anchoredPattern(QLatin1String("(.+)-(\\d+)")));
+    QString completeFileName      = fi.fileName();
+    QRegularExpressionMatch match = version.match(completeFileName);
 
-    if (version.exactMatch(completeFileName))
+    if (match.hasMatch())
     {
-        completeFileName = version.cap(1);
-        counter          = version.cap(2).toInt();
+        completeFileName = match.captured(1);
+        counter          = match.captured(2).toInt();
     }
 
     if (fi.exists())
@@ -255,34 +266,59 @@ void DFileOperations::openInFileManager(const QList<QUrl>& urls)
         return;
     }
 
-    bool equal = true;
-    QUrl first = urls.first();
-    first      = first.adjusted(QUrl::RemoveFilename);
+    bool similar = true;
+    QUrl first   = urls.first();
+    first        = first.adjusted(QUrl::RemoveFilename);
 
-    foreach (const QUrl& url, urls)
+    Q_FOREACH (const QUrl& url, urls)
     {
         if (first != url.adjusted(QUrl::RemoveFilename))
         {
-            equal = false;
+            similar = false;
             break;
         }
     }
 
     QList<QUrl> fileUrls;
 
-    if (equal)
+    if (similar)
     {
         fileUrls = urls;
     }
     else
     {
-        fileUrls = QList<QUrl>() << urls.first();
+        fileUrls << urls.first();
     }
 
     QString path = fileUrls.first().toLocalFile();
 
 #ifdef Q_OS_WIN
 
+    QString dopusPath = findExecutable(QLatin1String("DOpus"));
+
+    if (!dopusPath.isEmpty())
+    {
+        QFileInfo dopus(dopusPath);
+
+        if (dopus.exists())
+        {
+            QFileInfo dopusrt(dopus.dir(), QLatin1String("dopusrt.exe"));
+
+            if (dopusrt.exists())
+            {
+                QProcess process;
+                process.setProgram(dopusrt.filePath());
+                process.setNativeArguments(QString::fromUtf8("/CMD Go \"%1\"")
+                                           .arg(QDir::toNativeSeparators(path)));
+
+                if (process.startDetached())
+                {
+                    return;
+                }
+            }
+        }
+    }
+
     QStringList args;
     QFileInfo info(path);
 
@@ -328,7 +364,7 @@ void DFileOperations::openInFileManager(const QList<QUrl>& urls)
     {
         QStringList uris;
 
-        foreach (const QUrl& url, fileUrls)
+        Q_FOREACH (const QUrl& url, fileUrls)
         {
             uris << url.toString();
         }
@@ -382,7 +418,7 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
         }
     }
 
-    foreach (const QFileInfo& fileInfo, srcDir.entryInfoList(QDir::Files))
+    Q_FOREACH (const QFileInfo& fileInfo, srcDir.entryInfoList(QDir::Files))
     {
         QString copyPath = newCopyPath + QLatin1Char('/') + fileInfo.fileName();
 
@@ -391,7 +427,7 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
             return false;
         }
 
-        if (!copyFile(fileInfo.filePath(), copyPath))
+        if (!copyFile(fileInfo.filePath(), copyPath, cancel))
         {
             return false;
         }
@@ -407,10 +443,10 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
         }
     }
 
-    foreach (const QFileInfo& fileInfo, srcDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot))
+    Q_FOREACH (const QFileInfo& fileInfo, srcDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot))
     {
         if (!copyFolderRecursively(fileInfo.filePath(), newCopyPath, itemId, cancel, false))
-        {
+        {   // cppcheck-suppress useStlAlgorithm
             return false;
         }
     }
@@ -421,7 +457,7 @@ bool DFileOperations::copyFolderRecursively(const QString& srcPath,
 bool DFileOperations::copyFiles(const QStringList& srcPaths,
                                 const QString& dstPath)
 {
-    foreach (const QString& path, srcPaths)
+    Q_FOREACH (const QString& path, srcPaths)
     {
         QFileInfo fileInfo(path);
         QString copyPath = dstPath + QLatin1Char('/') + fileInfo.fileName();
@@ -438,6 +474,10 @@ bool DFileOperations::copyFiles(const QStringList& srcPaths,
 bool DFileOperations::renameFile(const QString& srcFile,
                                  const QString& dstFile)
 {
+    if (srcFile == dstFile)
+    {
+        return true;
+    }
 
 #ifdef Q_OS_WIN64
 
@@ -459,7 +499,17 @@ bool DFileOperations::renameFile(const QString& srcFile,
 
 #endif
 
-    bool ret = QFile::rename(srcFile, dstFile);
+    bool ret = (!QFileInfo::exists(dstFile));
+
+    if (ret)
+    {
+        ret = QFile::rename(srcFile, dstFile);
+
+        if (!ret && QFileInfo::exists(dstFile))
+        {
+            QFile::remove(dstFile);
+        }
+    }
 
     if (ret && (stat == 0))
     {
@@ -491,28 +541,66 @@ bool DFileOperations::renameFile(const QString& srcFile,
 }
 
 bool DFileOperations::copyFile(const QString& srcFile,
-                               const QString& dstFile)
+                               const QString& dstFile,
+                               bool* const cancel)
 {
-    QString tmpFile;
+    bool ret = true;
+    QString tmpFile(dstFile);
+    tmpFile += QLatin1String(".digikamtempfile.tmp");
 
-    int path = dstFile.lastIndexOf(QLatin1Char('/'));
-    int dot  = dstFile.lastIndexOf(QLatin1Char('.'));
-    dot      = (path > dot) ? -1 : dot;
-    int ext  = dstFile.length() - dot;
-    tmpFile  = dstFile.left(dot);
-    tmpFile += QLatin1String(".digikamtempfile");
-    tmpFile += (dot < 0) ? QLatin1String(".tmp")
-                         : dstFile.right(ext);
+    QFile sFile(srcFile);
+    QFile dFile(tmpFile);
 
-    bool ret = QFile::copy(srcFile, tmpFile);
+    if (!sFile.open(QIODevice::ReadOnly))
+    {
+        qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to open source file for reading:" << srcFile;
 
-    if (ret && !(ret = QFile::rename(tmpFile, dstFile)))
+        return false;
+    }
+
+    if (!dFile.open(QIODevice::WriteOnly | QIODevice::Unbuffered))
+    {
+        sFile.close();
+        qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to open destination file for writing:" << tmpFile;
+
+        return false;
+    }
+
+    const int  MAX_IPC_SIZE = (1024 * 32);
+    QByteArray buffer(MAX_IPC_SIZE, '\0');
+    qint64     len;
+
+    while (((len = sFile.read(buffer.data(), MAX_IPC_SIZE)) != 0))
+    {
+        if ((cancel && *cancel) || (len == -1) || (dFile.write(buffer.data(), len) != len))
+        {
+            sFile.close();
+            dFile.close();
+
+            ret = false;
+
+            break;
+        }
+    }
+
+    sFile.close();
+    dFile.close();
+
+    if (ret)
+    {
+        ret = QFile::rename(tmpFile, dstFile);
+    }
+
+    if (!ret)
     {
         QFile::remove(tmpFile);
     }
 
     if (ret)
     {
+        QFile::Permissions permissions = QFile::permissions(srcFile);
+        QFile::setPermissions(dstFile, permissions);
+
         copyModificationTime(srcFile, dstFile);
     }
 
@@ -629,4 +717,110 @@ bool DFileOperations::setModificationTime(const QString& srcFile,
     return true;
 }
 
+QString DFileOperations::findExecutable(const QString& name)
+{
+    QString path;
+    QString program = name;
+
+#ifdef Q_OS_WIN
+
+    program.append(QLatin1String(".exe"));
+
+    QSettings settings(QString::fromUtf8("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\"
+                                         "CurrentVersion\\App Paths\\%1").arg(program),
+                                         QSettings::NativeFormat);
+
+    path = settings.value(QLatin1String("Default"), QString()).toString();
+
+#endif
+
+    if (path.isEmpty())
+    {
+        path = QStandardPaths::findExecutable(program);
+    }
+
+    return path;
+}
+
+bool DFileOperations::sidecarFiles(const QString& srcFile,
+                                   const QString& dstFile,
+                                   SidecarAction action)
+{
+    QStringList sidecarExtensions;
+    sidecarExtensions << QLatin1String("xmp");
+    sidecarExtensions << MetaEngineSettings::instance()->settings().sidecarExtensions;
+
+    QFileInfo srcInfo(srcFile);
+
+    Q_FOREACH (const QString& ext, sidecarExtensions)
+    {
+        QString suffix(QLatin1Char('.') + ext);
+
+        QFileInfo extInfo(srcInfo.filePath() + suffix);
+        QFileInfo basInfo(srcInfo.path()             +
+                          QLatin1Char('/')           +
+                          srcInfo.completeBaseName() + suffix);
+
+        if (extInfo.exists())
+        {
+            QFileInfo dstInfo(dstFile);
+            QString destination = dstInfo.filePath() + suffix;
+
+            if (QFile::exists(destination))
+            {
+                QFile::remove(destination);
+            }
+
+            if      (action == Rename)
+            {
+                if (!renameFile(extInfo.filePath(), destination))
+                {
+                    return false;
+                }
+            }
+            else if (action == Copy)
+            {
+                if (!copyFile(extInfo.filePath(), destination))
+                {
+                    return false;
+                }
+            }
+
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Detected a sidecar" << extInfo.filePath();
+        }
+
+        if (basInfo.exists())
+        {
+            QFileInfo dstInfo(dstFile);
+            QString destination = dstInfo.path()             +
+                                  QLatin1Char('/')           +
+                                  dstInfo.completeBaseName() + suffix;
+
+            if (QFile::exists(destination))
+            {
+                QFile::remove(destination);
+            }
+
+            if      (action == Rename)
+            {
+                if (!renameFile(basInfo.filePath(), destination))
+                {
+                    return false;
+                }
+            }
+            else if (action == Copy)
+            {
+                if (!copyFile(basInfo.filePath(), destination))
+                {
+                    return false;
+                }
+            }
+
+            qCDebug(DIGIKAM_GENERAL_LOG) << "Detected a sidecar" << basInfo.filePath();
+        }
+    }
+
+    return true;
+}
+
 } // namespace Digikam
