@@ -6,19 +6,10 @@
  * Date        : 2006-01-20
  * Description : image file IO threaded interface.
  *
- * Copyright (C) 2005-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -422,7 +413,7 @@ void ManagedLoadSaveThread::preloadThumbnailGroup(const QList<LoadingDescription
     QMutexLocker lock(threadMutex());
     QList<LoadSaveTask*> todo;
 
-    foreach (const LoadingDescription& description, descriptions)
+    Q_FOREACH (const LoadingDescription& description, descriptions)
     {
         LoadingTask* const existingTask = findExistingTask(description);
 
@@ -569,7 +560,7 @@ void ManagedLoadSaveThread::stopAllTasks()
         }
     }
 
-    foreach (LoadSaveTask* const task, m_todo)
+    Q_FOREACH (LoadSaveTask* const task, m_todo)
     {
         delete task;
     }
