@@ -6,21 +6,12 @@
  * Date        : 2008-03-14
  * Description : A widget to host settings as expander box
  *
- * Copyright (C) 2008-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2008-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2010 by Manuel Viet <contact at 13zenrv dot fr>
- * Copyright (C) 2001      by Frerich Raabe <raabe at kde dot org>
+ * SPDX-FileCopyrightText: 2008-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText:      2010 by Manuel Viet <contact at 13zenrv dot fr>
+ * SPDX-FileCopyrightText: 2001      by Frerich Raabe <raabe at kde dot org>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -128,17 +119,8 @@ QSize DAdjustableLabel::sizeHint() const
 
     QFontMetrics fm(fontMetrics());
     int maxW     = screen->geometry().width() * 3 / 4;
-
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
-
     int currentW = fm.horizontalAdvance(d->ajdText);
 
-#else
-
-    int currentW = fm.width(d->ajdText);
-
-#endif
-
     return (QSize(currentW > maxW ? maxW : currentW, QLabel::sizeHint().height()));
 }
 
@@ -179,19 +161,10 @@ void DAdjustableLabel::adjustTextToLabel()
     int lblW      = size().width();
     bool adjusted = false;
 
-    foreach (const QString& line, d->ajdText.split(QLatin1Char('\n')))
+    Q_FOREACH (const QString& line, d->ajdText.split(QLatin1Char('\n')))
     {
-
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
-
         int lineW = fm.horizontalAdvance(line);
 
-#else
-
-        int lineW = fm.width(line);
-
-#endif
-
         if (lineW > lblW)
         {
             adjusted = true;
@@ -253,8 +226,8 @@ void DClickLabel::mouseReleaseEvent(QMouseEvent* event)
 
     if (event->button() == Qt::LeftButton)
     {
-        emit leftClicked();
-        emit activated();
+        Q_EMIT leftClicked();
+        Q_EMIT activated();
         event->accept();
     }
 }
@@ -266,7 +239,7 @@ void DClickLabel::keyPressEvent(QKeyEvent* e)
         case Qt::Key_Down:
         case Qt::Key_Right:
         case Qt::Key_Space:
-            emit activated();
+            Q_EMIT activated();
             return;
 
         default:
@@ -301,8 +274,8 @@ void DSqueezedClickLabel::mouseReleaseEvent(QMouseEvent* event)
 
     if (event->button() == Qt::LeftButton)
     {
-        emit leftClicked();
-        emit activated();
+        Q_EMIT leftClicked();
+        Q_EMIT activated();
         event->accept();
     }
 }
@@ -328,7 +301,7 @@ void DSqueezedClickLabel::keyPressEvent(QKeyEvent* e)
         case Qt::Key_Down:
         case Qt::Key_Right:
         case Qt::Key_Space:
-            emit activated();
+            Q_EMIT activated();
             return;
 
         default:
@@ -381,7 +354,7 @@ void DArrowClickLabel::mouseReleaseEvent(QMouseEvent* event)
 {
     if (event->button() == Qt::LeftButton)
     {
-        emit leftClicked();
+        Q_EMIT leftClicked();
     }
 }
 
@@ -390,7 +363,7 @@ void DArrowClickLabel::paintEvent(QPaintEvent*)
     QPainter p(this);
 
     QStyleOptionFrame opt;
-    opt.init(this);
+    opt.initFrom(this);
     opt.lineWidth    = 2;
     opt.midLineWidth = 0;
 
@@ -514,7 +487,8 @@ DLabelExpander::DLabelExpander(QWidget* const parent)
     : QWidget(parent),
       d      (new Private)
 {
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     d->grid        = new QGridLayout(this);
     d->line        = new DLineWidget(Qt::Horizontal, this);
@@ -606,7 +580,15 @@ void DLabelExpander::setIcon(const QIcon& icon)
 
 QIcon DLabelExpander::icon() const
 {
-    return QIcon(*d->pixmapLabel->pixmap());
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+
+    return QIcon(d->pixmapLabel->pixmap(Qt::ReturnByValue));
+
+#else
+
+  return QIcon(*d->pixmapLabel->pixmap());
+
+#endif
 }
 
 void DLabelExpander::setWidget(QWidget* const widget)
@@ -650,7 +632,7 @@ void DLabelExpander::setExpanded(bool b)
         }
     }
 
-    emit signalExpanded(b);
+    Q_EMIT signalExpanded(b);
 }
 
 bool DLabelExpander::isExpanded() const
@@ -746,7 +728,8 @@ DExpanderBox::DExpanderBox(QWidget* const parent)
     setWidgetResizable(true);
     QWidget* const main = new QWidget(viewport());
     d->vbox             = new QVBoxLayout(main);
-    d->vbox->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    d->vbox->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
     d->vbox->setContentsMargins(QMargins());
     setWidget(main);
 
@@ -831,7 +814,7 @@ void DExpanderBox::slotItemExpanded(bool b)
     if (exp)
     {
         int index = indexOf(exp);
-        emit signalItemExpanded(index, b);
+        Q_EMIT signalItemExpanded(index, b);
     }
 }
 
@@ -842,7 +825,7 @@ void DExpanderBox::slotItemToggled(bool b)
     if (exp)
     {
         int index = indexOf(exp);
-        emit signalItemToggled(index, b);
+        Q_EMIT signalItemToggled(index, b);
     }
 }
 
@@ -1074,7 +1057,7 @@ void DExpanderBoxExclusive::slotItemExpanded(bool b)
         }
     }
 
-    emit signalItemExpanded(indexOf(exp), b);
+    Q_EMIT signalItemExpanded(indexOf(exp), b);
 }
 
 void DExpanderBoxExclusive::setIsToolBox(bool b)
