@@ -6,18 +6,9 @@
  * Date        : 2021-08-27
  * Description : Showfoto folder view bookmarks list
  *
- * Copyright (C) 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2021-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -74,6 +65,7 @@ ShowfotoFolderViewBookmarkList::ShowfotoFolderViewBookmarkList(ShowfotoFolderVie
     setColumnCount(1);
     setHeaderHidden(true);
     setSortingEnabled(true);
+    setUniformRowHeights(true);
     setAllColumnsShowFocus(true);
     sortByColumn(0, Qt::AscendingOrder);
     setSelectionMode(QAbstractItemView::SingleSelection);
@@ -114,7 +106,7 @@ void ShowfotoFolderViewBookmarkList::slotLoadContents()
 
     if (fvitem)
     {
-        emit signalLoadContents(fvitem->path());
+        Q_EMIT signalLoadContents(fvitem->path());
     }
 }
 
@@ -169,7 +161,11 @@ void ShowfotoFolderViewBookmarkList::dragMoveEvent(QDragMoveEvent* e)
 
         if (inf.isDir())
         {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+            QTreeWidgetItem* const item                  = itemAt(e->position().toPoint());
+#else
             QTreeWidgetItem* const item                  = itemAt(e->pos());
+#endif
             ShowfotoFolderViewBookmarkItem* const fvitem = dynamic_cast<ShowfotoFolderViewBookmarkItem*>(item);
 
             if (
@@ -197,7 +193,11 @@ void ShowfotoFolderViewBookmarkList::dropEvent(QDropEvent* e)
 
         if (inf.isDir())
         {
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+            QTreeWidgetItem* const item                  = itemAt(e->position().toPoint());
+#else
             QTreeWidgetItem* const item                  = itemAt(e->pos());
+#endif
             ShowfotoFolderViewBookmarkItem* const fvitem = dynamic_cast<ShowfotoFolderViewBookmarkItem*>(item);
 
             if (
@@ -214,7 +214,7 @@ void ShowfotoFolderViewBookmarkList::dropEvent(QDropEvent* e)
                     path.append(QDir::separator());
                 }
 
-                emit signalAddBookmark(path);
+                Q_EMIT signalAddBookmark(path);
 
                 e->acceptProposedAction();
                 return;
@@ -225,12 +225,16 @@ void ShowfotoFolderViewBookmarkList::dropEvent(QDropEvent* e)
     e->ignore();
 }
 
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+QMimeData* ShowfotoFolderViewBookmarkList::mimeData(const QList<QTreeWidgetItem*>& items) const
+#else
 // cppcheck-suppress passedByValue
-QMimeData* ShowfotoFolderViewBookmarkList::mimeData(const QList<QTreeWidgetItem*> items) const       // clazy:exclude=function-args-by-ref
+QMimeData* ShowfotoFolderViewBookmarkList::mimeData(const QList<QTreeWidgetItem*> items) const     // clazy:exclude=function-args-by-ref
+#endif
 {
     QList<QUrl> urls;
 
-    foreach (QTreeWidgetItem* const itm, items)
+    Q_FOREACH (QTreeWidgetItem* const itm, items)
     {
         ShowfotoFolderViewBookmarkItem* const vitem = dynamic_cast<ShowfotoFolderViewBookmarkItem*>(itm);
 
