@@ -6,18 +6,9 @@
  * Date        : 2009-09-14
  * Description : a class to manipulate the results of an renaming options
  *
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -39,11 +30,12 @@ public:
 
     Modifier(const QString& name, const QString& description);
     Modifier(const QString& name, const QString& description, const QString& icon);
-    ~Modifier()                                     override;
+    ~Modifier()                                                  override;
 
 protected:
 
-    QString parseOperation(ParseSettings& settings) override = 0;
+    QString parseOperation(ParseSettings& settings,
+                           const QRegularExpressionMatch& match) override = 0;
 
 private:
 
