@@ -6,19 +6,10 @@
  * Date        : 2010-10-09
  * Description : Widget to choose options for face scanning
  *
- * Copyright (C) 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -76,31 +67,8 @@ void FaceScanWidget::doLoadState()
     }
 
     FaceScanSettings::AlreadyScannedHandling handling;
-    QString skipHandling = group.readEntry(entryName(d->configAlreadyScannedHandling),
-                                           QString::fromLatin1("Skip"));
-
-    if      (skipHandling == QLatin1String("Rescan"))
-    {
-
-#ifdef ENABLE_DETECT_AND_RECOGNIZE
-
-        handling = FaceScanSettings::Rescan;
-
-#else
-
-        handling = FaceScanSettings::Skip;
-
-#endif
-
-    }
-    else if (skipHandling == QLatin1String("Merge"))
-    {
-        handling = FaceScanSettings::Merge;
-    }
-    else // Skip
-    {
-        handling = FaceScanSettings::Skip;
-    }
+    handling = (FaceScanSettings::AlreadyScannedHandling)group.readEntry(entryName(d->configAlreadyScannedHandling),
+                                                                         (int)FaceScanSettings::Skip);
 
     d->alreadyScannedBox->setCurrentIndex(d->alreadyScannedBox->findData(handling));
 
@@ -139,31 +107,8 @@ void FaceScanWidget::doSaveState()
     }
 
     group.writeEntry(entryName(d->configMainTask), mainTask);
-
-    QString handling;
-
-    switch ((FaceScanSettings::AlreadyScannedHandling)(d->alreadyScannedBox->itemData(d->alreadyScannedBox->currentIndex()).toInt()))
-    {
-        case FaceScanSettings::Skip:
-        {
-            handling = QLatin1String("Skip");
-            break;
-        }
-
-        case FaceScanSettings::Rescan:
-        {
-            handling = QLatin1String("Rescan");
-            break;
-        }
-
-        case FaceScanSettings::Merge:
-        {
-            handling = QLatin1String("Merge");
-            break;
-        }
-    }
-
-    group.writeEntry(entryName(d->configAlreadyScannedHandling), handling);
+    group.writeEntry(entryName(d->configAlreadyScannedHandling),
+                               d->alreadyScannedBox->itemData(d->alreadyScannedBox->currentIndex()).toInt());
 
     ApplicationSettings::instance()->setFaceDetectionAccuracy(double(d->accuracyInput->value()) / 100);
     d->albumSelectors->saveState();
@@ -188,31 +133,27 @@ void FaceScanWidget::setupUi()
     QHBoxLayout* const scanOptionLayout = new QHBoxLayout;
 
     d->alreadyScannedBox                = new SqueezedComboBox;
-    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Skip images already scanned"),          FaceScanSettings::Skip);
-    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Scan again and merge results"),         FaceScanSettings::Merge);
+    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Skip images already scanned"),           FaceScanSettings::Skip);
+    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Scan again and merge results"),          FaceScanSettings::Merge);
+    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Clear unconfirmed results and rescan"),  FaceScanSettings::Rescan);
+    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Clear all previous results and rescan"), FaceScanSettings::ClearAll);
 
     QString buttonText;
     d->helpButton = new QPushButton(QIcon::fromTheme(QLatin1String("help-browser")), buttonText);
-    d->helpButton->setToolTip(i18nc("@info","Help"));
+    d->helpButton->setToolTip(i18nc("@info", "Help"));
 
     connect(d->helpButton, &QPushButton::clicked,
             this, []()
         {
-            DXmlGuiWindow::openHandbook(QLatin1String("main_window"), QLatin1String("people_view"));
+            openOnlineDocumentation(QLatin1String("main_window"), QLatin1String("people_view"));
         }
     );
 
     scanOptionLayout->addWidget(d->alreadyScannedBox, 9);
-    scanOptionLayout->addWidget(d->helpButton, 1);
+    scanOptionLayout->addWidget(d->helpButton,        1);
 
     optionLayout->addLayout(scanOptionLayout);
 
-#ifdef ENABLE_DETECT_AND_RECOGNIZE
-
-    d->alreadyScannedBox->addSqueezedItem(i18nc("@label:listbox", "Clear unconfirmed results and rescan"), FaceScanSettings::Rescan);
-
-#endif
-
     d->alreadyScannedBox->setCurrentIndex(FaceScanSettings::Skip);
 
     d->detectButton                   = new QRadioButton(i18nc("@option:radio", "Detect faces"));
@@ -325,14 +266,14 @@ void FaceScanWidget::setupConnections()
             this, SLOT(slotPrepareForRecognize(bool)));
 
     connect(d->accuracyInput, &DIntNumInput::valueChanged,
-            this, [this](int value)
+            this, [=](int value)
         {
             ApplicationSettings::instance()->setFaceDetectionAccuracy(double(value) / 100);
         }
     );
 
     connect(d->useYoloV3Button, &QCheckBox::toggled,
-            this, [this](bool yolo)
+            this, [=](bool yolo)
         {
             ApplicationSettings::instance()->setFaceDetectionYoloV3(yolo);
         }
