@@ -6,21 +6,12 @@
  * Date        : 2008-05-19
  * Description : Find Duplicates View.
  *
- * Copyright (C) 2016-2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
- * Copyright (C) 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2016-2017 by Mario Frank <mario dot frank at uni minus potsdam dot de>
+ * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -118,7 +109,8 @@ FindDuplicatesView::FindDuplicatesView(QWidget* const parent)
 
     d->settings       = ApplicationSettings::instance();
 
-    const int spacing = QApplication::style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
+                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
 
     // ---------------------------------------------------------------
 
@@ -356,7 +348,7 @@ QList<SAlbum*> FindDuplicatesView::currentFindDuplicatesAlbums() const
 
     QList<SAlbum*> albumList;
 
-    foreach (QTreeWidgetItem* const item, selectedItems)
+    Q_FOREACH (QTreeWidgetItem* const item, selectedItems)
     {
         FindDuplicatesAlbumItem* const albumItem = dynamic_cast<FindDuplicatesAlbumItem*>(item);
 
@@ -550,7 +542,7 @@ void FindDuplicatesView::slotDuplicatesAlbumActived()
 
     QList<Album*> albums;
 
-    foreach (QTreeWidgetItem* const item, d->listView->selectedItems())
+    Q_FOREACH (QTreeWidgetItem* const item, d->listView->selectedItems())
     {
         FindDuplicatesAlbumItem* const albumItem = dynamic_cast<FindDuplicatesAlbumItem*>(item);
 
@@ -587,7 +579,7 @@ void FindDuplicatesView::slotSetSelectedAlbums(const QList<PAlbum*>& albums)
     const AlbumSelectors::SelectionType type = albums.size() == 1 ? AlbumSelectors::SingleSelection
                                                                   : AlbumSelectors::MultipleSelection;
 
-    foreach (PAlbum* const album, albums)
+    Q_FOREACH (PAlbum* const album, albums)
     {
         d->albumSelectors->setAlbumSelected(album, type);
     }
@@ -610,7 +602,7 @@ void FindDuplicatesView::slotSetSelectedAlbums(const QList<TAlbum*>& albums)
     const AlbumSelectors::SelectionType type = albums.size() == 1 ? AlbumSelectors::SingleSelection
                                                                   : AlbumSelectors::MultipleSelection;
 
-    foreach (TAlbum* const album, albums)
+    Q_FOREACH (TAlbum* const album, albums)
     {
         d->albumSelectors->setTagSelected(album, type);
     }
