@@ -6,19 +6,10 @@
  * Date        : 2010-03-21
  * Description : A container to hold GPS information about an item.
  *
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -140,6 +131,7 @@ GPSItemContainer::GPSItemContainer(const QUrl& url)
       m_tagList     (),
       m_savedTagList(),
       m_writeXmpTags(true),
+      m_writeMetaLoc(true),
       m_saveTags    (true),
       m_saveGPS     (true)
 {
@@ -225,16 +217,7 @@ bool GPSItemContainer::loadImageData()
 
         QFileInfo info(m_url.toLocalFile());
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-
         QDateTime ctime = info.birthTime();
-
-#else
-
-        QDateTime ctime = info.created();
-
-#endif
-
         QDateTime mtime = info.lastModified();
 
         if (ctime.isNull() || mtime.isNull())
@@ -933,47 +916,76 @@ QString GPSItemContainer::saveChanges()
             }
         }
 
-        if (m_saveTags && !m_tagList.isEmpty() && m_writeXmpTags)
+        if (m_saveTags && !m_tagList.isEmpty() && (m_writeXmpTags || m_writeMetaLoc))
         {
-            QStringList tagSeq = meta->getXmpTagStringSeq("Xmp.digiKam.TagsList", false);
-
-            for (int i = 0 ; i < m_tagList.count() ; ++i)
+            if (m_writeXmpTags)
             {
-                QList<TagData> currentTagList = m_tagList[i];
-                QString tag;
+                QStringList tagSeq = meta->getXmpTagStringSeq("Xmp.digiKam.TagsList", false);
 
-                for (int j = 0 ; j < currentTagList.count() ; ++j)
+                for (int i = 0 ; i < m_tagList.count() ; ++i)
                 {
-                    tag.append(QLatin1Char('/') + currentTagList[j].tagName);
+                    QList<TagData> currentTagList = m_tagList[i];
+                    QString tag;
+
+                    for (int j = 0 ; j < currentTagList.count() ; ++j)
+                    {
+                        if (currentTagList[j].tipName != QLatin1String("{Country code}"))
+                        {
+                            tag.append(QLatin1Char('/') + currentTagList[j].tagName);
+                        }
+                    }
+
+                    tag.remove(0, 1);
+
+                    if (!tagSeq.contains(tag))
+                    {
+                        tagSeq.append(tag);
+                    }
                 }
 
-                tag.remove(0, 1);
+                bool success2 = meta->setXmpTagStringSeq("Xmp.digiKam.TagsList", tagSeq);
 
-                if (!tagSeq.contains(tag))
+                if (!success2)
                 {
-                    tagSeq.append(tag);
+                    returnString = i18n("Failed to save tags to file.");
+                }
+
+                success2 = meta->setXmpTagStringSeq("Xmp.dc.subject", tagSeq);
+
+                if (!success2)
+                {
+                    returnString = i18n("Failed to save tags to file.");
                 }
             }
 
-            bool success2 = meta->setXmpTagStringSeq("Xmp.digiKam.TagsList", tagSeq);
-
-            if (!success2)
+            if (m_writeMetaLoc)
             {
-                returnString = i18n("Failed to save tags to file.");
-            }
+                IptcCoreLocationInfo locationInfo;
 
-            success2 = meta->setXmpTagStringSeq("Xmp.dc.subject", tagSeq);
+                for (int i = 0 ; i < m_tagList.count() ; ++i)
+                {
+                    QList<TagData> currentTagList = m_tagList[i];
+                    QString tag;
 
-            if (!success2)
-            {
-                returnString = i18n("Failed to save tags to file.");
+                    for (int j = 0 ; j < currentTagList.count() ; ++j)
+                    {
+                        setLocationInfo(currentTagList[j], locationInfo);
+                    }
+                }
+
+                bool success3 = meta->setIptcCoreLocation(locationInfo);
+
+                if (!success3)
+                {
+                    returnString = i18n("Failed to save tags to file.");
+                }
             }
         }
     }
 
     if (success1)
     {
-        if (m_saveGPS || (m_saveTags && !m_tagList.isEmpty() && m_writeXmpTags))
+        if (m_saveGPS || (m_saveTags && !m_tagList.isEmpty() && (m_writeXmpTags || m_writeMetaLoc)))
         {
             success1 = meta->save(m_url.toLocalFile());
         }
@@ -1105,4 +1117,63 @@ QList<QList<TagData> > GPSItemContainer::getTagList() const
     return m_tagList;
 }
 
+void GPSItemContainer::setLocationInfo(const TagData& tagData, IptcCoreLocationInfo& locationInfo)
+{
+    if      (tagData.tipName == QLatin1String("{Country}"))
+    {
+        locationInfo.country       = tagData.tagName;
+    }
+    else if (tagData.tipName == QLatin1String("{Country code}"))
+    {
+        locationInfo.countryCode   = tagData.tagName;
+    }
+    else if (tagData.tipName == QLatin1String("{State}"))
+    {
+        locationInfo.provinceState = tagData.tagName;
+    }
+    else if (locationInfo.provinceState.isEmpty() &&
+             (tagData.tipName == QLatin1String("{State district}")))
+    {
+        locationInfo.provinceState = tagData.tagName;
+    }
+    else if (locationInfo.provinceState.isEmpty() &&
+             (tagData.tipName == QLatin1String("{County}")))
+    {
+        locationInfo.provinceState = tagData.tagName;
+    }
+    else if (tagData.tipName == QLatin1String("{City}"))
+    {
+        locationInfo.city          = tagData.tagName;
+    }
+    else if (locationInfo.city.isEmpty() &&
+             (tagData.tipName == QLatin1String("{City district}")))
+    {
+        locationInfo.city          = tagData.tagName;
+    }
+    else if (locationInfo.city.isEmpty() &&
+             (tagData.tipName == QLatin1String("{Suburb}")))
+    {
+        locationInfo.city          = tagData.tagName;
+    }
+    else if (locationInfo.city.isEmpty() &&
+             (tagData.tipName == QLatin1String("{Town}")))
+    {
+        locationInfo.city          = tagData.tagName;
+    }
+    else if (locationInfo.city.isEmpty() &&
+             (tagData.tipName == QLatin1String("{Village}")))
+    {
+        locationInfo.city          = tagData.tagName;
+    }
+    else if (locationInfo.city.isEmpty() &&
+             (tagData.tipName == QLatin1String("{Hamlet}")))
+    {
+        locationInfo.city          = tagData.tagName;
+    }
+    else if (tagData.tipName == QLatin1String("{Street}"))
+    {
+        locationInfo.location      = tagData.tagName;
+    }
+}
+
 } // namespace Digikam
