@@ -6,19 +6,10 @@
  * Date        : 2004-02-12
  * Description : digiKam image editor GUI
  *
- * Copyright (C) 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -119,7 +110,7 @@ void ImageWindow::closeEvent(QCloseEvent* e)
 
     // put right side bar in a defined state
 
-    emit signalNoCurrentItem();
+    Q_EMIT signalNoCurrentItem();
 
     m_canvas->resetImage();
 
@@ -145,11 +136,13 @@ void ImageWindow::closeEvent(QCloseEvent* e)
     DXmlGuiWindow::closeEvent(e);
 }
 
-void ImageWindow::showEvent(QShowEvent*)
+void ImageWindow::showEvent(QShowEvent* e)
 {
     // Restore the visibility of the thumbbar and start autosaving again.
 
     thumbBar()->restoreVisibility();
+
+    EditorWindow::showEvent(e);
 }
 
 bool ImageWindow::queryClose()
@@ -205,10 +198,7 @@ void ImageWindow::slotLoadItemInfosStage2()
 {
     // if window is minimized, show it
 
-    if (isMinimized())
-    {
-        KWindowSystem::unminimizeWindow(winId());
-    }
+    unminimizeAndActivateWindow();
 
     slotLoadCurrent();
 }
@@ -258,7 +248,7 @@ void ImageWindow::slotLoadCurrent()
 
 void ImageWindow::setViewToURL(const QUrl& url)
 {
-    emit signalURLChanged(url);
+    Q_EMIT signalURLChanged(url);
 }
 
 void ImageWindow::slotThumbBarImageSelected(const ItemInfo& info)
@@ -290,7 +280,7 @@ void ImageWindow::slotDroppedOnThumbbar(const QList<ItemInfo>& infos)
 
     QList<ItemInfo> toAdd;
 
-    foreach (const ItemInfo& it, infos)
+    Q_FOREACH (const ItemInfo& it, infos)
     {
         QModelIndex index(d->imageFilterModel->indexForItemInfo(it));
 
@@ -703,66 +693,9 @@ void ImageWindow::prepareImageToSave()
 {
     if (!d->currentItemInfo.isNull())
     {
-        MetadataHub hub;
-        hub.load(d->currentItemInfo);
-
-        // Get face tags
-
-        d->newFaceTags.clear();
-        QMultiMap<QString, QVariant> faceTags = hub.getFaceTags();
-
-        if (!faceTags.isEmpty())
-        {
-            QMap<QString, QVariant>::const_iterator it;
-
-            QSize size      = d->currentItemInfo.dimensions();
-            int orientation = d->currentItemInfo.orientation();
-
-            for (it = faceTags.constBegin() ; it != faceTags.constEnd() ; ++it)
-            {
-                // Start transform each face rect
-
-                QRect faceRect = TagRegion::relativeToAbsolute(it.value().toRectF(), size);
-                QSize tempSize = TagRegion::adjustToOrientation(faceRect, orientation, size);
-
-                qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>>face rect before:"
-                                             << faceRect.x()     << faceRect.y()
-                                             << faceRect.width() << faceRect.height();
-
-                for (int i = 0 ; i < m_transformQue.size() ; ++i)
-                {
-                    EditorWindow::TransformType type = m_transformQue[i];
-
-                    switch (type)
-                    {
-                        case EditorWindow::TransformType::RotateLeft:
-                            tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_ROT_270, tempSize);
-                            break;
-
-                        case EditorWindow::TransformType::RotateRight:
-                            tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_ROT_90,  tempSize);
-                            break;
-
-                        case EditorWindow::TransformType::FlipHorizontal:
-                            tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_HFLIP,   tempSize);
-                            break;
-
-                        case EditorWindow::TransformType::FlipVertical:
-                            tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_VFLIP,   tempSize);
-                            break;
-
-                        default:
-                            break;
-                    }
-
-                    qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>>face rect transform:"
-                                                 << faceRect.x()     << faceRect.y()
-                                                 << faceRect.width() << faceRect.height();
-                }
-
-                d->newFaceTags.insert(it.key(), QVariant(faceRect));
-            }
-        }
+        FaceTagsEditor editor;
+        d->faceImageSize = d->currentItemInfo.dimensions();
+        d->facesList     = editor.databaseFaces(d->currentItemInfo.id());
 
         // Ensure there is a UUID for the source image in the database,
         // even if not in the source image's metadata
@@ -781,38 +714,73 @@ void ImageWindow::prepareImageToSave()
 
 void ImageWindow::saveFaceTagsToImage(const ItemInfo& info)
 {
-    if (!info.isNull() && !d->newFaceTags.isEmpty())
+    if (!info.isNull() && !d->facesList.isEmpty())
     {
-        // Delete all old faces
+        FaceTagsEditor editor;
+        editor.removeAllFaces(info.id());
 
-        FaceTagsEditor().removeAllFaces(info.id());
-
-        QMultiMap<QString, QVariant>::const_iterator it;
-
-        for (it = d->newFaceTags.constBegin() ; it != d->newFaceTags.constEnd() ; ++it)
+        Q_FOREACH (const FaceTagsIface& dface, d->facesList)
         {
-            int tagId = FaceTags::getOrCreateTagForPerson(it.key());
+            QRect faceRect = dface.region().toRect();
+            QSize tempSize = d->faceImageSize;
 
-            if (tagId)
+            // Start transform each face rect
+
+            qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>>face rect before:"
+                                         << faceRect.x()     << faceRect.y()
+                                         << faceRect.width() << faceRect.height();
+
+            for (int i = 0 ; i < m_transformQue.size() ; ++i)
             {
-                TagRegion region(it.value().toRect());
-                FaceTagsEditor().add(info.id(), tagId, region, false);
+                EditorWindow::TransformType type = m_transformQue[i];
+
+                switch (type)
+                {
+                    case EditorWindow::TransformType::RotateLeft:
+                        tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_ROT_270, tempSize);
+                        break;
+
+                    case EditorWindow::TransformType::RotateRight:
+                        tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_ROT_90,  tempSize);
+                        break;
+
+                    case EditorWindow::TransformType::FlipHorizontal:
+                        tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_HFLIP,   tempSize);
+                        break;
+
+                    case EditorWindow::TransformType::FlipVertical:
+                        tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_VFLIP,   tempSize);
+                        break;
+
+                    default:
+                        break;
+                }
+
+                qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>>face rect transform:"
+                                             << faceRect.x()     << faceRect.y()
+                                             << faceRect.width() << faceRect.height();
             }
-            else
+
+            FaceTagsIface face(dface.type(), info.id(), dface.tagId(), TagRegion(faceRect));
+
+            if (!FaceTags::isSystemPersonTagId(dface.tagId()))
             {
-                qCDebug(DIGIKAM_GENERAL_LOG) << "Failed to create a person tag for name" << it.key();
+                ItemInfo nfo(info.id());
+                nfo.setTag(dface.tagId());
             }
+
+            editor.addManually(face);
         }
 
         MetadataHub hub;
         hub.load(info);
-        QSize tempS = info.dimensions();
-        hub.setFaceTags(d->newFaceTags, tempS);
-        hub.write(info.filePath(), MetadataHub::WRITE_ALL);
+
+        ScanController::FileMetadataWrite writeScope(info);
+        writeScope.changed(hub.writeToMetadata(info, MetadataHub::WRITE_TAGS, true));
     }
 
     m_transformQue.clear();
-    d->newFaceTags.clear();
+    d->facesList.clear();
 }
 
 VersionManager* ImageWindow::versionManager() const
@@ -933,7 +901,7 @@ void ImageWindow::deleteCurrentItem(bool ask, bool permanently)
 
     // bring all (sidebar) to a defined state without letting them sit on the deleted file
 
-    emit signalNoCurrentItem();
+    Q_EMIT signalNoCurrentItem();
 
     // We have database information, which means information will get through
     // everywhere. Just do it asynchronously.
@@ -959,7 +927,7 @@ void ImageWindow::removeCurrent()
     {
         // No image in the current Album -> Quit ImageEditor...
 
-        QMessageBox::information(this, i18n("No Image in Current Album"),
+        QMessageBox::information(this, i18nc("@title:window", "No Image in Current Album"),
                                  i18n("There is no image to show in the current album.\n"
                                       "The image editor will be closed."));
 
@@ -1022,7 +990,7 @@ void ImageWindow::slotCollectionImageChange(const CollectionImageChangeset& chan
     {
         case CollectionImageChangeset::Removed:
 
-            for (int i=0; i<d->imageInfoList.size(); ++i)
+            for (int i = 0 ; i < d->imageInfoList.size() ; ++i)
             {
                 if (changeset.containsImage(d->imageInfoList[i].id()))
                 {
@@ -1048,7 +1016,7 @@ void ImageWindow::slotCollectionImageChange(const CollectionImageChangeset& chan
 
         case CollectionImageChangeset::RemovedAll:
 
-            for (int i=0; i<d->imageInfoList.size(); ++i)
+            for (int i = 0 ; i < d->imageInfoList.size() ; ++i)
             {
                 if (changeset.containsAlbum(d->imageInfoList[i].albumId()))
                 {
@@ -1129,7 +1097,7 @@ void ImageWindow::dropEvent(QDropEvent* e)
         }
 
         loadItemInfos(imageInfoList, imageInfoList.first(),
-                       i18n("Album \"%1\"", ATitle));
+                      i18n("Album \"%1\"", ATitle));
         e->accept();
     }
     else if (DAlbumDrag::decode(e->mimeData(), urls, albumID))
@@ -1154,7 +1122,7 @@ void ImageWindow::dropEvent(QDropEvent* e)
         }
 
         loadItemInfos(imageInfoList, imageInfoList.first(),
-                       i18n("Album \"%1\"", ATitle));
+                      i18n("Album \"%1\"", ATitle));
         e->accept();
     }
     else if (DTagListDrag::canDecode(e->mimeData()))
@@ -1186,7 +1154,7 @@ void ImageWindow::dropEvent(QDropEvent* e)
         }
 
         loadItemInfos(imageInfoList, imageInfoList.first(),
-                       i18n("Album \"%1\"", ATitle));
+                      i18n("Album \"%1\"", ATitle));
         e->accept();
     }
     else
@@ -1231,7 +1199,7 @@ void ImageWindow::slotOpenOriginal()
     {
         //TODO: point to remote collection
 
-        QMessageBox::warning(this, i18nc("@title", "File Not Available"),
+        QMessageBox::warning(this, i18nc("@title:window", "File Not Available"),
                              i18nc("@info", "<qt>The original file (<b>%1</b>) is currently not available</qt>",
                                    originalId.m_fileName));
         return;
@@ -1239,7 +1207,7 @@ void ImageWindow::slotOpenOriginal()
 
     QList<ItemInfo> imageInfos;
 
-    foreach (const HistoryImageId& id, originals)
+    Q_FOREACH (const HistoryImageId& id, originals)
     {
         QUrl url = QUrl::fromLocalFile(id.m_filePath);
         url      = url.adjusted(QUrl::StripTrailingSlash);
