@@ -6,20 +6,11 @@
  * Date        : 2003-01-21
  * Description : Gphoto2 camera interface
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -767,7 +758,7 @@ bool GPCamera::getFolders(const QString& folder)
 
     gp_list_unref(clist);
 
-    emit signalFolderList(subFolderList);
+    Q_EMIT signalFolderList(subFolderList);
 
     return true;
 
@@ -1537,7 +1528,7 @@ bool GPCamera::cameraSummary(QString& summary)
         return false;
     }
 
-    // we do not expect titel/model/etc. to contain newlines,
+    // we do not expect title/model/etc. to contain newlines,
     // so we just escape HTML characters
     summary =  i18nc("@info List of device properties",
                      "Title: \"%1\"\n"
@@ -1663,6 +1654,7 @@ void GPCamera::printGphotoErrorDescription(int errorCode)
 
 void GPCamera::getSupportedCameras(int& count, QStringList& clist)
 {
+
 #ifdef HAVE_GPHOTO2
 
     clist.clear();
@@ -1687,6 +1679,8 @@ void GPCamera::getSupportedCameras(int& count, QStringList& clist)
     }
     else
     {
+        qCDebug(DIGIKAM_IMPORTUI_LOG) << "Number of cameras supported:" << count;
+
         for (int i = 0 ; i < count ; ++i)
         {
             gp_abilities_list_get_abilities(abilList, i, &abil);
@@ -1702,6 +1696,7 @@ void GPCamera::getSupportedCameras(int& count, QStringList& clist)
 
     Q_UNUSED(count);
     Q_UNUSED(clist);
+    qCDebug(DIGIKAM_IMPORTUI_LOG) << "GPCamera::getSupportedCamerasNumber(): function not available!";
 
 #endif // HAVE_GPHOTO2
 
@@ -1709,6 +1704,7 @@ void GPCamera::getSupportedCameras(int& count, QStringList& clist)
 
 void GPCamera::getSupportedPorts(QStringList& plist)
 {
+
 #ifdef HAVE_GPHOTO2
 
     GPPortInfoList* list = nullptr;
@@ -1723,13 +1719,15 @@ void GPCamera::getSupportedPorts(QStringList& plist)
 
     if (numPorts < 0)
     {
-        qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get list of port!";
+        qCDebug(DIGIKAM_IMPORTUI_LOG) << "Failed to get list of ports!";
         printGphotoErrorDescription(numPorts);
         gp_port_info_list_free(list);
         return;
     }
     else
     {
+        qCDebug(DIGIKAM_IMPORTUI_LOG) << "Number of ports supported:" << numPorts;
+
         for (int i = 0 ; i < numPorts ; ++i)
         {
             gp_port_info_list_get_info(list, i, &info);
@@ -1754,6 +1752,7 @@ void GPCamera::getSupportedPorts(QStringList& plist)
 #else
 
     Q_UNUSED(plist);
+    qCDebug(DIGIKAM_IMPORTUI_LOG) << "GPCamera::getSupportedPorts(): function not available!";
 
 #endif // HAVE_GPHOTO2
 
@@ -1761,6 +1760,7 @@ void GPCamera::getSupportedPorts(QStringList& plist)
 
 void GPCamera::getCameraSupportedPorts(const QString& model, QStringList& plist)
 {
+
 #ifdef HAVE_GPHOTO2
 
     int i                         = 0;
@@ -1798,6 +1798,7 @@ void GPCamera::getCameraSupportedPorts(const QString& model, QStringList& plist)
 
     Q_UNUSED(model);
     Q_UNUSED(plist);
+    qCDebug(DIGIKAM_IMPORTUI_LOG) << "GPCamera::getCameraSupportedPorts(): function not available!";
 
 #endif // HAVE_GPHOTO2
 
@@ -1805,6 +1806,7 @@ void GPCamera::getCameraSupportedPorts(const QString& model, QStringList& plist)
 
 int GPCamera::autoDetect(QString& model, QString& port)
 {
+
 #ifdef HAVE_GPHOTO2
 
     CameraList*          camList   = nullptr;
@@ -1871,6 +1873,7 @@ int GPCamera::autoDetect(QString& model, QString& port)
 
     Q_UNUSED(model);
     Q_UNUSED(port);
+    qCDebug(DIGIKAM_IMPORTUI_LOG) << "GPCamera::autoDetect(): function not available!";
 
 #endif // HAVE_GPHOTO2
 
@@ -1879,6 +1882,7 @@ int GPCamera::autoDetect(QString& model, QString& port)
 
 bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& model, QString& port)
 {
+
 #ifdef HAVE_GPHOTO2
 
     CameraAbilitiesList* abilList = nullptr;
@@ -1978,8 +1982,8 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
        if (cnt > 1)
        {
           qCWarning(DIGIKAM_IMPORTUI_LOG) << "More than one camera detected on port " << port
-                                  << ". Due to restrictions in the GPhoto2 API, "
-                                  << "only the first camera is used.";
+                                          << ". Due to restrictions in the GPhoto2 API, "
+                                          << "only the first camera is used.";
        }
 
        model   = QLatin1String(model_str);
@@ -2000,6 +2004,7 @@ bool GPCamera::findConnectedUsbCamera(int vendorId, int productId, QString& mode
     Q_UNUSED(productId);
     Q_UNUSED(model);
     Q_UNUSED(port);
+    qCDebug(DIGIKAM_IMPORTUI_LOG) << "GPCamera::findConnectedUsbCamera(): function not available!";
 
     return false;
 
