@@ -6,19 +6,10 @@
  * Date        : 2012-07-08
  * Description : Item delegate for import interface items.
  *
- * Copyright (C) 2012      by Islam Wazery <wazery at ubuntu dot com>
- * Copyright (C) 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2012      by Islam Wazery <wazery at ubuntu dot com>
+ * SPDX-FileCopyrightText: 2012-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -253,13 +244,13 @@ void ItemViewImportDelegate::invalidatePaintingCache()
 
     if (oldGridSize != d->gridSize)
     {
-        emit gridSizeChanged(d->gridSize);
+        Q_EMIT gridSizeChanged(d->gridSize);
 /*
-        emit sizeHintChanged(QModelIndex());
+        Q_EMIT sizeHintChanged(QModelIndex());
 */
     }
 
-    emit visualChange();
+    Q_EMIT visualChange();
 }
 
 QRect ItemViewImportDelegate::drawThumbnail(QPainter* p, const QRect& thumbRect, const QPixmap& background,
