@@ -6,18 +6,9 @@
  * Date        : 2004-11-22
  * Description : digiKam light table - Configure
  *
- * Copyright (C) 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -45,27 +36,27 @@ void LightTableWindow::setupActions()
     d->firstAction->setEnabled(false);
     connect(d->firstAction, SIGNAL(triggered()), this, SLOT(slotFirst()));
     ac->addAction(QLatin1String("lighttable_first"), d->firstAction);
-    ac->setDefaultShortcuts(d->firstAction, QList<QKeySequence>() << Qt::CTRL + Qt::Key_Home);
+    ac->setDefaultShortcuts(d->firstAction, QList<QKeySequence>() << (Qt::CTRL | Qt::Key_Home));
 
     d->lastAction = new QAction(QIcon::fromTheme(QLatin1String("go-last")), i18nc("@action: go to last item on list", "&Last"), this);
     d->lastAction->setEnabled(false);
     connect(d->lastAction, SIGNAL(triggered()), this, SLOT(slotLast()));
     ac->addAction(QLatin1String("lighttable_last"), d->lastAction);
-    ac->setDefaultShortcuts(d->lastAction, QList<QKeySequence>() << Qt::CTRL + Qt::Key_End);
+    ac->setDefaultShortcuts(d->lastAction, QList<QKeySequence>() << (Qt::CTRL | Qt::Key_End));
 
     d->setItemLeftAction = new QAction(QIcon::fromTheme(QLatin1String("arrow-left")), i18n("On left"), this);
     d->setItemLeftAction->setEnabled(false);
     d->setItemLeftAction->setWhatsThis(i18n("Show item on left panel"));
     connect(d->setItemLeftAction, SIGNAL(triggered()), this, SLOT(slotSetItemLeft()));
     ac->addAction(QLatin1String("lighttable_setitemleft"), d->setItemLeftAction);
-    ac->setDefaultShortcut(d->setItemLeftAction, Qt::CTRL + Qt::Key_L);
+    ac->setDefaultShortcut(d->setItemLeftAction, Qt::CTRL | Qt::Key_L);
 
     d->setItemRightAction = new QAction(QIcon::fromTheme(QLatin1String("arrow-right")), i18n("On right"), this);
     d->setItemRightAction->setEnabled(false);
     d->setItemRightAction->setWhatsThis(i18n("Show item on right panel"));
     connect(d->setItemRightAction, SIGNAL(triggered()), this, SLOT(slotSetItemRight()));
     ac->addAction(QLatin1String("lighttable_setitemright"), d->setItemRightAction);
-    ac->setDefaultShortcut(d->setItemRightAction, Qt::CTRL + Qt::Key_R);
+    ac->setDefaultShortcut(d->setItemRightAction, Qt::CTRL | Qt::Key_R);
 
     d->editItemAction = new QAction(QIcon::fromTheme(QLatin1String("document-edit")), i18n("Edit"), this);
     d->editItemAction->setEnabled(false);
@@ -77,19 +68,19 @@ void LightTableWindow::setupActions()
     openWithAction->setWhatsThis(i18n("Open the item with default assigned application."));
     connect(openWithAction, SIGNAL(triggered()), this, SLOT(slotFileWithDefaultApplication()));
     ac->addAction(QLatin1String("open_with_default_application"), openWithAction);
-    ac->setDefaultShortcut(openWithAction, Qt::CTRL + Qt::Key_F4);
+    ac->setDefaultShortcut(openWithAction, Qt::CTRL | Qt::Key_F4);
 
     d->removeItemAction = new QAction(QIcon::fromTheme(QLatin1String("list-remove")), i18n("Remove item from Light Table"), this);
     d->removeItemAction->setEnabled(false);
     connect(d->removeItemAction, SIGNAL(triggered()), this, SLOT(slotRemoveItem()));
     ac->addAction(QLatin1String("lighttable_removeitem"), d->removeItemAction);
-    ac->setDefaultShortcut(d->removeItemAction, Qt::CTRL + Qt::Key_K);
+    ac->setDefaultShortcut(d->removeItemAction, Qt::CTRL | Qt::Key_K);
 
     d->clearListAction = new QAction(QIcon::fromTheme(QLatin1String("edit-clear")), i18n("Remove all items from Light Table"), this);
     d->clearListAction->setEnabled(false);
     connect(d->clearListAction, SIGNAL(triggered()), this, SLOT(slotClearItemsList()));
     ac->addAction(QLatin1String("lighttable_clearlist"), d->clearListAction);
-    ac->setDefaultShortcut(d->clearListAction, Qt::CTRL + Qt::SHIFT + Qt::Key_K);
+    ac->setDefaultShortcut(d->clearListAction, Qt::CTRL | Qt::SHIFT | Qt::Key_K);
 
     d->fileDeleteAction = new QAction(QIcon::fromTheme(QLatin1String("user-trash")), i18nc("Non-pluralized", "Move to Trash"), this);
     d->fileDeleteAction->setEnabled(false);
@@ -101,7 +92,7 @@ void LightTableWindow::setupActions()
     d->fileDeleteFinalAction->setEnabled(false);
     connect(d->fileDeleteFinalAction, SIGNAL(triggered()), this, SLOT(slotDeleteFinalItem()));
     ac->addAction(QLatin1String("lighttable_filefinaldelete"), d->fileDeleteFinalAction);
-    ac->setDefaultShortcut(d->fileDeleteFinalAction, Qt::SHIFT + Qt::Key_Delete);
+    ac->setDefaultShortcut(d->fileDeleteFinalAction, Qt::SHIFT | Qt::Key_Delete);
 
     QAction* const closeAction = buildStdAction(StdCloseAction, this, SLOT(slotClose()), this);
     ac->addAction(QLatin1String("lighttable_close"), closeAction);
@@ -114,7 +105,7 @@ void LightTableWindow::setupActions()
     d->syncPreviewAction->setWhatsThis(i18n("Synchronize preview from left and right panels"));
     connect(d->syncPreviewAction, SIGNAL(triggered()), this, SLOT(slotToggleSyncPreview()));
     ac->addAction(QLatin1String("lighttable_syncpreview"), d->syncPreviewAction);
-    ac->setDefaultShortcut(d->syncPreviewAction, Qt::CTRL + Qt::SHIFT + Qt::Key_Y);
+    ac->setDefaultShortcut(d->syncPreviewAction, Qt::CTRL | Qt::SHIFT | Qt::Key_Y);
 
     d->navigateByPairAction = new QAction(QIcon::fromTheme(QLatin1String("system-run")), i18n("By Pair"), this);
     d->navigateByPairAction->setEnabled(false);
@@ -122,7 +113,7 @@ void LightTableWindow::setupActions()
     d->navigateByPairAction->setWhatsThis(i18n("Navigate by pairs with all items"));
     connect(d->navigateByPairAction, SIGNAL(triggered()), this, SLOT(slotToggleNavigateByPair()));
     ac->addAction(QLatin1String("lighttable_navigatebypair"), d->navigateByPairAction);
-    ac->setDefaultShortcut(d->navigateByPairAction, Qt::CTRL + Qt::SHIFT + Qt::Key_P);
+    ac->setDefaultShortcut(d->navigateByPairAction, Qt::CTRL | Qt::SHIFT | Qt::Key_P);
 
     d->clearOnCloseAction = new QAction(QIcon::fromTheme(QLatin1String("edit-clear")), i18n("Clear On Close"), this);
     d->clearOnCloseAction->setEnabled(true);
@@ -130,11 +121,11 @@ void LightTableWindow::setupActions()
     d->clearOnCloseAction->setToolTip(i18n("Clear light table when it is closed"));
     d->clearOnCloseAction->setWhatsThis(i18n("Remove all images from the light table when it is closed"));
     ac->addAction(QLatin1String("lighttable_clearonclose"), d->clearOnCloseAction);
-    ac->setDefaultShortcut(d->clearOnCloseAction, Qt::CTRL + Qt::SHIFT + Qt::Key_C);
+    ac->setDefaultShortcut(d->clearOnCloseAction, Qt::CTRL | Qt::SHIFT | Qt::Key_C);
 
     d->showBarAction = d->barViewDock->getToggleAction(this);
     ac->addAction(QLatin1String("lighttable_showthumbbar"), d->showBarAction);
-    ac->setDefaultShortcut(d->showBarAction, Qt::CTRL + Qt::Key_T);
+    ac->setDefaultShortcut(d->showBarAction, Qt::CTRL | Qt::Key_T);
 
     createFullScreenAction(QLatin1String("lighttable_fullscreen"));
     createSidebarActions();
@@ -152,34 +143,52 @@ void LightTableWindow::setupActions()
     d->leftZoomTo100percents = new QAction(QIcon::fromTheme(QLatin1String("zoom-original")), i18n("Zoom to 100%"), this);
     connect(d->leftZoomTo100percents, SIGNAL(triggered()), d->previewView, SLOT(slotLeftZoomTo100()));
     ac->addAction(QLatin1String("lighttable_zoomto100percents_left"), d->leftZoomTo100percents);
-    ac->setDefaultShortcut(d->leftZoomTo100percents, Qt::CTRL + Qt::Key_Period);
+    ac->setDefaultShortcut(d->leftZoomTo100percents, Qt::CTRL | Qt::Key_Period);
 
     d->leftZoomFitToWindowAction = new QAction(QIcon::fromTheme(QLatin1String("zoom-fit-best")), i18n("Fit to &Window"), this);
     connect(d->leftZoomFitToWindowAction, SIGNAL(triggered()), d->previewView, SLOT(slotLeftFitToWindow()));
     ac->addAction(QLatin1String("lighttable_zoomfit2window_left"), d->leftZoomFitToWindowAction);
-    ac->setDefaultShortcut(d->leftZoomFitToWindowAction, Qt::CTRL + Qt::ALT + Qt::Key_E);
+    ac->setDefaultShortcut(d->leftZoomFitToWindowAction, Qt::CTRL | Qt::ALT | Qt::Key_E);
 
     // Right Panel Zoom Actions
 
     d->rightZoomPlusAction  = buildStdAction(StdZoomInAction, d->previewView, SLOT(slotIncreaseRightZoom()), this);
     d->rightZoomPlusAction->setEnabled(false);
     ac->addAction(QLatin1String("lighttable_zoomplus_right"), d->rightZoomPlusAction);
-    ac->setDefaultShortcut(d->rightZoomPlusAction, Qt::SHIFT + d->rightZoomPlusAction->shortcut()[0]);
+
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+    ac->setDefaultShortcut(d->rightZoomPlusAction, QKeySequence(QKeyCombination(Qt::ShiftModifier, d->rightZoomPlusAction->shortcut()[0].key())));
+
+#else
+
+    ac->setDefaultShortcut(d->rightZoomPlusAction, Qt::Key(d->rightZoomPlusAction->shortcut()[0] ^ Qt::SHIFT) & d->rightZoomPlusAction->shortcut()[0]);
+
+#endif
 
     d->rightZoomMinusAction  = buildStdAction(StdZoomOutAction, d->previewView, SLOT(slotDecreaseRightZoom()), this);
     d->rightZoomMinusAction->setEnabled(false);
     ac->addAction(QLatin1String("lighttable_zoomminus_right"), d->rightZoomMinusAction);
-    ac->setDefaultShortcut(d->rightZoomMinusAction, Qt::SHIFT + d->rightZoomMinusAction->shortcut()[0]);
+
+#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+    ac->setDefaultShortcut(d->rightZoomMinusAction, QKeySequence(QKeyCombination(Qt::ShiftModifier, d->rightZoomMinusAction->shortcut()[0].key())));
+
+#else
+
+    ac->setDefaultShortcut(d->rightZoomMinusAction, Qt::Key(d->rightZoomMinusAction->shortcut()[0] ^ Qt::SHIFT) &  d->rightZoomMinusAction->shortcut()[0]);
+
+#endif
 
     d->rightZoomTo100percents = new QAction(QIcon::fromTheme(QLatin1String("zoom-original")), i18n("Zoom to 100%"), this);
     connect(d->rightZoomTo100percents, SIGNAL(triggered()), d->previewView, SLOT(slotRightZoomTo100()));
     ac->addAction(QLatin1String("lighttable_zoomto100percents_right"), d->rightZoomTo100percents);
-    ac->setDefaultShortcut(d->rightZoomTo100percents, Qt::CTRL + Qt::SHIFT + Qt::Key_Period);
+    ac->setDefaultShortcut(d->rightZoomTo100percents, Qt::CTRL | Qt::SHIFT | Qt::Key_Period);
 
     d->rightZoomFitToWindowAction = new QAction(QIcon::fromTheme(QLatin1String("zoom-fit-best")), i18n("Fit to &Window"), this);
     connect(d->rightZoomFitToWindowAction, SIGNAL(triggered()), d->previewView, SLOT(slotRightFitToWindow()));
     ac->addAction(QLatin1String("lighttable_zoomfit2window_right"), d->rightZoomFitToWindowAction);
-    ac->setDefaultShortcut(d->rightZoomFitToWindowAction, Qt::CTRL + Qt::SHIFT + Qt::Key_E);
+    ac->setDefaultShortcut(d->rightZoomFitToWindowAction, Qt::CTRL | Qt::SHIFT | Qt::Key_E);
 
     // -----------------------------------------------------------
 
@@ -195,7 +204,7 @@ void LightTableWindow::setupActions()
 
     // Standard 'Help' menu actions
 
-    createHelpActions();
+    createHelpActions(QLatin1String("light_table"));
 
     // Provides a menu entry that allows showing/hiding the toolbar(s)
 
@@ -215,7 +224,7 @@ void LightTableWindow::setupActions()
 
     QAction* const altBackwardAction = new QAction(i18n("Previous Image"), this);
     ac->addAction(QLatin1String("lighttable_backward_shift_space"), altBackwardAction);
-    ac->setDefaultShortcut(altBackwardAction, Qt::SHIFT + Qt::Key_Space);
+    ac->setDefaultShortcut(altBackwardAction, Qt::SHIFT | Qt::Key_Space);
     connect(altBackwardAction, SIGNAL(triggered()), this, SLOT(slotBackward()));
 
     // Labels shortcuts must be registered here to be saved in XML GUI files if user customize it.
@@ -224,32 +233,32 @@ void LightTableWindow::setupActions()
 
     QAction* const editTitlesRight = new QAction(i18n("Edit Titles on the Right"), this);
     ac->addAction(QLatin1String("edit_titles_right"), editTitlesRight);
-    ac->setDefaultShortcut(editTitlesRight, Qt::ALT + Qt::SHIFT + Qt::Key_T);
+    ac->setDefaultShortcut(editTitlesRight, Qt::ALT | Qt::SHIFT | Qt::Key_T);
     connect(editTitlesRight, SIGNAL(triggered()), this, SLOT(slotRightSideBarActivateTitles()));
 
     QAction* const editCommentsRight = new QAction(i18n("Edit Comments on the Right"), this);
     ac->addAction(QLatin1String("edit_comments_right"), editCommentsRight);
-    ac->setDefaultShortcut(editCommentsRight, Qt::ALT + Qt::SHIFT + Qt::Key_C);
+    ac->setDefaultShortcut(editCommentsRight, Qt::ALT | Qt::SHIFT | Qt::Key_C);
     connect(editCommentsRight, SIGNAL(triggered()), this, SLOT(slotRightSideBarActivateComments()));
 
     QAction* const assignedTagsRight = new QAction(i18n("Show Assigned Tags on the Right"), this);
     ac->addAction(QLatin1String("assigned_tags_right"), assignedTagsRight);
-    ac->setDefaultShortcut(assignedTagsRight, Qt::ALT + Qt::SHIFT + Qt::Key_A);
+    ac->setDefaultShortcut(assignedTagsRight, Qt::ALT | Qt::SHIFT | Qt::Key_A);
     connect(assignedTagsRight, SIGNAL(triggered()), this, SLOT(slotRightSideBarActivateAssignedTags()));
 
     QAction* const editTitlesLeft = new QAction(i18n("Edit Titles on the Left"), this);
     ac->addAction(QLatin1String("edit_titles_left"), editTitlesLeft);
-    ac->setDefaultShortcut(editTitlesLeft, Qt::CTRL + Qt::ALT + Qt::SHIFT + Qt::Key_T);
+    ac->setDefaultShortcut(editTitlesLeft, Qt::CTRL | Qt::ALT | Qt::SHIFT | Qt::Key_T);
     connect(editTitlesLeft, SIGNAL(triggered()), this, SLOT(slotLeftSideBarActivateTitles()));
 
     QAction* const editCommentsLeft = new QAction(i18n("Edit Comments on the Left"), this);
     ac->addAction(QLatin1String("edit_comments_left"), editCommentsLeft);
-    ac->setDefaultShortcut(editCommentsLeft, Qt::CTRL + Qt::ALT + Qt::SHIFT + Qt::Key_C);
+    ac->setDefaultShortcut(editCommentsLeft, Qt::CTRL | Qt::ALT | Qt::SHIFT | Qt::Key_C);
     connect(editCommentsLeft, SIGNAL(triggered()), this, SLOT(slotLeftSideBarActivateComments()));
 
     QAction* const assignedTagsLeft = new QAction(i18n("Show Assigned Tags on the Left"), this);
     ac->addAction(QLatin1String("assigned_tags_left"), assignedTagsLeft);
-    ac->setDefaultShortcut(assignedTagsLeft, Qt::CTRL + Qt::ALT + Qt::SHIFT + Qt::Key_A);
+    ac->setDefaultShortcut(assignedTagsLeft, Qt::CTRL | Qt::ALT | Qt::SHIFT | Qt::Key_A);
     connect(assignedTagsLeft, SIGNAL(triggered()), this, SLOT(slotLeftSideBarActivateAssignedTags()));
 
     // ---------------------------------------------------------------------------------
@@ -453,7 +462,7 @@ void LightTableWindow::setupUserArea()
     viewContainer->addDockWidget(Qt::TopDockWidgetArea, d->barViewDock);
     d->barViewDock->setFloating(false);
 
-    // Restore the previous state. This doesn't emit the proper signals to the
+    // Restore the previous state. This doesn't Q_EMIT the proper signals to the
     // dock widget, so it has to be manually reinitialized.
 
     viewContainer->setAutoSaveSettings(QLatin1String("LightTable Thumbbar"), true);
