@@ -6,20 +6,11 @@
  * Date        : 2008-11-15
  * Description : collections setup tab model/view
  *
- * Copyright (C) 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2012 by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText:      2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -37,8 +28,8 @@
 #include <QHBoxLayout>
 #include <QMessageBox>
 #include <QStandardPaths>
-#include <QLineEdit>
 #include <QComboBox>
+#include <QUrlQuery>
 #include <QUrl>
 #include <QIcon>
 #include <QDialog>
@@ -58,6 +49,8 @@
 #include "collectionlocation.h"
 #include "collectionmanager.h"
 #include "newitemsfinder.h"
+#include "dtextedit.h"
+#include "digikam_globals.h"
 
 namespace Digikam
 {
@@ -86,6 +79,8 @@ SetupCollectionDelegate::SetupCollectionDelegate(QAbstractItemView* const view,
 
     m_samplePushButton   = new QPushButton(view);
     m_samplePushButton->hide();
+    m_sampleAppendButton = new QToolButton(view);
+    m_sampleAppendButton->hide();
     m_sampleUpdateButton = new QToolButton(view);
     m_sampleUpdateButton->hide();
     m_sampleDeleteButton = new QToolButton(view);
@@ -106,7 +101,15 @@ QList<QWidget*> SetupCollectionDelegate::createItemWidgets(const QModelIndex& /*
     list << pushButton;
 
     connect(pushButton, &QPushButton::clicked,
-            this, [this, pushButton]() { emit categoryButtonPressed(pushButton->property("id").toInt()); });
+            this, [this, pushButton]() { Q_EMIT categoryButtonPressed(pushButton->property("id").toInt()); });
+
+    QToolButton* const appendButton = new QToolButton();
+    appendButton->setToolTip(i18nc("@info:tooltip", "Append a path to the collection."));
+    appendButton->setAutoRaise(true);
+    list << appendButton;
+
+    connect(appendButton, &QToolButton::clicked,
+            this, [this, appendButton]() { Q_EMIT appendPressed(appendButton->property("id").toInt()); });
 
     QToolButton* const updateButton = new QToolButton();
     updateButton->setToolTip(i18nc("@info:tooltip", "Updates the path of the collection."));
@@ -114,7 +117,7 @@ QList<QWidget*> SetupCollectionDelegate::createItemWidgets(const QModelIndex& /*
     list << updateButton;
 
     connect(updateButton, &QToolButton::clicked,
-            this, [this, updateButton]() { emit updatePressed(updateButton->property("id").toInt()); });
+            this, [this, updateButton]() { Q_EMIT updatePressed(updateButton->property("id").toInt()); });
 
     QToolButton* const deleteButton = new QToolButton();
     deleteButton->setToolTip(i18nc("@info:tooltip", "Removes the collection from digiKam."));
@@ -122,7 +125,7 @@ QList<QWidget*> SetupCollectionDelegate::createItemWidgets(const QModelIndex& /*
     list << deleteButton;
 
     connect(deleteButton, &QToolButton::clicked,
-            this, [this, deleteButton]() { emit deletePressed(deleteButton->property("id").toInt()); });
+            this, [this, deleteButton]() { Q_EMIT deletePressed(deleteButton->property("id").toInt()); });
 
     return list;
 }
@@ -141,7 +144,7 @@ QSize SetupCollectionDelegate::sizeHint(const QStyleOptionViewItem& option, cons
 
         int maxStyledWidth = 0;
 
-        foreach (const QModelIndex& catIndex, static_cast<const SetupCollectionModel*>(index.model())->categoryIndexes())
+        Q_FOREACH (const QModelIndex& catIndex, static_cast<const SetupCollectionModel*>(index.model())->categoryIndexes())
         {
             maxStyledWidth = qMax(maxStyledWidth, m_styledDelegate->sizeHint(option, catIndex).width());
         }
@@ -158,6 +161,19 @@ QSize SetupCollectionDelegate::sizeHint(const QStyleOptionViewItem& option, cons
         hint.setWidth(m_categoryMaxStyledWidth + widgetHint.width());
         hint.setHeight(qMax(hint.height(), widgetHint.height()));
     }
+    else if (index.data(SetupCollectionModel::IsAppendRole).toBool())
+    {
+        // set real pixmap on sample button to compute correct size hint
+
+        QIcon pix      = index.data(SetupCollectionModel::AppendDecorationRole).value<QIcon>();
+        m_sampleAppendButton->setIcon(index.data(SetupCollectionModel::AppendDecorationRole).value<QIcon>());
+        QSize widgetHint = m_sampleAppendButton->sizeHint();
+
+        // combine hints
+
+        hint.setWidth(hint.width() + widgetHint.width());
+        hint.setHeight(qMax(hint.height(), widgetHint.height()));
+    }
     else if (index.data(SetupCollectionModel::IsUpdateRole).toBool())
     {
         // set real pixmap on sample button to compute correct size hint
@@ -193,8 +209,9 @@ void SetupCollectionDelegate::updateItemWidgets(const QList<QWidget*>& widgets,
                                                 const QPersistentModelIndex& index) const
 {
     QPushButton* const pushButton   = static_cast<QPushButton*>(widgets.at(0));
-    QToolButton* const updateButton = static_cast<QToolButton*>(widgets.at(1));
-    QToolButton* const deleteButton = static_cast<QToolButton*>(widgets.at(2));
+    QToolButton* const appendButton = static_cast<QToolButton*>(widgets.at(1));
+    QToolButton* const updateButton = static_cast<QToolButton*>(widgets.at(2));
+    QToolButton* const deleteButton = static_cast<QToolButton*>(widgets.at(3));
 
     if      (index.data(SetupCollectionModel::IsCategoryRole).toBool())
     {
@@ -210,12 +227,24 @@ void SetupCollectionDelegate::updateItemWidgets(const QList<QWidget*>& widgets,
 
         pushButton->move(m_categoryMaxStyledWidth, (option.rect.height() - pushButton->height()) / 2);
         pushButton->show();
+        appendButton->hide();
         updateButton->hide();
         deleteButton->hide();
 
         pushButton->setEnabled(itemView()->isEnabled());
         pushButton->setProperty("id", index.data(SetupCollectionModel::CategoryButtonMapId));
     }
+    else if (index.data(SetupCollectionModel::IsAppendRole).toBool())
+    {
+        appendButton->setIcon(index.data(SetupCollectionModel::AppendDecorationRole).value<QIcon>());
+        appendButton->resize(appendButton->sizeHint());
+        appendButton->move(0, (option.rect.height() - appendButton->height()) / 2);
+        appendButton->show();
+        pushButton->hide();
+
+        appendButton->setEnabled(itemView()->isEnabled());
+        appendButton->setProperty("id", index.data(SetupCollectionModel::AppendMapId));
+    }
     else if (index.data(SetupCollectionModel::IsUpdateRole).toBool())
     {
         updateButton->setIcon(index.data(SetupCollectionModel::UpdateDecorationRole).value<QIcon>());
@@ -241,6 +270,7 @@ void SetupCollectionDelegate::updateItemWidgets(const QList<QWidget*>& widgets,
     else
     {
         pushButton->hide();
+        appendButton->hide();
         updateButton->hide();
         deleteButton->hide();
     }
@@ -309,6 +339,9 @@ void SetupCollectionTreeView::setModel(SetupCollectionModel* collectionModel)
     connect(static_cast<SetupCollectionDelegate*>(itemDelegate()), SIGNAL(categoryButtonPressed(int)),
             collectionModel, SLOT(slotCategoryButtonPressed(int)));
 
+    connect(static_cast<SetupCollectionDelegate*>(itemDelegate()), SIGNAL(appendPressed(int)),
+            collectionModel, SLOT(slotAppendPressed(int)));
+
     connect(static_cast<SetupCollectionDelegate*>(itemDelegate()), SIGNAL(updatePressed(int)),
             collectionModel, SLOT(slotUpdatePressed(int)));
 
@@ -343,6 +376,8 @@ void SetupCollectionTreeView::modelLoadedCollections()
     // Resize last column, so that delete button is always rightbound
 
     header()->setStretchLastSection(false); // defaults to true
+    header()->setSectionResizeMode(SetupCollectionModel::ColumnAppendButton, QHeaderView::Fixed);
+    resizeColumnToContents(SetupCollectionModel::ColumnAppendButton);
     header()->setSectionResizeMode(SetupCollectionModel::ColumnUpdateButton, QHeaderView::Fixed);
     resizeColumnToContents(SetupCollectionModel::ColumnUpdateButton);
     header()->setSectionResizeMode(SetupCollectionModel::ColumnDeleteButton, QHeaderView::Fixed);
@@ -364,6 +399,8 @@ void SetupCollectionTreeView::modelLoadedCollections()
 
 SetupCollectionModel::Item::Item()
     : parentId(INTERNALID),
+      orgIndex(0),
+      appended(false),
       updated (false),
       deleted (false)
 {
@@ -371,6 +408,8 @@ SetupCollectionModel::Item::Item()
 
 SetupCollectionModel::Item::Item(const CollectionLocation& location)
     : location(location),
+      orgIndex(0),
+      appended(false),
       updated (false),
       deleted (false)
 {
@@ -381,6 +420,8 @@ SetupCollectionModel::Item::Item(const QString& path, const QString& label, Setu
     : label   (label),
       path    (path),
       parentId(category),
+      orgIndex(0),
+      appended(false),
       updated (false),
       deleted (false)
 {
@@ -417,13 +458,37 @@ void SetupCollectionModel::loadCollections()
     m_collections.clear();
     QList<CollectionLocation> locations = CollectionManager::instance()->allLocations();
 
-    foreach (const CollectionLocation& location, locations)
+    Q_FOREACH (const CollectionLocation& location, locations)
     {
         m_collections << Item(location);
+        int idx = m_collections.size() - 1;
+
+        if (location.type() == CollectionLocation::Network)
+        {
+            QUrl url(location.identifier);
+
+            if (url.scheme() == QLatin1String("networkshareid"))
+            {
+               QUrlQuery q(url);
+
+                Q_FOREACH (const QString& path, q.allQueryItemValues(QLatin1String("mountpath")))
+                {
+                    if (location.albumRootPath() != path)
+                    {
+                        Item item(location);
+                        item.orgIndex = idx;
+                        item.appended = true;
+                        item.path     = path;
+                        m_collections << item;
+                        m_collections[idx].childs << path;
+                    }
+                }
+            }
+        }
     }
 
     endResetModel();
-    emit collectionsLoaded();
+    Q_EMIT collectionsLoaded();
 }
 
 void SetupCollectionModel::apply()
@@ -434,7 +499,11 @@ void SetupCollectionModel::apply()
     {
         const Item& item = m_collections.at(i);
 
-        if      (item.deleted && !item.location.isNull())
+        if      (item.appended)
+        {
+            continue;
+        }
+        else if (item.deleted && !item.location.isNull())
         {
             // if item was deleted and had a valid location, i.e. exists in DB
 
@@ -463,7 +532,7 @@ void SetupCollectionModel::apply()
 
     // Delete deleted items
 
-    foreach (int i, deletedItems)
+    Q_FOREACH (int i, deletedItems)
     {
         Item& item    = m_collections[i];
         CollectionManager::instance()->removeLocation(item.location);
@@ -474,7 +543,7 @@ void SetupCollectionModel::apply()
 
     QList<Item> failedItems;
 
-    foreach (int i, newItems)
+    Q_FOREACH (int i, newItems)
     {
         Item& item = m_collections[i];
         CollectionLocation location;
@@ -502,24 +571,26 @@ void SetupCollectionModel::apply()
 
     // Update collections
 
-    foreach (int i, updatedItems)
+    Q_FOREACH (int i, updatedItems)
     {
         Item& item  = m_collections[i];
         CollectionLocation location;
 
-        int newType = CollectionLocation::TypeVolumeHardWired;
+        int newType = CollectionLocation::VolumeHardWired;
 
         if      (item.parentId == CategoryRemovable)
         {
-            newType = CollectionLocation::TypeVolumeRemovable;
+            newType = CollectionLocation::VolumeRemovable;
         }
         else if (item.parentId == CategoryRemote)
         {
-            newType = CollectionLocation::TypeNetwork;
+            newType = CollectionLocation::Network;
         }
 
+        QStringList pathList;
+        pathList << item.path << item.childs;
         location    = CollectionManager::instance()->refreshLocation(item.location, newType,
-                                                                     QUrl::fromLocalFile(item.path), item.label);
+                                                                     pathList, item.label);
 
         if (location.isNull())
         {
@@ -535,7 +606,7 @@ void SetupCollectionModel::apply()
 
     // Rename collections
 
-    foreach (int i, renamedItems)
+    Q_FOREACH (int i, renamedItems)
     {
         Item& item = m_collections[i];
         CollectionManager::instance()->setLabel(item.location, item.label);
@@ -548,7 +619,7 @@ void SetupCollectionModel::apply()
     {
         QStringList failedPaths;
 
-        foreach (const Item& item, failedItems)
+        Q_FOREACH (const Item& item, failedItems)
         {
             failedPaths << QDir::toNativeSeparators(item.path);
         }
@@ -579,6 +650,86 @@ void SetupCollectionModel::slotCategoryButtonPressed(int mappedId)
     addCollection(mappedId);
 }
 
+void SetupCollectionModel::slotAppendPressed(int mappedId)
+{
+    QString picPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
+
+    QUrl curl       = DFileDialog::getExistingDirectoryUrl(m_dialogParentWidget,
+                                                           i18nc("@title:window", "Choose the Folder Containing your Collection"),
+                                                           QUrl::fromLocalFile(picPath));
+
+    if (curl.isEmpty())
+    {
+        return;
+    }
+
+    bool foundPath = false;
+
+    Q_FOREACH (const Item& item, m_collections)
+    {
+        if (!item.deleted)
+        {
+            QStringList possiblePaths;
+
+            possiblePaths << item.childs;
+
+            if      (!item.path.isEmpty())
+            {
+                possiblePaths << item.path;
+            }
+            else if (!item.location.isNull())
+            {
+                possiblePaths << item.location.albumRootPath();
+            }
+
+            if (possiblePaths.contains(curl.toLocalFile()))
+            {
+                foundPath = true;
+                break;
+            }
+        }
+    }
+
+    if (foundPath)
+    {
+        QMessageBox::warning(m_dialogParentWidget, i18nc("@title:window", "Problem Appending Collection"),
+                                                   i18n("A collection with the path \"%1\" already exists.",
+                                                        QDir::toNativeSeparators(curl.toLocalFile())));
+
+        return;
+    }
+
+    QModelIndex index = indexForId(mappedId, (int)ColumnStatus);
+
+    if (!index.isValid() || (mappedId >= m_collections.count()))
+    {
+        return;
+    }
+
+    Item& orgItem   = m_collections[index.internalId()];
+
+    Item item(curl.toLocalFile(), orgItem.label, (Category)orgItem.parentId);
+    orgItem.path    = !orgItem.updated ? orgItem.location.albumRootPath()
+                                       : orgItem.path;
+    orgItem.label   = orgItem.location.label();
+    orgItem.childs << curl.toLocalFile();
+    orgItem.updated = true;
+
+    item.orgIndex   = index.internalId();
+    item.location   = orgItem.location;
+    item.appended   = true;
+
+    int row         = rowCount(index);
+
+    beginInsertRows(index, row, row);
+    m_collections << item;
+    endInsertRows();
+
+    // only workaround for bug 182753
+
+    Q_EMIT layoutChanged();
+}
+
 void SetupCollectionModel::slotUpdatePressed(int mappedId)
 {
     updateCollection(mappedId);
@@ -596,8 +747,8 @@ void SetupCollectionModel::addCollection(int category)
         return;
     }
 
-    QString path;
     QString label;
+    QString path = lastAddedCollectionPath;
 
     if (askForNewCollectionPath(category, &path, &label))
     {
@@ -612,7 +763,7 @@ void SetupCollectionModel::addCollection(int category)
 
         // only workaround for bug 182753
 
-        emit layoutChanged();
+        Q_EMIT layoutChanged();
     }
 }
 
@@ -622,7 +773,7 @@ void SetupCollectionModel::emitDataChangedForChildren(const QModelIndex& parent)
 {
     int rows    = rowCount(parent);
     int columns = columnCount(parent);
-    emit dataChanged(index(0, 0, parent), index(rows, columns, parent));
+    Q_EMIT dataChanged(index(0, 0, parent), index(rows, columns, parent));
 
     for (int r = 0 ; r < rows ; ++r)
     {
@@ -675,7 +826,7 @@ void SetupCollectionModel::updateCollection(int internalId)
 
             // only workaround for bug 182753
 
-            emit layoutChanged();
+            Q_EMIT layoutChanged();
         }
 
         item.deleted = false;
@@ -692,15 +843,28 @@ void SetupCollectionModel::deleteCollection(int internalId)
         return;
     }
 
-    Item& item = m_collections[index.internalId()];
+    int result    = QMessageBox::No;
+    Item& item    = m_collections[index.internalId()];
+    QString label = data(indexForId(internalId, (int)ColumnName), Qt::DisplayRole).toString();
 
     // Ask for confirmation
 
-    QString label = data(indexForId(internalId, (int)ColumnName), Qt::DisplayRole).toString();
-    int result    = QMessageBox::warning(m_dialogParentWidget,
-                                         i18n("Remove Collection?"),
-                                         i18n("Do you want to remove the collection \"%1\" from your list of collections?", label),
-                                         QMessageBox::Yes | QMessageBox::No);
+    if (item.appended)
+    {
+        result = QMessageBox::warning(m_dialogParentWidget,
+                                      i18nc("@title:window", "Remove Path from the Collection?"),
+                                      i18n("Do you want to remove the appended path \"%1\" from the collection \"%2\"?",
+                                           item.path, label),
+                                      QMessageBox::Yes | QMessageBox::No);
+    }
+    else
+    {
+        result = QMessageBox::warning(m_dialogParentWidget,
+                                      i18nc("@title:window", "Remove Collection?"),
+                                      i18n("Do you want to remove the collection \"%1\" from your list of collections?",
+                                            label),
+                                      QMessageBox::Yes | QMessageBox::No);
+    }
 
     if (result == QMessageBox::Yes)
     {
@@ -710,9 +874,36 @@ void SetupCollectionModel::deleteCollection(int internalId)
         item.deleted = true;
         endRemoveRows();
 
+        if (item.appended)
+        {
+            Item& orgItem   = m_collections[item.orgIndex];
+
+            orgItem.path    = orgItem.location.albumRootPath();
+            orgItem.label   = orgItem.location.label();
+            orgItem.childs.removeAll(item.path);
+            orgItem.updated = true;
+        }
+        else if (!item.childs.isEmpty())
+        {
+            for (int i = 0 ; i < m_collections.count() ; ++i)
+            {
+                Item& remItem = m_collections[i];
+
+                if (remItem.orgIndex == (int)index.internalId())
+                {
+                    QModelIndex remIndex       = indexForId(i, (int)ColumnStatus);
+                    QModelIndex remParentIndex = parent(remIndex);
+
+                    beginRemoveRows(remParentIndex, remIndex.row(), remIndex.row());
+                    remItem.deleted = true;
+                    endRemoveRows();
+                }
+            }
+        }
+
         // only workaround for bug 182753
 
-        emit layoutChanged();
+        Q_EMIT layoutChanged();
     }
 }
 
@@ -801,12 +992,27 @@ QVariant SetupCollectionModel::data(const QModelIndex& index, int role) const
     {
         const Item& item = m_collections.at(index.internalId());
 
+        if ((role == Qt::BackgroundRole) && item.appended)
+        {
+             return QPalette().alternateBase();
+        }
+
         switch (index.column())
         {
             case ColumnName:
             {
                 if ((role == Qt::DisplayRole) || (role == Qt::EditRole))
                 {
+                    if (item.appended)
+                    {
+                        const Item& orgItem = m_collections.at(item.orgIndex);
+
+                        if (!orgItem.label.isNull())
+                        {
+                            return orgItem.label;
+                        }
+                    }
+
                     if (!item.label.isNull())
                     {
                         return item.label;
@@ -860,6 +1066,11 @@ QVariant SetupCollectionModel::data(const QModelIndex& index, int role) const
                         return QIcon::fromTheme(QLatin1String("folder-new"));
                     }
 
+                    if (item.appended)
+                    {
+                        return QIcon::fromTheme(QLatin1String("mail-attachment"));
+                    }
+
                     switch (item.location.status())
                     {
                         case CollectionLocation::LocationAvailable:
@@ -931,6 +1142,34 @@ QVariant SetupCollectionModel::data(const QModelIndex& index, int role) const
                 break;
             }
 
+            case ColumnAppendButton:
+            {
+                switch (role)
+                {
+                    case Qt::ToolTipRole:
+                    {
+                        return i18n("Append network path");
+                    }
+
+                    case IsAppendRole:
+                    {
+                        return ((item.location.type() == CollectionLocation::Network) && !item.appended);
+                    }
+
+                    case AppendDecorationRole:
+                    {
+                        return QIcon::fromTheme(QLatin1String("list-add"));
+                    }
+
+                    case AppendMapId:
+                    {
+                        return buttonMapId(index);
+                    }
+                }
+
+                break;
+            }
+
             case ColumnUpdateButton:
             {
                 switch (role)
@@ -942,7 +1181,7 @@ QVariant SetupCollectionModel::data(const QModelIndex& index, int role) const
 
                     case IsUpdateRole:
                     {
-                        return true;
+                        return (!item.appended);
                     }
 
                     case UpdateDecorationRole:
@@ -1013,6 +1252,11 @@ QVariant SetupCollectionModel::headerData(int section, Qt::Orientation orientati
                 return i18nc("#title: collection status",     "Status");
             }
 
+            case ColumnAppendButton:
+            {
+                break;
+            }
+
             case ColumnUpdateButton:
             {
                 break;
@@ -1050,11 +1294,11 @@ int SetupCollectionModel::rowCount(const QModelIndex& parent) const
     int parentId = parent.row();
     int rowCount = 0;
 
-    foreach (const Item& item, m_collections)
+    Q_FOREACH (const Item& item, m_collections)
     {
-        if (!item.deleted && item.parentId == parentId)
+        if (!item.deleted && (item.parentId == parentId))
         {
-            ++rowCount;
+            ++rowCount; // cppcheck-suppress useStlAlgorithm
         }
     }
 
@@ -1063,7 +1307,7 @@ int SetupCollectionModel::rowCount(const QModelIndex& parent) const
 
 int SetupCollectionModel::columnCount(const QModelIndex& /*parent*/) const
 {
-    return 5;
+    return NumberOfColumns;
 }
 
 Qt::ItemFlags SetupCollectionModel::flags(const QModelIndex& index) const
@@ -1079,16 +1323,25 @@ Qt::ItemFlags SetupCollectionModel::flags(const QModelIndex& index) const
     }
     else
     {
+        Qt::ItemFlags flags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
+
         switch (index.column())
         {
             case ColumnName:
             {
-                return (Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsEditable);
+                const Item& item = m_collections.at(index.internalId());
+
+                if (item.appended)
+                {
+                    return flags;
+                }
+
+                return (flags | Qt::ItemIsEditable);
             }
 
             default:
             {
-                return (Qt::ItemIsEnabled | Qt::ItemIsSelectable);
+                return flags;
             }
         }
     }
@@ -1102,7 +1355,7 @@ bool SetupCollectionModel::setData(const QModelIndex& index, const QVariant& val
     {
         Item& item = m_collections[index.internalId()];
         item.label = value.toString();
-        emit dataChanged(index, index);
+        Q_EMIT dataChanged(index, index);
     }
 
     return false;
@@ -1117,7 +1370,7 @@ QModelIndex SetupCollectionModel::index(int row, int column, const QModelIndex&
             return createIndex(row, 0, INTERNALID);
         }
     }
-    else if ((row >= 0) && (column < 5))
+    else if ((row >= 0) && (column < NumberOfColumns))
     {
         // m_collections is a flat list with all entries, of all categories and also deleted entries.
         // The model indices contain as internal id the index to this list.
@@ -1128,7 +1381,7 @@ QModelIndex SetupCollectionModel::index(int row, int column, const QModelIndex&
         {
             const Item& item = m_collections.at(i);
 
-            if (!item.deleted && item.parentId == parentId)
+            if (!item.deleted && (item.parentId == parentId))
             {
                 if (rowCount == row)
                 {
@@ -1205,17 +1458,17 @@ SetupCollectionModel::Category SetupCollectionModel::typeToCategory(CollectionLo
     switch (type)
     {
         default:
-        case CollectionLocation::TypeVolumeHardWired:
+        case CollectionLocation::VolumeHardWired:
         {
             return CategoryLocal;
         }
 
-        case CollectionLocation::TypeVolumeRemovable:
+        case CollectionLocation::VolumeRemovable:
         {
             return CategoryRemovable;
         }
 
-        case CollectionLocation::TypeNetwork:
+        case CollectionLocation::Network:
         {
             return CategoryRemote;
         }
@@ -1232,20 +1485,22 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
     }
 
     QUrl curl       = DFileDialog::getExistingDirectoryUrl(m_dialogParentWidget,
-                                                          i18n("Choose the folder containing your collection"),
-                                                          QUrl::fromLocalFile(picPath));
+                                                           i18nc("@title:window", "Choose the Folder Containing your Collection"),
+                                                           QUrl::fromLocalFile(picPath));
 
     if (curl.isEmpty())
     {
         return false;
     }
 
+    lastAddedCollectionPath = curl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).toLocalFile();
+
     // Check path: First check with manager
 
     QString messageFromManager, deviceIcon;
     QList<CollectionLocation> assumeDeleted;
 
-    foreach (const Item& item, m_collections)
+    Q_FOREACH (const Item& item, m_collections)
     {
         if (item.deleted && !item.location.isNull())
         {
@@ -1270,7 +1525,7 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
 
     // If there are other added collections then CollectionManager does not know about them. Check here.
 
-    foreach (const Item& item, m_collections)
+    Q_FOREACH (const Item& item, m_collections)
     {
         if (!item.deleted && item.location.isNull())
         {
@@ -1308,7 +1563,7 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
         case CollectionManager::LocationNotAllowed:
         case CollectionManager::LocationInvalidCheck:
         {
-            QMessageBox::warning(m_dialogParentWidget, i18n("Problem Adding Collection"), messageFromManager);
+            QMessageBox::warning(m_dialogParentWidget, i18nc("@title:window", "Problem Adding Collection"), messageFromManager);
             // fail
             return false;
         }
@@ -1317,7 +1572,7 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
     // Create a dialog that displays volume information and allows to change the name of the collection
 
     QDialog* const dialog     = new QDialog(m_dialogParentWidget);
-    dialog->setWindowTitle(i18n("Adding Collection"));
+    dialog->setWindowTitle(i18nc("@title:window", "Adding Collection"));
 
     QWidget* const mainWidget = new QWidget(dialog);
     QLabel* const nameLabel   = new QLabel;
@@ -1326,8 +1581,8 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
 
     // lineedit for collection name
 
-    QLineEdit* const nameEdit = new QLineEdit;
-    nameEdit->setClearButtonEnabled(true);
+    DTextEdit* const nameEdit = new DTextEdit;
+    nameEdit->setLinesVisible(1);
     nameLabel->setBuddy(nameEdit);
 
     // label for the icon showing the type of storage (hard disk, CD, USB drive)
@@ -1361,8 +1616,10 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
     mainWidget->setLayout(grid1);
 
     QVBoxLayout* const vbx          = new QVBoxLayout(dialog);
-    QDialogButtonBox* const buttons = new QDialogButtonBox(QDialogButtonBox::Ok |
-                                                           QDialogButtonBox::Cancel, dialog);
+    QDialogButtonBox* const buttons = new QDialogButtonBox(QDialogButtonBox::Ok   |
+                                                           QDialogButtonBox::Help |
+                                                           QDialogButtonBox::Cancel,
+                                                           dialog);
     vbx->addWidget(mainWidget);
     vbx->addWidget(buttons);
     dialog->setLayout(vbx);
@@ -1373,6 +1630,9 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
     connect(buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
             dialog, SLOT(reject()));
 
+    connect(buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this, SLOT(slotHelp()));
+
     // default to directory name as collection name
 
     QDir dir(path);
@@ -1384,6 +1644,7 @@ bool SetupCollectionModel::askForNewCollectionPath(int category, QString* const
         {
             *newLabel = nameEdit->text();
             *newPath  = path;
+
             return true;
         }
     }
@@ -1396,7 +1657,7 @@ bool SetupCollectionModel::askForNewCollectionCategory(int* const category)
     // Create a dialog that displays the category and allows to change the category of the collection
 
     QDialog* const dialog     = new QDialog(m_dialogParentWidget);
-    dialog->setWindowTitle(i18n("Select Category"));
+    dialog->setWindowTitle(i18nc("@title:window", "Select Category"));
 
     QWidget* const mainWidget = new QWidget(dialog);
     QLabel* const nameLabel   = new QLabel;
@@ -1422,8 +1683,10 @@ bool SetupCollectionModel::askForNewCollectionCategory(int* const category)
     mainWidget->setLayout(grid1);
 
     QVBoxLayout* const vbx          = new QVBoxLayout(dialog);
-    QDialogButtonBox* const buttons = new QDialogButtonBox(QDialogButtonBox::Ok |
-                                                           QDialogButtonBox::Cancel, dialog);
+    QDialogButtonBox* const buttons = new QDialogButtonBox(QDialogButtonBox::Ok   |
+                                                           QDialogButtonBox::Help |
+                                                           QDialogButtonBox::Cancel,
+                                                           dialog);
     vbx->addWidget(mainWidget);
     vbx->addWidget(buttons);
     dialog->setLayout(vbx);
@@ -1434,6 +1697,9 @@ bool SetupCollectionModel::askForNewCollectionCategory(int* const category)
     connect(buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
             dialog, SLOT(reject()));
 
+    connect(buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this, SLOT(slotHelp()));
+
     // default to current category
 
     if (category)
@@ -1474,4 +1740,9 @@ int SetupCollectionModel::buttonMapId(const QModelIndex& index) const
     return index.internalId();
 }
 
+void SetupCollectionModel::slotHelp()
+{
+    openOnlineDocumentation(QLatin1String("setup_application"), QLatin1String("collections_settings"));
+}
+
 } // namespace Digikam
