@@ -6,18 +6,9 @@
  * Date        : 2020-11-14
  * Description : Files downloader
  *
- * Copyright (C) 2020-2021 by Maik Qualmann <metzpinguin at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2021 by Maik Qualmann <metzpinguin at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -29,6 +20,7 @@
 #include <QLabel>
 #include <QTimer>
 #include <QPointer>
+#include <QCheckBox>
 #include <QByteArray>
 #include <QMessageBox>
 #include <QPushButton>
@@ -48,6 +40,9 @@
 // Local includes
 
 #include "digikam_debug.h"
+#include "digikam_globals.h"
+#include "dxmlguiwindow.h"
+#include "systemsettings.h"
 #include "itempropertiestab.h"
 
 namespace Digikam
@@ -66,6 +61,7 @@ public:
         redirects   (0),
         buttons     (nullptr),
         progress    (nullptr),
+        faceCheck   (nullptr),
         nameLabel   (nullptr),
         reply       (nullptr),
         netMngr     (nullptr)
@@ -84,6 +80,7 @@ public:
 
     QDialogButtonBox*      buttons;
     QProgressBar*          progress;
+    QCheckBox*             faceCheck;
     QLabel*                nameLabel;
 
     QNetworkReply*         reply;
@@ -112,6 +109,12 @@ FilesDownloader::FilesDownloader(QWidget* const parent)
                              246305388
                             );
 
+    d->files << DownloadInfo(QLatin1String("aestheticdetector/"),
+                             QLatin1String("weights_inceptionv3_299.pb"),
+                             QLatin1String("8923e3daff71c07533b9023ef32c69d8c058d1e0931d76d8b81241a201138538"),
+                             88007527
+                            );
+
     if (qApp->applicationName() == QLatin1String("digikam"))
     {
         d->files << DownloadInfo(QLatin1String("facesengine/dnnface/"),
@@ -142,15 +145,23 @@ FilesDownloader::~FilesDownloader()
         d->reply = nullptr;
     }
 
+    if (d->faceCheck)
+    {
+        SystemSettings system(qApp->applicationName());
+
+        system.disableFaceEngine = d->faceCheck->isChecked();
+        system.saveSettings();
+    }
+
     delete d;
 }
 
 bool FilesDownloader::checkDownloadFiles() const
 {
-    foreach (const DownloadInfo& info, d->files)
+    Q_FOREACH (const DownloadInfo& info, d->files)
     {
         if (!downloadExists(info))
-        {
+        {   // cppcheck-suppress useStlAlgorithm
             return false;
         }
     }
@@ -160,15 +171,17 @@ bool FilesDownloader::checkDownloadFiles() const
 
 void FilesDownloader::startDownload()
 {
-    setWindowTitle(i18n("Download required files"));
+    setWindowTitle(i18nc("@title:window", "Download Required Files"));
     setMinimumHeight(250);
     setMinimumWidth(600);
 
     QWidget* const mainWidget = new QWidget(this);
     QVBoxLayout* const vBox   = new QVBoxLayout(mainWidget);
 
-    d->buttons                = new QDialogButtonBox(QDialogButtonBox::Ok |
-                                                     QDialogButtonBox::Cancel, mainWidget);
+    d->buttons                = new QDialogButtonBox(QDialogButtonBox::Help |
+                                                     QDialogButtonBox::Ok |
+                                                     QDialogButtonBox::Cancel,
+                                                     mainWidget);
     d->buttons->button(QDialogButtonBox::Ok)->setDefault(true);
     d->buttons->button(QDialogButtonBox::Ok)->setText(i18n("Download"));
     d->buttons->button(QDialogButtonBox::Ok)->setIcon(QIcon::fromTheme(QLatin1String("edit-download")));
@@ -176,10 +189,11 @@ void FilesDownloader::startDownload()
     QString path = QDir::toNativeSeparators(getFacesEnginePath());
     qint64 size  = 0;
 
-    foreach (const DownloadInfo& info, d->files)
+    Q_FOREACH (const DownloadInfo& info, d->files)
     {
         if (!downloadExists(info))
         {
+            // cppcheck-suppress useStlAlgorithm
             size += info.size;
         }
     }
@@ -189,15 +203,18 @@ void FilesDownloader::startDownload()
     QLabel* const infoLabel   = new QLabel(i18nc("%1: folder path, %2: disk size with unit",
                                                  "<p>For the face engine and red eye removal tool, digiKam "
                                                  "needs some large binary files. Some of these files were "
-                                                 "not found and are now being downloaded. You can cancel this "
-                                                 "process, the next time digiKam is started this dialog will "
-                                                 "appear again. Face detection will not work without these "
-                                                 "files.</p>"
+                                                 "not found. Click 'Download' to begin downloading the "
+                                                 "needed files. You can cancel this process, the next time "
+                                                 "digiKam is started this dialog will appear again. Face "
+                                                 "detection will not work without these files.</p>"
                                                  "<p>The files will be downloaded to %1. Make sure there are "
                                                  "around %2 available. <b>After the successful download you "
                                                  "have to restart digiKam.</b></p>", path, total), mainWidget);
+
     infoLabel->setWordWrap(true);
 
+    d->faceCheck              = new QCheckBox(i18n("Disable face engine feature and don't ask again"), mainWidget);
+
     d->progress               = new QProgressBar(mainWidget);
     d->progress->setMinimum(0);
     d->progress->setMaximum(1);
@@ -206,7 +223,9 @@ void FilesDownloader::startDownload()
     d->nameLabel              = new QLabel(mainWidget);
 
     vBox->addWidget(infoLabel);
-    vBox->addStretch(10);
+    vBox->addStretch(5);
+    vBox->addWidget(d->faceCheck);
+    vBox->addStretch(1);
     vBox->addWidget(d->nameLabel);
     vBox->addWidget(d->progress);
     vBox->addWidget(d->buttons);
@@ -216,6 +235,9 @@ void FilesDownloader::startDownload()
     connect(d->buttons->button(QDialogButtonBox::Ok), SIGNAL(clicked()),
             this, SLOT(slotDownload()));
 
+    connect(d->buttons->button(QDialogButtonBox::Help), SIGNAL(clicked()),
+            this, SLOT(slotHelp()));
+
     connect(d->buttons->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
             this, SLOT(reject()));
 
@@ -243,12 +265,14 @@ void FilesDownloader::slotDownload()
         QMessageBox::information(this, qApp->applicationName(),
                                  i18n("All files were downloaded successfully."));
 
+        d->faceCheck->setChecked(false);
+
         close();
     }
     else
     {
         QPointer<QMessageBox> msgBox = new QMessageBox(QMessageBox::Critical,
-                 i18n("Download error"),
+                 i18nc("@title:window", "Download Error"),
                  i18n("An error occurred during the download.\n\n"
                       "File: %1\n\n%2\n\n"
                       "You can try again or continue the "
@@ -257,7 +281,7 @@ void FilesDownloader::slotDownload()
                  QMessageBox::Yes | QMessageBox::Cancel,
                  qApp->activeWindow());
 
-        msgBox->button(QMessageBox::Yes)->setText(i18n("Try again"));
+        msgBox->button(QMessageBox::Yes)->setText(i18nc("@action:button", "Try Again"));
         msgBox->button(QMessageBox::Yes)->setIcon(QIcon::fromTheme(QLatin1String("edit-download")));
 
         int result = msgBox->exec();
@@ -449,13 +473,18 @@ void FilesDownloader::slotDownloadProgress(qint64 bytesReceived, qint64 bytesTot
 
 QString FilesDownloader::getFacesEnginePath() const
 {
-    QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+    QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
     QUrl    appUrl  = QUrl::fromLocalFile(appPath).adjusted(QUrl::RemoveFilename);
     appUrl.setPath(appUrl.path() + QLatin1String("digikam/facesengine"));
 
     return appUrl.toLocalFile();
 }
 
+void FilesDownloader::slotHelp()
+{
+    openOnlineDocumentation(QLatin1String("getting_started"), QLatin1String("quick_start"), QLatin1String("firstrun-downloads"));
+}
+
 //-----------------------------------------------------------------------------
 
 DownloadInfo::DownloadInfo()
