@@ -6,19 +6,10 @@
  * Date        : 2003-02-03
  * Description : digiKam setup dialog.
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2003-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2003-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU Album
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Album Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -57,6 +48,10 @@
 #include "dxmlguiwindow.h"
 #include "onlineversiondlg.h"
 
+#ifdef HAVE_MEDIAPLAYER
+#   include "setupvideo.h"
+#endif
+
 namespace Digikam
 {
 
@@ -69,6 +64,7 @@ public:
         page_collections        (nullptr),
         page_albumView          (nullptr),
         page_tooltip            (nullptr),
+        page_video              (nullptr),
         page_metadata           (nullptr),
         page_template           (nullptr),
         page_lighttable         (nullptr),
@@ -82,6 +78,9 @@ public:
         collectionsPage         (nullptr),
         albumViewPage           (nullptr),
         tooltipPage             (nullptr),
+#ifdef HAVE_MEDIAPLAYER
+        videoPage               (nullptr),
+#endif
         metadataPage            (nullptr),
         templatePage            (nullptr),
         lighttablePage          (nullptr),
@@ -98,6 +97,7 @@ public:
     DConfigDlgWdgItem*       page_collections;
     DConfigDlgWdgItem*       page_albumView;
     DConfigDlgWdgItem*       page_tooltip;
+    DConfigDlgWdgItem*       page_video;
     DConfigDlgWdgItem*       page_metadata;
     DConfigDlgWdgItem*       page_template;
     DConfigDlgWdgItem*       page_lighttable;
@@ -112,6 +112,13 @@ public:
     SetupCollections*        collectionsPage;
     SetupAlbumView*          albumViewPage;
     SetupToolTip*            tooltipPage;
+
+#ifdef HAVE_MEDIAPLAYER
+
+    SetupVideo*              videoPage;
+
+#endif
+
     SetupMetadata*           metadataPage;
     SetupTemplate*           templatePage;
     SetupLightTable*         lighttablePage;
@@ -136,90 +143,87 @@ Setup::Setup(QWidget* const parent)
                    Qt::WindowCloseButtonHint     |
                    Qt::WindowMinMaxButtonsHint);
 
-    setWindowTitle(i18n("Configure"));
+    setWindowTitle(i18nc("@title:window", "Configure"));
     setStandardButtons(QDialogButtonBox::Help | QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     button(QDialogButtonBox::Ok)->setDefault(true);
     setFaceType(List);
     setModal(true);
 
     d->databasePage     = new SetupDatabase();
-    d->page_database    = addPage(d->databasePage, i18n("Database"));
-    d->page_database->setHeader(i18n("<qt>Database Settings<br/>"
-                                     "<i>Customize database settings</i></qt>"));
+    d->page_database    = addPage(d->databasePage, i18nc("@title: settings section", "Database"));
+    d->page_database->setHeader(i18nc("@title", "Database Settings\nCustomize database settings"));
     d->page_database->setIcon(QIcon::fromTheme(QLatin1String("network-server-database")));
 
     d->collectionsPage  = new SetupCollections();
-    d->page_collections = addPage(d->collectionsPage, i18n("Collections"));
-    d->page_collections->setHeader(i18n("<qt>Collections Settings<br/>"
-                                        "<i>Set root albums locations</i></qt>"));
+    d->page_collections = addPage(d->collectionsPage, i18nc("@title: settings section", "Collections"));
+    d->page_collections->setHeader(i18nc("@title", "Collections Settings\nSet root albums locations"));
     d->page_collections->setIcon(QIcon::fromTheme(QLatin1String("folder-pictures")));
 
     d->albumViewPage  = new SetupAlbumView();
-    d->page_albumView = addPage(d->albumViewPage, i18n("Views"));
-    d->page_albumView->setHeader(i18n("<qt>Application Views Settings<br/>"
-                                      "<i>Customize the look of the views</i></qt>"));
+    d->page_albumView = addPage(d->albumViewPage, i18nc("@title: settings section", "Views"));
+    d->page_albumView->setHeader(i18nc("@title", "Application Views Settings\nCustomize the look of the views"));
     d->page_albumView->setIcon(QIcon::fromTheme(QLatin1String("view-list-icons")));
 
     d->tooltipPage  = new SetupToolTip();
-    d->page_tooltip = addPage(d->tooltipPage, i18n("Tool-Tip"));
-    d->page_tooltip->setHeader(i18n("<qt>Items Tool-Tip Settings<br/>"
-                                    "<i>Customize information in item tool-tips</i></qt>"));
+    d->page_tooltip = addPage(d->tooltipPage, i18nc("@title: settings section", "Tool-Tip"));
+    d->page_tooltip->setHeader(i18nc("@title", "Items Tool-Tip Settings\nCustomize information in item tool-tips"));
     d->page_tooltip->setIcon(QIcon::fromTheme(QLatin1String("dialog-information")));
 
+#ifdef HAVE_MEDIAPLAYER
+
+    d->videoPage  = new SetupVideo();
+    d->page_video = addPage(d->videoPage, i18nc("@title: settings section", "Video"));
+    d->page_video->setHeader(i18nc("@title", "Video Preview Settings\nCustomize settings to play video media"));
+    d->page_video->setIcon(QIcon::fromTheme(QLatin1String("video-x-generic")));
+
+#endif
+
     d->metadataPage  = new SetupMetadata();
-    d->page_metadata = addPage(d->metadataPage, i18n("Metadata"));
-    d->page_metadata->setHeader(i18n("<qt>Embedded Image Information Management<br/>"
-                                     "<i>Setup relations between images and metadata</i></qt>"));
-    d->page_metadata->setIcon(QIcon::fromTheme(QLatin1String("format-text-code"))); // krazy:exclude=iconnames
+    d->page_metadata = addPage(d->metadataPage, i18nc("@title: settings section", "Metadata"));
+    d->page_metadata->setHeader(i18nc("@title", "Embedded Image Information Management\nSetup relations between images and metadata"));
+    d->page_metadata->setIcon(QIcon::fromTheme(QLatin1String("format-text-code")));
 
     d->templatePage  = new SetupTemplate();
-    d->page_template = addPage(d->templatePage, i18n("Templates"));
-    d->page_template->setHeader(i18n("<qt>Metadata templates<br/>"
-                                     "<i>Manage your collection of metadata templates</i></qt>"));
+    d->page_template = addPage(d->templatePage, i18nc("@title: settings section", "Templates"));
+    d->page_template->setHeader(i18nc("@title", "Metadata templates\nManage your collection of metadata templates"));
     d->page_template->setIcon(QIcon::fromTheme(QLatin1String("im-user")));
 
     d->editorPage  = new SetupEditor();
-    d->page_editor = addPage(d->editorPage, i18n("Image Editor"));
-    d->page_editor->setHeader(i18n("<qt>Image Editor Settings<br/>"
-                                   "<i>Customize the image editor settings</i></qt>"));
+    d->page_editor = addPage(d->editorPage, i18nc("@title: settings section", "Image Editor"));
+    d->page_editor->setHeader(i18nc("@title", "Image Editor Settings\nCustomize the image editor settings"));
     d->page_editor->setIcon(QIcon::fromTheme(QLatin1String("document-edit")));
 
     d->iccPage  = new SetupICC(buttonBox());
-    d->page_icc = addPage(d->iccPage, i18n("Color Management"));
-    d->page_icc->setHeader(i18n("<qt>Settings for Color Management<br/>"
-                                "<i>Customize the color management settings</i></qt>"));
+    d->page_icc = addPage(d->iccPage, i18nc("@title: settings section", "Color Management"));
+    d->page_icc->setHeader(i18nc("@title", "Settings for Color Management\nCustomize the color management settings"));
     d->page_icc->setIcon(QIcon::fromTheme(QLatin1String("preferences-desktop-display-color")));
 
     d->lighttablePage  = new SetupLightTable();
-    d->page_lighttable = addPage(d->lighttablePage, i18n("Light Table"));
-    d->page_lighttable->setHeader(i18n("<qt>Light Table Settings<br/>"
-                                       "<i>Customize tool used to compare images</i></qt>"));
+    d->page_lighttable = addPage(d->lighttablePage, i18nc("@title: settings section", "Light Table"));
+    d->page_lighttable->setHeader(i18nc("@title", "Light Table Settings\nCustomize tool used to compare images"));
     d->page_lighttable->setIcon(QIcon::fromTheme(QLatin1String("lighttable")));
 
     d->imageQualitySorterPage = new SetupImageQualitySorter();
-    d->page_imagequalitysorter = addPage(d->imageQualitySorterPage, i18n("Image Quality Sorter"));
-    d->page_imagequalitysorter->setHeader(i18n("<qt>Image Quality Sorter Settings</qt>"));
+    d->page_imagequalitysorter = addPage(d->imageQualitySorterPage, i18nc("@title: settings section", "Image Quality Sorter"));
+    d->page_imagequalitysorter->setHeader(i18nc("@title", "Image Quality Sorter Settings\nCustomize default settings to perform image triaging by quality"));
     d->page_imagequalitysorter->setIcon(QIcon::fromTheme(QLatin1String("flag-green")));
 
     d->cameraPage  = new SetupCamera();
-    d->page_camera = addPage(d->cameraPage, i18n("Cameras"));
-    d->page_camera->setHeader(i18n("<qt>Camera Settings<br/>"
-                                   "<i>Manage your camera devices</i></qt>"));
+    d->page_camera = addPage(d->cameraPage, i18nc("@title: settings section", "Cameras"));
+    d->page_camera->setHeader(i18nc("@title", "Camera Settings\nManage your camera devices"));
     d->page_camera->setIcon(QIcon::fromTheme(QLatin1String("camera-photo")));
 
     connect(d->cameraPage, SIGNAL(signalUseFileMetadataChanged(bool)),
             d->tooltipPage, SLOT(slotUseFileMetadataChanged(bool)));
 
     d->pluginsPage  = new SetupPlugins();
-    d->page_plugins = addPage(d->pluginsPage, i18n("Plugins"));
-    d->page_plugins->setHeader(i18n("<qt>Plug-in Settings<br/>"
-                                    "<i>Set which plugins will be accessible from application</i></qt>"));
+    d->page_plugins = addPage(d->pluginsPage, i18nc("@title: settings section", "Plugins"));
+    d->page_plugins->setHeader(i18nc("@title", "Plug-in Settings\nSet which plugins will be accessible from application"));
     d->page_plugins->setIcon(QIcon::fromTheme(QLatin1String("preferences-plugin")));
 
     d->miscPage  = new SetupMisc(this);
-    d->page_misc = addPage(d->miscPage, i18nc("@title: miscs settings section", "Miscellaneous"));
-    d->page_misc->setHeader(i18n("<qt>Miscellaneous Settings<br/>"
-                                 "<i>Customize behavior of the other parts of digiKam</i></qt>"));
+    d->page_misc = addPage(d->miscPage, i18nc("@title: settings section", "Miscellaneous"));
+    d->page_misc->setHeader(i18nc("@title", "Miscellaneous Settings\nCustomize behavior of the other parts of digiKam"));
     d->page_misc->setIcon(QIcon::fromTheme(QLatin1String("preferences-other")));
 
     for (int i = 0 ; i != SetupPageEnumLast ; ++i)
@@ -246,11 +250,14 @@ Setup::Setup(QWidget* const parent)
     connect(buttonBox()->button(QDialogButtonBox::Ok), &QPushButton::clicked,
             this, &Setup::slotOkClicked);
 
+    connect(buttonBox()->button(QDialogButtonBox::Cancel), &QPushButton::clicked,
+            this, &Setup::slotCancelClicked);
+
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("Setup Dialog"));
 
     winId();
-    windowHandle()->resize(800, 600);
+    DXmlGuiWindow::setGoodDefaultWindowSize(windowHandle());
     DXmlGuiWindow::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size());
 }
@@ -259,15 +266,26 @@ Setup::~Setup()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(QLatin1String("Setup Dialog"));
-    group.writeEntry(QLatin1String("Setup Page"), (int)activePageIndex());
+    group.writeEntry(QLatin1String("Setup Page"),      (int)activePageIndex());
+    group.writeEntry(QLatin1String("Albumview Tab"),   (int)d->albumViewPage->activeTab());
+    group.writeEntry(QLatin1String("ToolTip Tab"),     (int)d->tooltipPage->activeTab());
+    group.writeEntry(QLatin1String("Video Tab"),       (int)d->videoPage->activeTab());
+    group.writeEntry(QLatin1String("Metadata Tab"),    (int)d->metadataPage->activeTab());
+    group.writeEntry(QLatin1String("Metadata SubTab"), (int)d->metadataPage->activeSubTab());
+    group.writeEntry(QLatin1String("Editor Tab"),      (int)d->editorPage->activeTab());
+    group.writeEntry(QLatin1String("ICC Tab"),         (int)d->iccPage->activeTab());
+    group.writeEntry(QLatin1String("Camera Tab"),      (int)d->cameraPage->activeTab());
+    group.writeEntry(QLatin1String("Plugin Tab"),      (int)d->pluginsPage->activeTab());
+    group.writeEntry(QLatin1String("Misc Tab"),        (int)d->miscPage->activeTab());
     DXmlGuiWindow::saveWindowSize(windowHandle(), group);
     config->sync();
+
     delete d;
 }
 
 void Setup::slotHelp()
 {
-    DXmlGuiWindow::openHandbook(QLatin1String("setup_application"));
+    openOnlineDocumentation(QLatin1String("setup_application"));
 }
 
 void Setup::setTemplate(const Template& t)
@@ -395,8 +413,8 @@ bool Setup::execMetadataFilters(QWidget* const parent, int tab)
         return false;
     }
 
-    widget->setActiveMainTab(SetupMetadata::Display);
-    widget->setActiveSubTab(tab);
+    widget->setActiveTab(SetupMetadata::Display);
+    widget->setActiveSubTab((SetupMetadata::MetadataSubTab)tab);
 
     bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
     delete setup;
@@ -424,7 +442,61 @@ bool Setup::execExifTool(QWidget* const parent)
         return false;
     }
 
-    widget->setActiveMainTab(SetupMetadata::ExifTool);
+    widget->setActiveTab(SetupMetadata::ExifTool);
+
+    bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
+    delete setup;
+
+    return success;
+}
+
+bool Setup::execLocalize(QWidget* const parent)
+{
+    QPointer<Setup> setup        = new Setup(parent);
+    setup->showPage(MiscellaneousPage);
+    setup->setFaceType(Plain);
+
+    DConfigDlgWdgItem* const cur = setup->currentPage();
+
+    if (!cur)
+    {
+        return false;
+    }
+
+    SetupMisc* const widget  = dynamic_cast<SetupMisc*>(cur->widget());
+
+    if (!widget)
+    {
+        return false;
+    }
+
+    widget->setActiveTab(SetupMisc::Localize);
+
+    bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
+    delete setup;
+
+    return success;
+}
+
+bool Setup::execImageQualitySorter(QWidget* const parent)
+{
+    QPointer<Setup> setup        = new Setup(parent);
+    setup->showPage(ImageQualityPage);
+    setup->setFaceType(Plain);
+
+    DConfigDlgWdgItem* const cur = setup->currentPage();
+
+    if (!cur)
+    {
+        return false;
+    }
+
+    SetupImageQualitySorter* const widget  = dynamic_cast<SetupImageQualitySorter*>(cur->widget());
+
+    if (!widget)
+    {
+        return false;
+    }
 
     bool success                 = (setup->DConfigDlg::exec() == QDialog::Accepted);
     delete setup;
@@ -453,6 +525,13 @@ void Setup::slotOkClicked()
     d->collectionsPage->applySettings();
     d->albumViewPage->applySettings();
     d->tooltipPage->applySettings();
+
+#ifdef HAVE_MEDIAPLAYER
+
+    d->videoPage->applySettings();
+
+#endif
+
     d->metadataPage->applySettings();
     d->templatePage->applySettings();
     d->lighttablePage->applySettings();
@@ -475,6 +554,17 @@ void Setup::slotOkClicked()
     accept();
 }
 
+void Setup::slotCancelClicked()
+{
+
+#ifdef HAVE_MEDIAPLAYER
+
+    d->videoPage->cancel();
+
+#endif
+
+}
+
 void Setup::showPage(Setup::Page page)
 {
     DConfigDlgWdgItem* item = nullptr;
@@ -485,6 +575,16 @@ void Setup::showPage(Setup::Page page)
         KConfigGroup group        = config->group(QLatin1String("Setup Dialog"));
 
         item = d->pageItem((Page)group.readEntry(QLatin1String("Setup Page"), (int)CollectionsPage));
+        d->albumViewPage->setActiveTab((SetupAlbumView::AlbumTab)group.readEntry(QLatin1String("AlbumView Tab"), (int)SetupAlbumView::IconView));
+        d->tooltipPage->setActiveTab((SetupToolTip::ToolTipTab)group.readEntry(QLatin1String("ToolTip Tab"), (int)SetupToolTip::IconItems));
+        d->videoPage->setActiveTab((SetupVideo::VideoTab)group.readEntry(QLatin1String("Video Tab"), (int)SetupVideo::Decoder));
+        d->metadataPage->setActiveTab((SetupMetadata::MetadataTab)group.readEntry(QLatin1String("Metadata Tab"), (int)SetupMetadata::Behavior));
+        d->metadataPage->setActiveSubTab((SetupMetadata::MetadataSubTab)group.readEntry(QLatin1String("Metadata SubTab"), (int)SetupMetadata::ExifViewer));
+        d->editorPage->setActiveTab((SetupEditor::EditorTab)group.readEntry(QLatin1String("Editor Tab"), (int)SetupEditor::EditorWindow));
+        d->iccPage->setActiveTab((SetupICC::ICCTab)group.readEntry(QLatin1String("ICC Tab"), (int)SetupICC::Behavior));
+        d->cameraPage->setActiveTab((SetupCamera::CameraTab)group.readEntry(QLatin1String("Camera Tab"), (int)SetupCamera::Devices));
+        d->pluginsPage->setActiveTab((SetupPlugins::PluginTab)group.readEntry(QLatin1String("Plugin Tab"), (int)SetupPlugins::Generic));
+        d->miscPage->setActiveTab((SetupMisc::MiscTab)group.readEntry(QLatin1String("Misc Tab"), (int)SetupMisc::Behaviour));
     }
     else
     {
@@ -518,6 +618,15 @@ Setup::Page Setup::activePageIndex() const
         return ToolTipPage;
     }
 
+#ifdef HAVE_MEDIAPLAYER
+
+    if (cur == d->page_video)
+    {
+        return VideoPage;
+    }
+
+#endif
+
     if (cur == d->page_metadata)
     {
         return MetadataPage;
@@ -582,6 +691,13 @@ DConfigDlgWdgItem* Setup::Private::pageItem(Setup::Page page) const
         case Setup::ToolTipPage:
             return page_tooltip;
 
+#ifdef HAVE_MEDIAPLAYER
+
+        case Setup::VideoPage:
+            return page_video;
+
+#endif
+
         case Setup::MetadataPage:
             return page_metadata;
 
