@@ -3,10 +3,9 @@
 # Script to build a Linux Host installation to compile an AppImage bundle of digiKam.
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Halt and catch errors
@@ -28,17 +27,17 @@ echo "--------------------------------------------------------------------------
 #################################################################################################
 # Pre-processing checks
 
-. ./config.sh
 . ./common.sh
+. ./config.sh
 ChecksRunAsRoot
 StartScript
 ChecksCPUCores
 HostAdjustments
 RegisterRemoteServers
-CheckSystemReleaseID
-
 ORIG_WD="`pwd`"
 
+#################################################################################################
+
 if   [[ "$OS_NAME" == "mageia" ]] ; then
 
     . ./host_mageia.inc
@@ -49,11 +48,16 @@ elif [[ "$OS_NAME" == "ubuntu" ]] ; then
 
 fi
 
-# Clean up previous openssl install
+# Clean up previous openssl and libicu install
 
-rm -fr /usr/local/lib/libssl.a    || true
-rm -fr /usr/local/lib/libcrypto.a || true
-rm -fr /usr/local/include/openssl || true
+rm -fr /usr/local/lib/libssl.a       || true
+rm -fr /usr/local/lib/libcrypto.a    || true
+rm -fr /usr/local/include/openssl    || true
+
+rm -fr /usr/local/lib/libicu*.a      || true
+rm -fr /usr/local/lib/icu            || true
+rm -fr /usr/local/lib/pkgconfig/icu* || true
+rm -fr /usr/local/include/unicode    || true
 
 #################################################################################################
 
@@ -64,15 +68,15 @@ cd /
 
 # Create the build dir for the 3rdparty deps
 if [ ! -d $BUILDING_DIR ] ; then
-    mkdir -p $BUILDING_DIR
+    mkdir $BUILDING_DIR
 fi
 
 if [ ! -d $DOWNLOAD_DIR ] ; then
-    mkdir -p $DOWNLOAD_DIR
+    mkdir $DOWNLOAD_DIR
 fi
 
 if [ ! -d /opt/cmake ] ; then
-    mkdir -p /opt/cmake
+    mkdir /opt/cmake
 fi
 
 #################################################################################################
@@ -114,8 +118,10 @@ rm -rf $BUILDING_DIR/* || true
 # Low level libraries and Qt5 dependencies
 # NOTE: The order to compile each component here is very important.
 
+# TODO: more recent libicu do not link yet with Qt6
 #/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_libicu        -- -j$CPU_CORES
-#/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_openssl       -- -j$CPU_CORES
+
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_openssl       -- -j$CPU_CORES
 
 /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_qt            -- -j$CPU_CORES    # depend of tiff, png, jpeg
 
