@@ -3,10 +3,9 @@
 # Script to build digiKam under Linux host
 # This script must be run as sudo
 #
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Halt and catch errors
@@ -33,8 +32,8 @@ echo "------------------------------------"
 #################################################################################################
 # Pre-processing checks
 
-. ./config.sh
 . ./common.sh
+. ./config.sh
 ChecksRunAsRoot
 StartScript
 ChecksCPUCores
@@ -51,6 +50,7 @@ ORIG_WD="`pwd`"
 # Install out-dated dependencies
 
 cd $BUILDING_DIR
+rm -rf $BUILDING_DIR/* || true
 
 /opt/cmake/bin/cmake $ORIG_WD/../3rdparty \
       -DCMAKE_INSTALL_PREFIX:PATH=/usr \
@@ -63,8 +63,6 @@ cd $BUILDING_DIR
 
 /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_heif          -- -j$CPU_CORES
 cp $DOWNLOAD_DIR/heif_manifest.txt $ORIG_WD/data/
-/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_qtav          -- -j$CPU_CORES    # depend of qt and ffmpeg
-cp $DOWNLOAD_DIR/qtav_manifest.txt $ORIG_WD/data/
 /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_exiv2         -- -j$CPU_CORES
 cp $DOWNLOAD_DIR/exiv2_manifest.txt $ORIG_WD/data/
 /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_lensfun       -- -j$CPU_CORES
@@ -73,6 +71,17 @@ cp $DOWNLOAD_DIR/lensfun_manifest.txt $ORIG_WD/data/
 #################################################################################################
 # Build digiKam in temporary directory and installation
 
+# Clean up previous install (see bug #459276)
+
+FILES=$(find /usr | { grep -E '(digikam|showfoto)' || true; })
+
+for FILE in $FILES ; do
+    if [[ -f ${FILE} || -d ${FILE} ]] ; then
+        echo -e "   ==> ${FILE} will be removed from previous install"
+        rm -fr ${FILE}
+    fi
+done
+
 if [ -d "$DK_BUILDTEMP/digikam-$DK_VERSION" ] ; then
 
     echo "---------- Updating existing $DK_BUILDTEMP"
@@ -83,7 +92,6 @@ if [ -d "$DK_BUILDTEMP/digikam-$DK_VERSION" ] ; then
     git reset --hard
     git pull
 
-    rm -fr po
     rm -fr build
     mkdir -p build
     cd build
@@ -120,15 +128,28 @@ fi
 echo -e "\n\n"
 echo "---------- Configure digiKam $DK_VERSION"
 
+#export CC=/usr/bin/clang
+#export CXX=/usr/bin/clang++
+
+if [[ $DK_QTVERSION == 5.* ]] ; then
+
+    echo "Build digiKam with Qt5"
+    BUILD_WITH_QT6=OFF
+
+else
+
+    echo "Build digiKam with Qt6"
+    BUILD_WITH_QT6=ON
+
+fi
+
 /opt/cmake/bin/cmake -G "Unix Makefiles" .. \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DCMAKE_INSTALL_PREFIX=/usr \
       -DBUILD_TESTING=OFF \
+      -DBUILD_WITH_QT6=$BUILD_WITH_QT6 \
       -DBUILD_WITH_CCACHE=ON \
-      -DDIGIKAMSC_CHECKOUT_PO=ON \
-      -DDIGIKAMSC_CHECKOUT_DOC=OFF \
       -DDIGIKAMSC_COMPILE_PO=ON \
-      -DDIGIKAMSC_COMPILE_DOC=OFF \
       -DDIGIKAMSC_COMPILE_DIGIKAM=ON \
       -DENABLE_KFILEMETADATASUPPORT=OFF \
       -DENABLE_AKONADICONTACTSUPPORT=OFF \
@@ -182,9 +203,15 @@ fi
 #################################################################################################
 # Install Extra Plugins
 
-cd $BUILDING_DIR
+# TODO: not yet ported to Qt6
 
-/opt/cmake/bin/cmake $ORIG_WD/../3rdparty \
+if [[ $DK_QTVERSION == 5.* ]] ; then
+
+    echo "Build 3rd-party plugins with Qt5"
+
+    cd $BUILDING_DIR
+
+    /opt/cmake/bin/cmake $ORIG_WD/../3rdparty \
       -DCMAKE_INSTALL_PREFIX:PATH=/usr \
       -DINSTALL_ROOT=/usr \
       -DEXTERNALS_DOWNLOAD_DIR=$DOWNLOAD_DIR \
@@ -193,9 +220,15 @@ cd $BUILDING_DIR
       -DENABLE_QTVERSION=$DK_QTVERSION \
       -DENABLE_QTWEBENGINE=$DK_QTWEBENGINE
 
-/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_mosaicwall -- -j$CPU_CORES
-/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_flowview   -- -j$CPU_CORES
-/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_gmic_qt    -- -j$CPU_CORES
+    /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_gmic_qt    -- -j$CPU_CORES
+    /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_mosaicwall -- -j$CPU_CORES
+    /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_flowview   -- -j$CPU_CORES
+
+else
+
+    echo "Drop build stage of 3rd-party plugins with Qt6"
+
+fi
 
 #################################################################################################
 
