@@ -2,19 +2,22 @@
 
 # Configuration for script to build AppImage bundle.
 #
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+#
+# SPDX-License-Identifier: BSD-3-Clause
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
 
 ########################################################################
 
+# NOTE: include common.sh header first.
+CheckSystemReleaseID
+
 # digiKam tag version from git. Official tarball do not include extra shared libraries.
 # The list of tags can be listed with this url: https://invent.kde.org/graphics/digikam/-/tags
 # If you want to package current implementation from git, use "master" as tag.
-#DK_VERSION=v7.6.0
-#DK_VERSION=master
-DK_VERSION=qt5-maintenance
+#DK_VERSION=v7.0.0
+DK_VERSION=master
+#DK_VERSION=gsoc21-qt6-port
 
 # Absolute path where are downloaded all tarballs to compile.
 DOWNLOAD_DIR="/d"
@@ -41,20 +44,21 @@ DK_BUILDTEMP=$BUILDING_DIR/dktemp
 
 # KDE Application version.
 # See official release here: https://download.kde.org/stable/release-service/
-DK_KA_VERSION="22.12.1"
+DK_KA_VERSION="22.12.3"
 
 # KDE KF5 frameworks version.
 # See official release here: https://download.kde.org/stable/frameworks/
-DK_KF5_VERSION="5.102"
-
-# Installer sub version to differentiates newer updates of the installer itself, even if the underlying application hasn’t changed.
-#DK_SUBVER="-01"
+DK_KF5_VERSION="5.104"
 
 # Installer will include or not digiKam debug symbols
 DK_DEBUG=0
 
-# Qt version to use in bundle. Possible values: 5.15, 5.15-LTS
-#DK_QTVERSION="5.15-LTS"
+# Qt version to use in bundle. Possible values:
+# - 5.15:     stable Qt5 release.
+# - 5.15-LTS: rolling release version 5 (can be not stbilized)
+# - 6.3.1:    stable Qt6 release.
+
+#DK_QTVERSION="6.3.1"
 DK_QTVERSION="5.15"
 
 # QtWebEngine version to use in bundle when 5.15-LTS is used.
@@ -63,6 +67,9 @@ DK_QTWEBENGINEVERSION="5.15.9"
 # Option to use QtWebEngine instead QtWebkit
 DK_QTWEBENGINE=1
 
+# Installer sub version to differentiates newer updates of the installer itself, even if the underlying application hasn’t changed.
+#DK_SUBVER="-01"
+
 # Sign bundles with GPG. Passphrase must be hosted in ~/.gnupg/dkorg-gpg-pwd.txt
 DK_SIGN=0
 
