@@ -3,11 +3,10 @@
 # Script to build a bundle Macports installation with all digiKam dependencies in a dedicated directory
 # This script must be run as sudo
 #
-# Copyright (c) 2015      by Shanti, <listaccount at revenant dot org>
-# Copyright (c) 2015-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015      by Shanti, <listaccount at revenant dot org>
+# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Ask to run as root
@@ -138,7 +137,7 @@ if [[ $CONTINUE_INSTALL == 0 ]]; then
 
         if [ -z $MP_LASTEST_VER ] ; then
 
-            echo "---------- Cannot check the lastest Macports version from $MP_URL"
+            echo "---------- Cannot check the lastest Macports verion from $MP_URL"
             echo "---------- Aborting..."
             exit;
 
@@ -225,8 +224,6 @@ echo -e "\n"
 echo "---------- Updating MacPorts"
 port -v selfupdate
 
-#################################################################################################
-
 if [[ $CONTINUE_INSTALL == 0 ]]; then
 
 #    port -v upgrade outdated
@@ -293,6 +290,8 @@ port install \
              bison \
              py38-lxml \
              x265 \
+             libde265 \
+             libheif \
              aom \
              ffmpeg \
              wget +ssl \
@@ -323,7 +322,7 @@ fi
 
 port activate boost
 
-# port broken since a while. Check later
+# port broken since a while. check later
 #             sane-backends \
 
 echo -e "\n"
@@ -370,7 +369,6 @@ fi
 
 cmake --build . --config RelWithDebInfo --target ext_opencv      -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_imagemagick -- -j$CPU_CORES
-cmake --build . --config RelWithDebInfo --target ext_libde265    -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_libjxl      -- -j$CPU_CORES
 cmake --build . --config RelWithDebInfo --target ext_libavif     -- -j$CPU_CORES
 
