@@ -4,11 +4,10 @@
 # and create a PKG file with Packages application (http://s.sudre.free.fr/Software/Packages/about.html)
 # This script must be run as sudo
 #
-# Copyright (c) 2015      by Shanti, <listaccount at revenant dot org>
-# Copyright (c) 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
+# SPDX-FileCopyrightText: 2015      by Shanti, <listaccount at revenant dot org>
+# SPDX-FileCopyrightText: 2015-2022 by Gilles Caulier  <caulier dot gilles at gmail dot com>
 #
-# Redistribution and use is allowed according to the terms of the BSD license.
-# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
+# SPDX-License-Identifier: BSD-3-Clause
 #
 
 # Ask to run as root
@@ -600,14 +599,14 @@ ln -sv "../../../digikam.app/Contents/etc/mariadb$MARIADB_SUFFIX"
 cd $DOWNLOAD_DIR
 
 #if [ ! -f "$DOWNLOAD_DIR/Image-ExifTool.tar.gz" ] ; then
-    wget "https://files.kde.org/digikam/exiftool/Image-ExifTool.tar.gz" -O Image-ExifTool.tar.gz
+    wget https://files.kde.org/digikam/exiftool/Image-ExifTool.tar.gz -O Image-ExifTool.tar.gz
 #fi
 
 tar -xvf "$DOWNLOAD_DIR/Image-ExifTool.tar.gz" -C "$TEMPROOT/digikam.app/Contents/bin"
 ln -s "$TEMPROOT/digikam.app/Contents/bin/Image-ExifTool*" "$TEMPROOT/digikam.app/Contents/bin/Image-ExifTool"
 
-cd "$TEMPROOT/digikam.app/Contents/bin"
-ln -sv "./Image-ExifTool/exiftool" exiftool
+cd $TEMPROOT/digikam.app/Contents/bin
+ln -sv "./Image-ExifTool/exiftool" "exiftool"
 
 #################################################################################################
 # Build PKG file
